@@ -529,6 +529,97 @@ drp_out();
 
 
 
+function prn_title_over (id_prn) {
+var link_elem = document.getElementById(id_prn).getElementsByTagName('a')[0];
+if (!ArTiOr[id_prn]) ArTiOr[id_prn] = link_elem.getAttribute('title');
+if (!ArTiPr[id_prn]) {
+var xmlhttp = new XMLHttpRequest();
+xmlhttp.open('GET','tabella.php?id_sessione='+id_sessione+'&dati_prn='+id_prn,false);
+xmlhttp.send();
+var dati_prn = xmlhttp.responseXML.getElementsByTagName('txt');
+if (dati_prn.length) {
+ArTiPr[id_prn] = dati_prn[0].childNodes[0].nodeValue;
+}
+}
+if (ArTiPr[id_prn]) link_elem.setAttribute('title',ArTiPr[id_prn]);
+}
+
+
+
+function prn_title_out (id_prn) {
+var link_elem = document.getElementById(id_prn).getElementsByTagName('a')[0];
+if (ArTiOr[id_prn] == 'null' || ArTiOr[id_prn] == '' || ArTiOr[id_prn] == null) link_elem.removeAttribute('title')
+else link_elem.setAttribute('title',ArTiOr[id_prn]);
+}
+
+
+
+function res_color (n_col,on) {
+var boxes = document.getElementById(curr_sel_row).childNodes;
+for (var n1 = ((sel_start_date * 1) + 1) ; n1 <= n_col ; n1++) {
+if (on) boxes[n1].style.backgroundColor = colore_drp2;
+else boxes[n1].style.backgroundColor = '';
+}
+}
+
+
+
+function reserve_sel_dates (row_id,n_col) {
+var ins_res = 0;
+if (sel_start_date) {
+if (row_id == curr_sel_row) ins_res = 1;
+row_id = curr_sel_row;
+var curr_stop_date = n_col;
+n_col = sel_start_date;
+}
+else curr_sel_row = row_id;
+var boxes = document.getElementById(row_id).childNodes;
+if (sel_start_date) boxes[n_col].style.backgroundColor = '';
+else boxes[n_col].style.backgroundColor = colore_drp2;
+var c_fine = 0;
+for (n1 = 1 ; n1 < ((n_col * 1) + 1) ; n1++) {
+var c_ini = c_fine;
+c_fine = (boxes[n1].colSpan / 2);
+c_fine = c_ini + c_fine;
+} // for n2
+var c_ini1 = c_ini;
+var c_fine1 = c_fine;
+for (var n1 = ((n_col * 1) + 1) ; n1 < (boxes.length - 1) ; n1++) {
+var prenota = boxes[n1].getElementsByTagName('table');
+if (prenota.length) break;
+if (!sel_start_date && boxes[n1].style.backgroundColor != '' && boxes[n1].style.backgroundColor != 'null' && boxes[n1].style.backgroundColor != null) break;
+if (sel_start_date && n1 > sel_stop_date) break;
+c_ini = c_fine;
+c_fine = c_ini + 1;
+if (allinea_tab_mesi == 'SI') c_fine = c_fine - 1;
+if (sel_start_date) {
+res_color(n1,0);
+colora_date(c_ini1,c_fine,colore_date_norm);
+boxes[n1].onmouseover = new Function("colora_date("+c_ini+","+c_fine+",'"+colore_date_sel+"');");
+boxes[n1].onmouseout = new Function("colora_date("+c_ini+","+c_fine+",'"+colore_date_norm+"');");
+}
+else {
+boxes[n1].onmouseover = new Function("res_color("+n1+",1);colora_date("+c_ini1+","+c_fine+",'"+colore_date_sel+"');");
+boxes[n1].onmouseout = new Function("res_color("+n1+",0);colora_date("+c_ini1+","+c_fine+",'"+colore_date_norm+"');");
+}
+if (allinea_tab_mesi == 'SI') c_fine = c_fine + 1;
+if (curr_stop_date == n1) c_fine1 = c_fine;
+} // for n1
+if (sel_start_date) sel_start_date = 0;
+else {
+sel_start_date = n_col;
+sel_stop_date = (n1 - 1);
+}
+if (ins_res) {
+document.getElementById('ins_ini_per').value = ArDaCo[(c_ini1 + 1)];
+document.getElementById('ins_fin_per').value = ArDaCo[(c_fine1 + 1)];
+document.getElementById('ins_app').value = arr_app[row_id.substr(3)];
+document.getElementById('ins_pren').submit();
+}
+}
+
+
+
 function attiva_drag_drop () {
 var n0 = 0;
 var n1 = 0;
@@ -560,7 +651,10 @@ for (n3 = 0 ; n3 < prenota.length ; n3++) {
 if (prenota[n3].id.substr(0,3) == 'prn') {
 prenota[n3].draggable = true;
 if (prenota[n3].draggable) prenota[n3].style.cursor = 'move';
-prenota[n3].getElementsByTagName('a')[0].draggable = false;
+var link_elem = prenota[n3].getElementsByTagName('a')[0];
+link_elem.draggable = false;
+link_elem.onmouseover = new Function("prn_title_over('"+prenota[n3].id+"');");
+link_elem.onmouseout = new Function("prn_title_out('"+prenota[n3].id+"');");
 if (priv_mod_da == 's') {
 caselle_prn = prenota[n3].getElementsByTagName('td');
 caselle_prn[0].draggable = true;
@@ -573,6 +667,7 @@ ArInPr[prenota[n3].id.substr(3)] = c_ini;
 ArFiPr[prenota[n3].id.substr(3)] = c_fine;
 }
 } // for n3
+if (prenota.length == 0 && (caselle[n2].style.backgroundColor == 'null' || caselle[n2].style.backgroundColor == '' || caselle[n2].style.backgroundColor == null)) caselle[n2].onclick = new Function("reserve_sel_dates('"+righe[n1].id+"','"+n2+"');");
 if (allinea_tab_mesi == 'SI') c_fine = c_fine + 1;
 }
 } // if
@@ -972,3 +1067,24 @@ document.getElementById('lpren_contr').value = lpren_contr;
 } // function contr_da_tab_mese
 
 
+
+// modifica_prenota.php functions
+
+function apri_vis (bott_vis,div_vis,testo_vis) {
+var bott = document.getElementById(bott_vis);
+var cont_vis = document.getElementById(div_vis);
+var elem_vis = cont_vis.style.visibility;
+if (elem_vis != 'visible') {
+var testo = testo_vis;
+cont_vis.style.visibility = 'visible';
+bott.innerHTML = '<img style=\"display: block;\" src=\"./img/freccia_giu_marg.png\" alt=\"".mex("nascondi",$pag)." &gt;\">';
+}
+if (elem_vis == 'visible') {
+var testo = '';
+cont_vis.style.visibility = 'hidden';
+bott.innerHTML = '<img style=\"display: block;\" src=\"./img/freccia_destra_marg.png\" alt=\"".mex("mostra",$pag)." &gt;\">';
+}
+cont_vis.innerHTML = testo;
+return false;
+} // fine function apri_vis
+
