@@ -67,6 +67,7 @@ $azione = "SI";
 $upload_backup = "";
 $cancella_backup = "";
 $ripristina_backup = "";
+$lingua_mex = "ita";
 } # fine if ($id_utente == "b")
 
 
@@ -630,7 +631,7 @@ else {
 if (@is_file(C_DATI_PATH."/hoteld_doc_backup.php")) {
 if ($linee_backup = file(C_DATI_PATH."/hoteld_doc_backup.php")) {
 
-if (C_RESTRIZIONI_DEMO_ADMIN != "SI") ripristina_backup_contr($linee_backup,"NO",$pag,$PHPR_TAB_PRE,$modalita);
+if (C_RESTRIZIONI_DEMO_ADMIN != "SI") ripristina_backup_contr($linee_backup,"NO",$pag,$PHPR_TAB_PRE,$modalita,$contr_agg);
 
 } # fine if ($linee_backup = file(C_DATI_PATH."/hoteld_doc_backup.php"))
 else echo mex("Non ho potuto leggere il file",$pag).".<br>";
@@ -756,6 +757,8 @@ echo ".<br><table><tr><td style=\"width: 30px;\"></td><td>
 <label><input type=\"checkbox\" name=\"compresso\" value=\"SI\" checked> ".mex("Compresso",$pag)."</label>
 </td></tr></table></div></form><table><tr><td style=\"height: 4px;\"></td></tr></table>";
 if ($file_esistente == "SI") {
+$linee_backup = file(C_DATI_PATH."/hoteld_doc_backup.php");
+$info_contr = ripristina_backup_contr($linee_backup,"SI",$pag,$PHPR_TAB_PRE,"info");
 echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"./crea_backup.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
@@ -763,8 +766,25 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"./crea_backup.php\
 <input type=\"hidden\" name=\"azione\" value=\"SI\">
 <input class=\"sbutton\" type=\"submit\" name=\"ripristina_backup\" value=\"".mex("Ripristina i documenti dal file",$pag)."\"><br>
 <table><tr><td style=\"width: 30px;\"></td><td>
-<label><input type=\"radio\" name=\"modalita\" value=\"aggiungi\" checked>".mex("aggiungi ai documenti attuali",$pag)."</label><br>
-<label><input type=\"radio\" name=\"modalita\" value=\"rimpiazza\">".mex("rimpiazza i documenti attuali",$pag)."</label> (".mex("i documenti attuali verranno cancellati",$pag).")<br>";
+<label><input type=\"radio\" name=\"modalita\" value=\"aggiungi\" checked>".mex("aggiungi ai documenti attuali",$pag)."</label>";
+if ($info_contr['max_contr'] > 1) {
+echo " <select name=\"contr_agg\">
+<option value=\"\" selected>".mex("tutti i documenti contenuti nel file",$pag)."</option>";
+unset($nomi_contratti);
+$nomi_con = explode("#@&",$info_contr['nomi_con']);
+$num_nomi_con = count($nomi_con);
+for ($num1 = 0 ; $num1 < $num_nomi_con ; $num1++) {
+$nome_con = explode("#?&",$nomi_con[$num1]);
+$nomi_contratti[$nome_con[0]] = $nome_con[1];
+} # fine for $num1
+for ($num1 = 1 ; $num1 <= $info_contr['max_contr'] ; $num1++) {
+echo "<option value=\"$num1\">".mex("solo il documento",$pag)." $num1";
+if (strcmp($nomi_contratti[$num1],"")) echo " (".$nomi_contratti[$num1].")";
+echo "</option>";
+} # fine for $num1
+echo "</select>";
+} # fine if ($info_contr['max_contr'] > 1)
+echo "<br><label><input type=\"radio\" name=\"modalita\" value=\"rimpiazza\">".mex("rimpiazza i documenti attuali",$pag)."</label> (".mex("i documenti attuali verranno cancellati",$pag).")<br>";
 echo "</td></tr></table></div></form><table><tr><td style=\"height: 1px;\"></td></tr></table>";
 } # fine if ($file_esistente == "SI")
 } # fine if ($id_utente == 1)
