@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2011 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2012 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -242,7 +242,7 @@ return $idclienti;
 
 
 
-function mostra_dati_cliente ($dati_cliente,&$dcognome,&$dnome,&$dsoprannome,&$dtitolo_cli,&$dsesso,&$ddatanascita,&$ddatanascita_f,&$dnazionenascita,&$dcittanascita,&$dregionenascita,&$ddocumento,&$dscadenzadoc,&$dscadenzadoc_f,&$dtipodoc,&$dnazionedoc,&$dregionedoc,&$dcittadoc,&$dnazionalita,&$dlingua_cli,&$dnazione,&$dregione,&$dcitta,&$dvia,&$dnumcivico,&$dtelefono,&$dtelefono2,&$dtelefono3,&$dfax,&$dcap,&$demail,&$dcod_fiscale,&$dpartita_iva,$mostra_num="",$priv_ins_clienti="") {
+function mostra_dati_cliente ($dati_cliente,&$dcognome,&$dnome,&$dsoprannome,&$dtitolo_cli,&$dsesso,&$ddatanascita,&$ddatanascita_f,&$dnazionenascita,&$dcittanascita,&$dregionenascita,&$ddocumento,&$dscadenzadoc,&$dscadenzadoc_f,&$dtipodoc,&$dnazionedoc,&$dregionedoc,&$dcittadoc,&$dnazionalita,&$dlingua_cli,&$dnazione,&$dregione,&$dcitta,&$dvia,&$dnumcivico,&$dtelefono,&$dtelefono2,&$dtelefono3,&$dfax,&$dcap,&$demail,&$dcod_fiscale,&$dpartita_iva,$mostra_num="",$priv_ins_clienti="",$silenzio="") {
 global $pag,$id_utente,$PHPR_TAB_PRE;
 
 if ($id_utente == 1 or !$id_utente) {
@@ -307,26 +307,28 @@ $d_nome_lingua = ucfirst(togli_acapo($d_nome_lingua[0]));
 if (!$d_nome_lingua) $dlingua_cli = "";
 } # fine if ($dlingua_cli)
 
+$output = "";
+
 $O = "o"; $O2 = "o";
 if ($dsesso == "f") $O = "a";
 if ($dsesso2 == "f") $O2 = "a";
 if ($mostra_num == "SI") {
-echo "$didclienti. <em>$dcognome</em> ";
-if ($dnome) echo "<em>$dnome</em> ";
+$output .= "$didclienti. <em>$dcognome</em> ";
+if ($dnome) $output .= "<em>$dnome</em> ";
 } # fine if ($mostra_num == "SI")
 else {
-if ($dtitolo_cli) echo "$dtitolo_cli ";
-echo "<b>$dcognome</b>";
-if ($dnome) echo " $dnome";
-if ($dsoprannome) echo " ($dsoprannome)";
+if ($dtitolo_cli) $output .= "$dtitolo_cli ";
+$output .= "<b>$dcognome</b>";
+if ($dnome) $output .= " $dnome";
+if ($dsoprannome) $output .= " ($dsoprannome)";
 } # fine else if ($mostra_num == "SI")
-if ($ddatanascita or $dcittanascita) echo " ".mex("nat$O",$pag);
-if ($ddatanascita) echo " ".mex("il",$pag)." $ddatanascita_f";
-if ($dcittanascita) echo mex(" a",$pag)." $dcittanascita";
+if ($ddatanascita or $dcittanascita) $output .= " ".mex("nat$O",$pag);
+if ($ddatanascita) $output .= " ".mex("il",$pag)." $ddatanascita_f";
+if ($dcittanascita) $output .= mex(" a",$pag)." $dcittanascita";
 if ($dregionenascita or $dnazionenascita) {
-echo " ($dregionenascita";
-if ($dregionenascita and $dnazionenascita) echo ", ";
-echo "$dnazionenascita)";
+$output .= " ($dregionenascita";
+if ($dregionenascita and $dnazionenascita) $output .= ", ";
+$output .= "$dnazionenascita)";
 } # fine if ($dregionenascita or $dnazionenascita)
 
 $lin = "";
@@ -336,7 +338,7 @@ if ($d_nome_lingua) $lin .= "(".mex("ln.",$pag)." <em>$d_nome_lingua</em>)";
 if ($lin and $ddocumento) {
 if (!$dnazionedoc or $dnazionedoc == $dnazionalita) $lin .= " - ";
 else {
-echo "<br>$lin";
+$output .= "<br>$lin";
 $lin = "";
 } # fine else if (!$dnazionedoc or...
 } # fine if ($lin and $ddocumento)
@@ -354,7 +356,7 @@ if (date("Ymd",(time() + (C_DIFF_ORE * 3600))) <= str_replace("-","",$dscadenzad
 else $lin .= " ".mex("scade",$pag)." <font color=\"red\">$dscadenzadoc_f</font>";
 } # fine if ($dscadenzadoc)
 } # fine if ($ddocumento)
-if ($lin) echo "<br>$lin";
+if ($lin) $output .= "<br>$lin";
 
 $lin = "";
 if ($dcitta) {
@@ -370,7 +372,7 @@ if ($dregione) $lin .= $dregione;
 if ($dnazione and $dregione) $lin .= ", ";
 if ($dnazione) $lin .= $dnazione;
 if ($dnazione or $dregione) $lin .= ") ";
-if ($lin) echo "<br>$lin";
+if ($lin) $output .= "<br>$lin";
 
 $lin = "";
 if ($dtelefono) $lin .= mex("Telefono",$pag).": $dtelefono ";
@@ -378,13 +380,16 @@ if ($dtelefono2) $lin .= mex("2º telefono",$pag).": $dtelefono2 ";
 if ($dtelefono3) $lin .= mex("3º telefono",$pag).": $dtelefono3, ";
 if ($dfax) $lin .= "fax: $dfax, ";
 if ($demail) $lin .= "email: <a href=\"mailto:$demail\">$demail</a> ";
-if ($lin) echo "<br>$lin";
+if ($lin) $output .= "<br>$lin";
 
 $lin = "";
 if ($dcod_fiscale) $lin .= mex("Codice fiscale",$pag).": $dcod_fiscale ";
 if ($dcod_fiscale and $dpartita_iva) $lin .= ", ";
 if ($dpartita_iva) $lin .= mex("Partita iva",$pag).": $dpartita_iva ";
-if ($lin) echo "<br>$lin";
+if ($lin) $output .= "<br>$lin";
+
+if (!$silenzio) echo $output;
+else return $output;
 
 } # fine function mostra_dati_cliente
 
