@@ -499,6 +499,8 @@ $incomp_tariffe = risul_query($costi,$numca,'vartariffeincomp');
 $incomp_tariffe = explode(",",$incomp_tariffe);
 for ($num1 = 0 ; $num1 < count($incomp_tariffe) ; $num1++) $dati_cap[$numca]["incomp_tariffa".$incomp_tariffe[$num1]] = "i";
 $dati_cap[$numca]['idprenota'] = $id_prenota;
+$dati_cap[$numca]['datainserimento'] = risul_query($costi,$numca,'datainserimento');
+$dati_cap[$numca]['utente_inserimento'] = risul_query($costi,$numca,'utente_inserimento');
 } # fine for $numca
 
 return $dati_cap;
