@@ -622,7 +622,7 @@ $stato['inserita'] = "SI";
 
 } # fine if ($inserire != "NO")
 
-if ($stato['inserita'] != "SI") $stato['inserita'] = "NO";
+if (!@is_array($stato) or $stato['inserita'] != "SI") $stato['inserita'] = "NO";
 $stato['mess_errore'] = $mess_errore;
 $stato['mess_regola1'] = $mess_regola1;
 $stato['mess_prenota'] = $mess_prenota;
