@@ -255,8 +255,8 @@ if ($num_soldi_esistenti >= (C_MASSIMO_NUM_STORIA_SOLDI + 1)) $priv_mod_pagato =
 
 
 function prepara_modifiche_prenotazione ($id_prenota_idpr,$num_id_prenota,&$prenota_in_anno_succ,&$dati_da_anno_prec,&$tra_anni,$anno,$PHPR_TAB_PRE) {
-global $d_id_utente_inserimento_idpr,$d_id_clienti_idpr,$d_id_data_inizio_idpr,$d_id_data_fine_idpr,$d_appartamento_idpr,$d_assegnazione_app_idpr,$d_app_assegnabili_idpr,$d_nome_tipotariffa_idpr,$d_app_eliminati_costi_idpr,$d_sconto_idpr,$d_caparra_idpr,$d_met_paga_caparra_idpr,$d_commissioni_idpr,$d_num_persone_idpr,$d_nome_tariffa_idpr,$d_costo_tariffa_idpr,$d_molt_tariffa_idpr,$d_tariffesettimanali_idpr,$d_costo_agg_tot_idpr,$d_prezzo_costo_agg_idpr,$d_costo_tot_idpr,$d_pagato_idpr,$d_confermato_idpr,$d_checkin_idpr,$d_checkout_idpr,$d_prenota_comp_idpr,$n_host_inserimento_idpr;
-global $dati_tariffe,$dati_ca,$dati_prenota_modifica,$id_prenota_orig,$tableperiodi_orig,$tableprenota_orig,$tablecostiprenota_orig,$tableperiodi_prec,$tableprenota_prec,$tablecostiprenota_prec,$fineperiodo_orig,$stile_data,$d_data_inizio_f,$d_data_fine_f;
+global $d_id_utente_inserimento_idpr,$d_id_clienti_idpr,$d_id_data_inizio_idpr,$d_id_data_fine_idpr,$d_appartamento_idpr,$d_assegnazione_app_idpr,$d_app_assegnabili_idpr,$d_nome_tipotariffa_idpr,$d_app_eliminati_costi_idpr,$d_sconto_idpr,$d_caparra_idpr,$d_met_paga_caparra_idpr,$d_commissioni_idpr,$d_num_persone_idpr,$d_nome_tariffa_idpr,$d_costo_tariffa_idpr,$d_molt_tariffa_idpr,$d_tariffesettimanali_idpr,$d_costo_agg_tot_idpr,$d_prezzo_costo_agg_idpr,$d_costo_tot_idpr,$d_pagato_idpr,$d_confermato_idpr,$d_checkin_idpr,$d_checkout_idpr,$d_commento,$d_prenota_comp_idpr;
+global $dati_tariffe,$dati_ca,$dati_prenota_modifica,$id_prenota_orig,$tableperiodi_orig,$tableprenota_orig,$tablecostiprenota_orig,$tableperiodi_prec,$tableprenota_prec,$tablecostiprenota_prec,$fineperiodo_orig,$stile_data,$d_data_inizio_f,$d_data_fine_f,$n_host_inserimento_idpr;
 if (!function_exists('dati_tariffe')) include("./includes/funzioni_tariffe.php");
 if (!function_exists('dati_costi_agg_ntariffe')) include("./includes/funzioni_costi_agg.php");
 
@@ -477,9 +477,10 @@ $n_host_inserimento_idpr[$id_prenota] = risul_query($dati_prenota_modifica,0,'ho
 
 
 
-function esegui_modifiche_prenotazione (&$inserire,&$cancellata,$id_prenota_int,$id_prenota_idpr,$num_id_prenota,$id_transazione,$id_sessione,$anno,$id_nuovo_utente_inserimento,$n_stima_checkin,$n_met_paga_caparra,$n_origine_prenota,$n_pagato,$n_confermato,$n_commento,$n_cancella_commento,$tableprenota_da_aggiornare,$tipo_sposta,$dati_da_anno_prec,$prenota_in_anno_succ,$tra_anni,$PHPR_TAB_PRE) {
-global $id_utente,$priv_mod_checkin,$attiva_regole1_consentite,$regole1_consentite,$attiva_tariffe_consentite,$tariffe_consentite_vett,$priv_mod_date,$priv_ins_periodi_passati,$priv_mod_commento,$priv_mod_sconto,$priv_mod_caparra,$priv_mod_pagato,$priv_mod_orig_prenota,$cassa_pagamenti;
+function esegui_modifiche_prenotazione (&$inserire,&$cancellata,$id_prenota_int,$id_prenota_idpr,$num_id_prenota,$id_transazione,$id_sessione,$anno,$id_nuovo_utente_inserimento,$n_stima_checkin,$n_met_paga_caparra,$n_origine_prenota,$n_pagato,$n_confermato,$tipo_commento,$n_commento,$n_cancella_commento,$tableprenota_da_aggiornare,$tipo_sposta,$dati_da_anno_prec,$prenota_in_anno_succ,$tra_anni,$PHPR_TAB_PRE) {
+global $id_utente,$priv_mod_checkin,$attiva_regole1_consentite,$regole1_consentite,$attiva_tariffe_consentite,$tariffe_consentite_vett,$priv_mod_date,$priv_ins_periodi_passati,$priv_mod_commento,$priv_mod_sconto,$priv_mod_caparra,$priv_mod_pagato,$priv_mod_orig_prenota,$d_commento,$cassa_pagamenti;
 global $dati_ca,$d_id_utente_inserimento_idpr,$d_appartamento_idpr,$d_id_data_inizio_idpr,$d_nome_tariffa_idpr,$d_app_eliminati_costi_idpr,$d_checkin_idpr,$d_checkout_idpr,$d_prenota_comp_idpr,$fineperiodo_orig;
+global $id_prenota_orig,$tableperiodi_orig,$tableprenota_orig,$tablecostiprenota_orig,$tableperiodi_prec,$tableprenota_prec,$tablecostiprenota_prec,$stile_data;
 
 $pag = "modifica_prenota.php";
 $tablenometariffe = $PHPR_TAB_PRE."ntariffe".$anno;
@@ -1186,7 +1187,7 @@ $datainserimento = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 3600)));
 $idcostiprenota = esegui_query("select max(idcostiprenota) from $tablecostiprenota");
 $idcostiprenota = risul_query($idcostiprenota,0,0) + 1;
 if ($costo_agg_da_inserire[15]) $costo_agg_da_inserire[15] = $num_ripetizioni_costo_ins_idpr[$id_prenota][$num2].";".$costo_agg_da_inserire[15];
-esegui_query("insert into $tablecostiprenota (idcostiprenota,idprenota,tipo,nome,valore,associasett,settimane,moltiplica,letto,idntariffe,varmoltiplica,varnumsett,varperiodipermessi,vartariffeassociate,vartariffeincomp,varbeniinv,varappincompatibili,variazione,categoria,datainserimento,hostinserimento,utente_inserimento) values ('$idcostiprenota','$id_prenota','".$costo_agg_da_inserire[0]."','".aggslashdb($costo_agg_da_inserire[1])."','".$costo_agg_da_inserire[2]."','".$costo_agg_da_inserire[5]."','".$costo_agg_da_inserire[6]."','".$costo_agg_da_inserire[7]."','".$costo_agg_da_inserire[8]."','".$costo_agg_da_inserire[9]."','".$costo_agg_da_inserire[10]."','".$costo_agg_da_inserire[11]."','".$costo_agg_da_inserire[12]."','".$costo_agg_da_inserire[13]."','".$costo_agg_da_inserire[14]."','".$costo_agg_da_inserire[15]."','".$costo_agg_da_inserire[16]."','".$costo_agg_da_inserire[17]."','".$costo_agg_da_inserire[18]."','$datainserimento','$HOSTNAME','$id_utente_inserimento')");
+esegui_query("insert into $tablecostiprenota (idcostiprenota,idprenota,tipo,nome,valore,associasett,settimane,moltiplica,letto,idntariffe,varmoltiplica,varnumsett,varperiodipermessi,vartariffeassociate,vartariffeincomp,varbeniinv,varappincompatibili,variazione,categoria,datainserimento,hostinserimento,utente_inserimento) values ('$idcostiprenota','$id_prenota','".$costo_agg_da_inserire[0]."','".aggslashdb($costo_agg_da_inserire[1])."','".$costo_agg_da_inserire[2]."','".$costo_agg_da_inserire[5]."','".$costo_agg_da_inserire[6]."','".$costo_agg_da_inserire[7]."','".$costo_agg_da_inserire[8]."','".$costo_agg_da_inserire[9]."','".$costo_agg_da_inserire[10]."','".$costo_agg_da_inserire[11]."','".$costo_agg_da_inserire[12]."','".$costo_agg_da_inserire[13]."','".$costo_agg_da_inserire[14]."','".$costo_agg_da_inserire[15]."','".$costo_agg_da_inserire[16]."','".$costo_agg_da_inserire[17]."','".$costo_agg_da_inserire[18]."','$datainserimento','$HOSTNAME','$id_utente')");
 if (substr($costo_agg_da_inserire[0],1,1) != "f") esegui_query("update $tablecostiprenota set valore_perc = '".$costo_agg_da_inserire[3]."', arrotonda = '".$costo_agg_da_inserire[4]."' where idcostiprenota = '$idcostiprenota'");
 if ($dati_ca[$num_costo]['tasseperc']) esegui_query("update $tablecostiprenota set tasseperc = '".$dati_ca[$num_costo]['tasseperc']."' where idcostiprenota = '$idcostiprenota'");
 } # fine for $num2
@@ -1255,13 +1256,34 @@ if ($n_confermato != "") {
 esegui_query("update $tableprenota set conferma = '$n_confermato' where idprenota = '$id_prenota' ");
 } # fine if ($n_confermato != "")
 
-if ($n_commento != "") {
-esegui_query("update $tableprenota set commento = '".aggslashdb($n_commento)."' where idprenota = '$id_prenota' ");
-} # fine if ($n_commento != "")
+if ($n_commento != "" and ($tipo_commento == "checkin" or $tipo_commento == "checkout")) {
+$n_comm_checkin = "";
+$n_comm_checkout = "";
+if ($tipo_commento == "checkin" and !$d_checkin_idpr[$id_prenota]) $n_comm_checkin = $n_commento;
+if ($tipo_commento == "checkout" and !$d_checkout_idpr[$id_prenota]) $n_comm_checkout = $n_commento;
+$n_comm = $d_commento;
+if (strstr($n_comm,">")) {
+$n_comm = explode(">",$n_comm);
+if (strcmp($n_comm[1],"")) {
+if ($n_comm_checkin) $n_comm_checkin = $n_comm[1]." - $n_comm_checkin";
+else $n_comm_checkin = $n_comm[1];
+} # fine if (strcmp($n_comm[1],""))
+if (strcmp($n_comm[2],"")) {
+if ($n_comm_checkout) $n_comm_checkout = $n_comm[2]." - $n_comm_checkout";
+else $n_comm_checkout = $n_comm[2];
+} # fine if (strcmp($n_comm[2],""))
+$n_comm = $n_comm[0];
+} # fine if (strstr($n_comm,">"))
+if (strcmp($n_comm_checkin,"") or strcmp($n_comm_checkout,"")) $n_comm .= ">$n_comm_checkin>$n_comm_checkout";
+esegui_query("update $tableprenota set commento = '".aggslashdb($n_comm)."' where idprenota = '$id_prenota' ");
+} # fine if ($n_commento != "" and ($tipo_commento == "checkin" or...
 
-if ($n_cancella_commento == "SI") {
-esegui_query("update $tableprenota set commento = '' where idprenota = '$id_prenota' ");
-} # fine if ($n_cancella_commento == "SI")
+if (($n_commento != "" and $tipo_commento != "checkin" and $tipo_commento != "checkout") or $n_cancella_commento == "SI") {
+$n_comm = $n_commento;
+if ($n_cancella_commento == "SI") $n_comm = "";
+if (strstr($d_commento,">")) $n_comm = $n_comm.strstr($d_commento,">");
+esegui_query("update $tableprenota set commento = '".aggslashdb($n_comm)."' where idprenota = '$id_prenota' ");
+} # fine if (($n_commento != "" and $tipo_commento != "checkin" and $tipo_commento != "checkout") or...
 
 $adesso = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 3600)));
 esegui_query("update $tableprenota set tariffa_tot = '$n_costo_tot', data_modifica = '$adesso' where idprenota = '$id_prenota' ");
