@@ -79,6 +79,8 @@ case "Includi tutti gli anni":  		$messaggio = "Include all years"; break;
 case "Includi solo gli anni selezionati":  	$messaggio = "Include only selected years"; break;
 case "Prova a mantenere i dati degli anni non contenuti nel backup":	$messaggio = "Try to retain data of years not contained in the backup"; break;
 case "alcuni dati di questi anni potrebbero comunque venir persi":	$messaggio = "some data of these years may be lost anyway"; break;
+case "tutti i documenti contenuti nel file":	$messaggio = "all the documents contained in file"; break;
+case "solo il documento":  			$messaggio = "only document"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
