@@ -195,7 +195,7 @@ case "SI":  					$messaggio = "YES"; break;
 case "Costo aggiuntivo già esistente":  	$messaggio = "Extra cost already inserted"; break;
 case "Tariffe incompatibili con il costo":  	$messaggio = "Rates that are incompatible with the cost"; break;
 case "Tariffe incompatibili":  			$messaggio = "Incompatible rates"; break;
-case "Importa i prezzi della":  		$messaggio = "Import the prices to"; break;
+case "i prezzi della":  			$messaggio = "the prices to"; break;
 case "dalla":  					$messaggio = "from"; break;
 case "aggiungendo":  				$messaggio = "adding"; break;
 case "I prezzi della tariffa selezionata sono stati importati":	$messaggio = "The prices of the selected rate have been imported"; break;
@@ -234,7 +234,7 @@ case "Le commissioni normali sulla":  		$messaggio = "The normal commissions on"
 case "sono":  					$messaggio = "are"; break;
 case "Inserisci o modifica le commissioni":  	$messaggio = "Insert or modify commissions"; break;
 case "Tasse":  					$messaggio = "Taxes"; break;
-case "Tasse applicate sulla":  			$messaggio = "Taxes applied on"; break;
+case "Tasse applicate su":  			$messaggio = "Taxes applied on"; break;
 case "della tariffa":  				$messaggio = "of the rate"; break;
 case "Inserisci o modifica le tasse":  		$messaggio = "Insert or modify taxes"; break;
 case "Le commissioni sono state modificate":  	$messaggio = "Commissions have been modified"; break;
@@ -292,6 +292,16 @@ case "Se la prenotazione ha una durata di":	$messaggio = "If the reservation len
 case "o più giorni":  				$messaggio = "days or more"; break;
 case "Se":  					$messaggio = "If"; break;
 case "Se si inseriscono":  			$messaggio = "If"; break;
+case "Importa ora":  				$messaggio = "Import now"; break;
+case "Importa sempre":  			$messaggio = "Always import"; break;
+case "cancella":  				$messaggio = "delete"; break;
+case "L'importatazione dei prezzi è stata cancellata":	$messaggio = "The prices import has been deleted"; break;
+case "al prezzo fisso":  			$messaggio = "to fixed price"; break;
+case "al prezzo per persona":  			$messaggio = "to per person price"; break;
+case "ad entrambi i prezzi":  			$messaggio = "to both prices"; break;
+case "La tariffa":  				$messaggio = "The rate"; break;
+case "esporta i prezzi ad altre tariffe, non può importare i prezzi in modo permanente":	$messaggio = "exports its prices to other rates, it can't import prices permanently"; break;
+case "tutte le tariffe":  			$messaggio = "all rates"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
