@@ -1,24 +1,24 @@
 <?php exit(); ?>
 
-<!--             2011-06-11 17:48:27             -->
+<!--             2013-03-06 12:39:21             -->
 
-<!--  **    SAVE THIS FILE AS phpres_doc_backup.php     **  -->
+<!--  **    SAVE THIS FILE AS hoteld_doc_backup.php     **  -->
 
-<!--  **  SALVA QUESTO FILE COME phpres_doc_backup.php  **  -->
+<!--  **  SALVA QUESTO FILE COME hoteld_doc_backup.php  **  -->
 
 
 <backup>
-<versione>2.00</versione>
+<versione>2.03</versione>
 <database>
 <tabella>
 <nometabella>contratti</nometabella>
 <colonnetabella>
 <nomecolonna>numero</nomecolonna>
-<tipocolonna>int</tipocolonna>
+<tipocolonna>int4</tipocolonna>
 <nomecolonna>tipo</nomecolonna>
-<tipocolonna>string</tipocolonna>
+<tipocolonna>varchar</tipocolonna>
 <nomecolonna>testo</nomecolonna>
-<tipocolonna>blob</tipocolonna>
+<tipocolonna>text</tipocolonna>
 </colonnetabella>
 <righetabella>
 <riga><cmp>1</cmp><cmp>vett2</cmp><cmp>vat_perc_arr_invo;vat_num_invo</cmp></riga>
@@ -33,6 +33,7 @@
 <riga><cmp>75</cmp><cmp>var4</cmp><cmp>surname_recei</cmp></riga>
 <riga><cmp>76</cmp><cmp>var4</cmp><cmp>struct_telephone_recei</cmp></riga>
 <riga><cmp>98</cmp><cmp>var4</cmp><cmp>street_num_recei</cmp></riga>
+<riga><cmp>421</cmp><cmp>var4</cmp><cmp>show_method_recei</cmp></riga>
 <riga><cmp>325</cmp><cmp>var2</cmp><cmp>city_row_invo</cmp></riga>
 <riga><cmp>326</cmp><cmp>var2</cmp><cmp>nation_row_invo</cmp></riga>
 <riga><cmp>330</cmp><cmp>var2</cmp><cmp>struct_fisc_code_invo</cmp></riga>
@@ -67,6 +68,11 @@
 <riga><cmp>417</cmp><cmp>var2</cmp><cmp>max_vat_num_invo</cmp></riga>
 <riga><cmp>418</cmp><cmp>var2</cmp><cmp>people_phrase_invo</cmp></riga>
 <riga><cmp>419</cmp><cmp>var2</cmp><cmp>merge_discount_with_rate</cmp></riga>
+<riga><cmp>420</cmp><cmp>var2</cmp><cmp>logo_invo</cmp></riga>
+<riga><cmp>422</cmp><cmp>var2</cmp><cmp>tax_cost_name_invo</cmp></riga>
+<riga><cmp>423</cmp><cmp>var2</cmp><cmp>show_tax_cost_invo</cmp></riga>
+<riga><cmp>424</cmp><cmp>var2</cmp><cmp>vat_invo</cmp></riga>
+<riga><cmp>425</cmp><cmp>var2</cmp><cmp>tot_costs_tax_invo</cmp></riga>
 <riga><cmp>1</cmp><cmp>var</cmp><cmp>Mr</cmp></riga>
 <riga><cmp>3</cmp><cmp>var</cmp><cmp>il</cmp></riga>
 <riga><cmp>4</cmp><cmp>var</cmp><cmp>Il_</cmp></riga>
@@ -78,6 +84,8 @@
 <riga><cmp>15</cmp><cmp>var</cmp><cmp>al3</cmp></riga>
 <riga><cmp>16</cmp><cmp>var</cmp><cmp>a</cmp></riga>
 <riga><cmp>17</cmp><cmp>var</cmp><cmp>o3</cmp></riga>
+<riga><cmp>5</cmp><cmp>opzeml</cmp><cmp>;;</cmp></riga>
+<riga><cmp>6</cmp><cmp>opzeml</cmp><cmp>;SI;</cmp></riga>
 <riga><cmp>5</cmp><cmp>oggetto</cmp><cmp>Availability</cmp></riga>
 <riga><cmp>6</cmp><cmp>oggetto</cmp><cmp>Reservation confirmation</cmp></riga>
 <riga><cmp>1</cmp><cmp>nomi_con</cmp><cmp>1#?&Example#@&2#?&Invoice#@&3#?&Invoice - html#@&4#?&Last payment receipt#@&5#?&Availability email#@&6#?&Confirm reservation email</cmp></riga>
@@ -276,6 +284,11 @@ Best regards,
 \cell\row\pard \trowd\trql\trleft276\trpaddft3\trpaddt55\trpaddfl3\trpaddl55\trpaddfb3\trpaddb55\trpaddfr3\trpaddr55\clbrdrl\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clcbpat2\cellx7792\clbrdrl\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clbrdrr\brdrs\brdrw1\brdrcf1\clcbpat2\clvertalb\cellx9637
 \pard\intbl\pard\plain \intbl\ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\ql\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f1\fs24\lang1040\i0\b0 Taxes[c vat_num_invo="1"] at [vat_perc_arr_invo(vat_num_invo)]%[/c] total}
 \cell\pard\plain \intbl\ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\qr\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f1\fs24\lang1040\i0\b0 [currency_name] [vat_invo_p]}
+[r][r3][c show_tax_cost_invo="1"]
+\cell\row\pard \trowd\trql\trleft276\trpaddft3\trpaddt55\trpaddfl3\trpaddl55\trpaddfb3\trpaddb55\trpaddfr3\trpaddr55\clbrdrl\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clcbpat2\cellx7792\clbrdrl\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clbrdrr\brdrs\brdrw1\brdrcf1\clcbpat2\clvertalb\cellx9637
+\pard\intbl\pard\plain \intbl\ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\ql\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f1\fs24\lang1040\i0\b0 [extra_cost_name]}
+\cell\pard\plain \intbl\ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\qr\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f1\fs24\lang1040\i0\b0 [currency_name] [extra_cost_no_vat_invo_p]}
+[/c][/r3][/r]
 \cell\row\pard \trowd\trql\trleft276\trrh-119\trpaddft3\trpaddt55\trpaddfl3\trpaddl55\trpaddfb3\trpaddb55\trpaddfr3\trpaddr55\clbrdrt\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clcbpat3\cellx7792\clbrdrt\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clcbpat3\clvertalb\cellx9637
 \pard\intbl\pard\plain \intbl\ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\ql\rtlch\af1\afs12\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs12\lang1040\loch\f1\fs12\lang1040 
 \cell\pard\plain \intbl\ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\qr\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 
@@ -365,7 +378,7 @@ Best regards,
 \par \pard\plain \ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f6\fs24\lang1040\i0\b0 VAT number [structure_vat_number] [struct_fisc_code_recei]}
 \par \pard\plain \ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\ql\rtlch\af6\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f6\fs24\lang1040\loch\f6\fs24\lang1040 {\rtlch \ltrch\loch\f6\fs24\lang1040\i0\b0 [struct_telephone_recei]}
 \par \pard\plain \ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\ql\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 
-\par \pard\plain \ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\li5370\ri0\lin5370\rin0\fi0\ql\rtlch\af6\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f6\fs24\lang1040\loch\f6\fs24\lang1040 {\rtlch \ltrch\loch\f6\fs24\lang1040\i0\b0 Receipt for [first_name_recei] [surname_recei] }
+\par \pard\plain \ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\li5370\ri0\lin5370\rin0\fi0\ql\rtlch\af6\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f6\fs24\lang1040\loch\f6\fs24\lang1040 {\rtlch \ltrch\loch\f6\fs24\lang1040\i0\b0 [c surname_recei!=""]Receipt for [first_name_recei] [surname_recei][/c] }
 [c street!=""]\par \pard\plain \ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f6\fs24\lang1040\i0\b0 \tab \tab \tab \tab \tab \tab \tab \tab [street][street_num_recei]}
 [/c][c city_row_recei!=""]\par \pard\plain \ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f6\fs24\lang1040\i0\b0 \tab \tab \tab \tab \tab \tab \tab \tab [city_row_recei]}
 [/c][c nation_row_recei!=""]\par \pard\plain \ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f6\fs24\lang1040\i0\b0 \tab \tab \tab \tab \tab \tab \tab \tab [nation_row_recei]}
@@ -381,8 +394,8 @@ Best regards,
 \pard\intbl\pard\plain \intbl\ltrpar\s1\cf0\cbpat3\ql\rtlch\afs12\lang255\ltrch\dbch\langfe255\hich\fs12\lang1040\loch\fs12\lang1040 
 \cell\pard\plain \intbl\ltrpar\s1\cf0\ql\rtlch\afs24\lang255\ltrch\dbch\langfe255\hich\fs24\lang1040\loch\fs24\lang1040 
 \cell\row\pard \trowd\trql\trleft276\trpaddft3\trpaddt55\trpaddfl3\trpaddl55\trpaddfb3\trpaddb55\trpaddfr3\trpaddr55\clbrdrl\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clcbpat2\cellx7792\clbrdrl\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clbrdrr\brdrs\brdrw1\brdrcf1\clcbpat2\clvertalb\cellx9637
-\pard\intbl\pard\plain \intbl\ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\ql\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f1\fs24\lang1040\i0\b0 Stay from [starting_date] al [ending_date][c people_num_tot!=""] for [people_num_tot] persons[/c]}
-\cell\pard\plain \intbl\ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\qr\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f1\fs24\lang1040\i0\b0 }
+\pard\intbl\pard\plain \intbl\ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\ql\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f1\fs24\lang1040\i0\b0 [c starting_date!=""]Stay from [starting_date] al [ending_date][/c][c people_num_tot!=""] for [people_num_tot] persons[/c][c starting_date=""][last_payment_method][/c]}
+\cell\pard\plain \intbl\ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\qr\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f1\fs24\lang1040\i0\b0 [c show_method_recei="1"][currency_name] [last_payment_value_p][/c]}
 \cell\row\pard \trowd\trql\trleft276\trrh-119\trpaddft3\trpaddt55\trpaddfl3\trpaddl55\trpaddfb3\trpaddb55\trpaddfr3\trpaddr55\clbrdrt\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clcbpat3\cellx7792\clbrdrt\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clcbpat3\clvertalb\cellx9637
 \pard\intbl\pard\plain \intbl\ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\ql\rtlch\af1\afs12\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs12\lang1040\loch\f1\fs12\lang1040 
 \cell\pard\plain \intbl\ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\qr\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 
@@ -420,6 +433,7 @@ __________&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbs
 [r][r3][/r3] [/r]
 
 <div class="structure_data">
+[logo_invo]
 <div class="structure_name" style="font-size: large;">[structure_type] [structure_name]</div>
 [structure_company_name]<br>
 [structure_address] - [structure_city]<br>
@@ -469,6 +483,10 @@ Invoice n. [document_progressive_number] released on [today]
 <td style="width: 120px; text-align: right; border-color: black;">[currency_name] [tot_no_vat_invo_p]</td></tr>
 <tr><td style="border-color: black;">Taxes[c vat_num_invo="1"] at [vat_perc_arr_invo(vat_num_invo)]%[/c] total</td>
 <td style="width: 120px; text-align: right; border-color: black;">[currency_name] [vat_invo_p]</td></tr>
+[r][r3][c show_tax_cost_invo="1"]
+<tr><td style="border-color: black;">[extra_cost_name]</td>
+<td style="width: 120px; text-align: right; border-color: black;">[currency_name] [extra_cost_no_vat_invo_p]</td></tr>
+[/c][/r3][/r]
 </table>
 
 <table class="invoice_total" border="1" cellpadding="5" style="border: 1px black solid; width: 740px; margin-left: auto; margin-right: 5px; margin-top: 8px; border-collapse: collapse; background-color: #cccccc;">
@@ -513,88 +531,103 @@ Invoice n. [document_progressive_number] released on [today]
 <riga><cmp>111</cmp><cmp>cond4</cmp><cmp>rpt#@?#$?cap#%?!=#%?txt#%?#@?set#%?69#%?.=#%?var#%?cap#%?txt#%?#%?txt#%?</cmp></riga>
 <riga><cmp>112</cmp><cmp>cond4</cmp><cmp>rpt#@?and#$?cap#%?!=#%?txt#%?#$?nazione#%?!=#%?txt#%?#@?set#%?69#%?.=#%?txt#%? #%?txt#%?#%?txt#%?</cmp></riga>
 <riga><cmp>113</cmp><cmp>cond4</cmp><cmp>rpt#@?#$?nazione#%?!=#%?txt#%?#@?set#%?69#%?.=#%?var#%?nazione#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>114</cmp><cmp>cond4</cmp><cmp>rpt#@?#@?set#%?421#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>115</cmp><cmp>cond4</cmp><cmp>rpt#@?and#$?data_inizio#%?=#%?txt#%?#$?metodo_ultimo_pagamento#%?!=#%?txt#%?#@?set#%?421#%?=#%?txt#%?1#%?txt#%?#%?txt#%?</cmp></riga>
 <riga><cmp>25</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?409#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
 <riga><cmp>26</cmp><cmp>cond2</cmp><cmp>rpt#@?and#$?vat_perc_arr_invo(vat_num_invo)#%?=#%?var#%?percentuale_tasse_tariffa#$?repetition_num_invo#%?>#%?txt#%?1#@?set#%?409#%?=#%?txt#%?1#%?txt#%?#%?txt#%?</cmp></riga>
 <riga><cmp>27</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?410#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
 <riga><cmp>30</cmp><cmp>cond2</cmp><cmp>rpt#@?and#$?show_rate_invo#%?=#%?txt#%?1#$?sconto#%?!=#%?txt#%?0#@?set#%?410#%?=#%?txt#%?1#%?txt#%?#%?txt#%?</cmp></riga>
 <riga><cmp>31</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?411#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>32</cmp><cmp>cond2</cmp><cmp>rpt#@?and#$?vat_perc_arr_invo(vat_num_invo)#%?=#%?var#%?percentuale_tasse_costo_agg#$?valore_costo_agg#%?!=#%?txt#%?0#$?repetition_num_invo#%?>#%?txt#%?1#@?set#%?411#%?=#%?txt#%?1#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>36</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?336#%?=#%?var#%?percentuale_tasse_tariffa#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>38</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?tmp_var_invo#%?=#%?txt#%?#@?set#%?336#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>39</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?exist_perc_vat_invo(tmp_var_invo)#%?=#%?txt#%?1#@?break#%?cont</cmp></riga>
-<riga><cmp>40</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?408#%?vat_num_invo#%?+#%?txt#%?1#%?</cmp></riga>
-<riga><cmp>42</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?417#%?=#%?var#%?vat_num_invo#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>43</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?a1#%?=#%?var#%?tmp_var_invo#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>44</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?a2#%?=#%?txt#%?1#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>46</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?cont</cmp></riga>
-<riga><cmp>48</cmp><cmp>cond2</cmp><cmp>rpt#@?or#$?valore_costo_agg#%?=#%?txt#%?0#$?valore_costo_agg#%?=#%?txt#%?#@?break#%?cont</cmp></riga>
-<riga><cmp>52</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?336#%?=#%?var#%?percentuale_tasse_costo_agg#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>60</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?tmp_var_invo#%?=#%?txt#%?#@?set#%?336#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>61</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?exist_perc_vat_invo(tmp_var_invo)#%?=#%?txt#%?1#@?break#%?cont</cmp></riga>
-<riga><cmp>65</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?408#%?vat_num_invo#%?+#%?txt#%?1#%?</cmp></riga>
-<riga><cmp>75</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?417#%?=#%?var#%?vat_num_invo#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>76</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?a1#%?=#%?var#%?tmp_var_invo#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>81</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?a2#%?=#%?txt#%?1#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>83</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?cont</cmp></riga>
-<riga><cmp>84</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?351#%?valore_costo_agg_senza_tasse#%?+#%?txt#%?0#%?</cmp></riga>
-<riga><cmp>86</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?342#%?=#%?var#%?nome_costo_agg#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>87</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?show_extra_cost_invo#%?=#%?txt#%?1#@?oper#%?343#%?tot_no_vat_invo#%?+#%?var#%?valore_costo_agg_senza_tasse#%?</cmp></riga>
-<riga><cmp>88</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?show_extra_cost_invo#%?=#%?txt#%?1#@?oper#%?413#%?part_tot_no_vat_invo#%?+#%?var#%?valore_costo_agg_senza_tasse#%?</cmp></riga>
-<riga><cmp>89</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?show_extra_cost_invo#%?=#%?txt#%?1#@?oper#%?414#%?part_tot_vat_invo#%?+#%?var#%?tasse_costo_agg#%?</cmp></riga>
-<riga><cmp>90</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?350#%?tot_no_vat_invo#%?+#%?txt#%?0#%?</cmp></riga>
-<riga><cmp>91</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?415#%?part_tot_no_vat_invo#%?+#%?txt#%?0#%?</cmp></riga>
-<riga><cmp>95</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?416#%?part_tot_vat_invo#%?+#%?txt#%?0#%?</cmp></riga>
-<riga><cmp>100</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?349#%?price_tot_invo#%?-#%?var#%?tot_no_vat_invo#%?</cmp></riga>
-<riga><cmp>103</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?last_reserv_invo#%?=#%?var#%?numero_prenotazione#@?break#%?</cmp></riga>
-<riga><cmp>105</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?339#%?=#%?var#%?numero_prenotazione#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>106</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?show_rate_invo#%?=#%?txt#%?1#@?oper#%?343#%?tot_no_vat_invo#%?+#%?var#%?costo_tariffa_senza_tasse#%?</cmp></riga>
-<riga><cmp>108</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?show_rate_invo#%?=#%?txt#%?1#@?oper#%?413#%?part_tot_no_vat_invo#%?+#%?var#%?costo_tariffa_senza_tasse#%?</cmp></riga>
-<riga><cmp>110</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?show_rate_invo#%?=#%?txt#%?1#@?oper#%?414#%?part_tot_vat_invo#%?+#%?var#%?tasse_tariffa#%?</cmp></riga>
-<riga><cmp>111</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?show_discount_invo#%?=#%?txt#%?1#@?oper#%?343#%?tot_no_vat_invo#%?-#%?var#%?sconto_senza_tasse#%?</cmp></riga>
-<riga><cmp>112</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?show_discount_invo#%?=#%?txt#%?1#@?oper#%?413#%?part_tot_no_vat_invo#%?-#%?var#%?sconto_senza_tasse#%?</cmp></riga>
-<riga><cmp>113</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?show_discount_invo#%?=#%?txt#%?1#@?oper#%?414#%?part_tot_vat_invo#%?-#%?var#%?tasse_sconto#%?</cmp></riga>
-<riga><cmp>114</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?353#%?costo_tariffa_senza_tasse#%?+#%?txt#%?0#%?</cmp></riga>
-<riga><cmp>115</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?352#%?sconto_senza_tasse#%?*#%?txt#%?-1#%?</cmp></riga>
-<riga><cmp>116</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?350#%?tot_no_vat_invo#%?+#%?txt#%?0#%?</cmp></riga>
-<riga><cmp>117</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?415#%?part_tot_no_vat_invo#%?+#%?txt#%?0#%?</cmp></riga>
-<riga><cmp>118</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?416#%?part_tot_vat_invo#%?+#%?txt#%?0#%?</cmp></riga>
-<riga><cmp>119</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?349#%?price_tot_invo#%?-#%?var#%?tot_no_vat_invo#%?</cmp></riga>
-<riga><cmp>120</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?merge_discount_with_rate#%?=#%?txt#%?YES#@?oper#%?353#%?costo_tariffa_senza_tasse#%?-#%?var#%?sconto_senza_tasse#%?</cmp></riga>
-<riga><cmp>121</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?merge_discount_with_rate#%?=#%?txt#%?YES#@?set#%?410#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>122</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?418#%?=#%?txt#%?#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>123</cmp><cmp>cond2</cmp><cmp>rpt#@?and#$?num_persone_tot#%?!=#%?txt#%?#$?num_persone_tot#%?!=#%?txt#%?0#@?set#%?418#%?=#%?txt#%? for x persons#%?txt#%?x#%?var#%?num_persone_tot</cmp></riga>
-<riga><cmp>124</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?repetition_num_invo#%?>#%?txt#%?1#@?break#%?</cmp></riga>
-<riga><cmp>125</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?347#%?price_tot_invo#%?+#%?var#%?costo_tot#%?</cmp></riga>
-<riga><cmp>126</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?348#%?price_tot_invo#%?+#%?txt#%?0#%?</cmp></riga>
-<riga><cmp>128</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?codice_fiscale_struttura#%?!=#%?txt#%?#@?set#%?330#%?=#%?txt#%?- Codice Fiscale  #%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>129</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?codice_fiscale_struttura#%?!=#%?txt#%?#@?set#%?330#%?.=#%?var#%?codice_fiscale_struttura#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>130</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?telefono_struttura#%?!=#%?txt#%?#@?set#%?333#%?=#%?txt#%?Tel. #%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>131</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?telefono_struttura#%?!=#%?txt#%?#@?set#%?333#%?.=#%?var#%?telefono_struttura#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>132</cmp><cmp>cond2</cmp><cmp>inr#@?#@?set#%?339#%?=#%?txt#%?#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>133</cmp><cmp>cond2</cmp><cmp>inr#@?#@?oper#%?412#%?repetition_num_invo#%?+#%?txt#%?1#%?</cmp></riga>
-<riga><cmp>134</cmp><cmp>cond2</cmp><cmp>ind#@?#@?set#%?419#%?=#%?txt#%?YES#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>135</cmp><cmp>cond2</cmp><cmp>ind#@?#@?set#%?347#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>136</cmp><cmp>cond2</cmp><cmp>rpt#@?and#$?telefono_struttura#%?!=#%?txt#%?#$?sito_web_struttura#%?!=#%?txt#%?#@?set#%?333#%?.=#%?txt#%? - #%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>137</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?sito_web_struttura#%?!=#%?txt#%?#@?set#%?333#%?.=#%?var#%?sito_web_struttura#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>138</cmp><cmp>cond2</cmp><cmp>ind#@?#@?set#%?343#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>139</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?331#%?=#%?var#%?nome#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>140</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?332#%?=#%?var#%?cognome#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>141</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?numcivico#%?!=#%?txt#%?#@?set#%?355#%?=#%?txt#%?, #%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>142</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?numcivico#%?!=#%?txt#%?#@?set#%?355#%?.=#%?var#%?numcivico#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>143</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?citta#%?!=#%?txt#%?#@?set#%?325#%?.=#%?var#%?citta#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>144</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?regione#%?!=#%?txt#%?#@?set#%?325#%?.=#%?txt#%? (#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>145</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?regione#%?!=#%?txt#%?#@?set#%?325#%?.=#%?var#%?regione#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>146</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?regione#%?!=#%?txt#%?#@?set#%?325#%?.=#%?txt#%?)#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>147</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?cap#%?!=#%?txt#%?#@?set#%?326#%?.=#%?var#%?cap#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>148</cmp><cmp>cond2</cmp><cmp>rpt#@?and#$?cap#%?!=#%?txt#%?#$?nazione#%?!=#%?txt#%?#@?set#%?326#%?.=#%?txt#%? #%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>149</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?nazione#%?!=#%?txt#%?#@?set#%?326#%?.=#%?var#%?nazione#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>150</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?405#%?=#%?var#%?codice_fiscale#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>151</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?406#%?=#%?var#%?partita_iva#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>152</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?407#%?=#%?var#%?via#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>153</cmp><cmp>cond2</cmp><cmp>ind#@?#@?set#%?408#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>154</cmp><cmp>cond2</cmp><cmp>ind#@?#@?set#%?412#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>155</cmp><cmp>cond2</cmp><cmp>inr#@?#@?set#%?413#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>156</cmp><cmp>cond2</cmp><cmp>inr#@?#@?set#%?414#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>32</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?423#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>36</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?nome_costo_agg#%?=#%?var#%?tax_cost_name_invo#@?set#%?423#%?=#%?txt#%?1#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>38</cmp><cmp>cond2</cmp><cmp>rpt#@?and#$?vat_perc_arr_invo(vat_num_invo)#%?=#%?var#%?percentuale_tasse_costo_agg#$?valore_costo_agg#%?!=#%?txt#%?0#$?repetition_num_invo#%?>#%?txt#%?1#$?show_tax_cost_invo#%?!=#%?txt#%?1#@?set#%?411#%?=#%?txt#%?1#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>39</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?336#%?=#%?var#%?percentuale_tasse_tariffa#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>40</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?tmp_var_invo#%?=#%?txt#%?#@?set#%?336#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>42</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?exist_perc_vat_invo(tmp_var_invo)#%?=#%?txt#%?1#@?break#%?cont</cmp></riga>
+<riga><cmp>43</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?408#%?vat_num_invo#%?+#%?txt#%?1#%?</cmp></riga>
+<riga><cmp>44</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?417#%?=#%?var#%?vat_num_invo#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>46</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?a1#%?=#%?var#%?tmp_var_invo#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>48</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?a2#%?=#%?txt#%?1#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>52</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?cont</cmp></riga>
+<riga><cmp>60</cmp><cmp>cond2</cmp><cmp>rpt#@?or#$?valore_costo_agg#%?=#%?txt#%?0#$?valore_costo_agg#%?=#%?txt#%?#$?show_tax_cost_invo#%?=#%?txt#%?1#@?break#%?cont</cmp></riga>
+<riga><cmp>61</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?336#%?=#%?var#%?percentuale_tasse_costo_agg#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>65</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?tmp_var_invo#%?=#%?txt#%?#@?set#%?336#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>75</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?exist_perc_vat_invo(tmp_var_invo)#%?=#%?txt#%?1#@?break#%?cont</cmp></riga>
+<riga><cmp>76</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?408#%?vat_num_invo#%?+#%?txt#%?1#%?</cmp></riga>
+<riga><cmp>81</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?417#%?=#%?var#%?vat_num_invo#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>83</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?a1#%?=#%?var#%?tmp_var_invo#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>84</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?a2#%?=#%?txt#%?1#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>86</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?cont</cmp></riga>
+<riga><cmp>87</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?351#%?valore_costo_agg_senza_tasse#%?+#%?txt#%?0#%?</cmp></riga>
+<riga><cmp>88</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?show_tax_cost_invo#%?=#%?txt#%?1#@?oper#%?351#%?valore_costo_agg#%?+#%?txt#%?0#%?</cmp></riga>
+<riga><cmp>89</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?342#%?=#%?var#%?nome_costo_agg#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>90</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?show_extra_cost_invo#%?=#%?txt#%?1#@?oper#%?343#%?tot_no_vat_invo#%?+#%?var#%?valore_costo_agg_senza_tasse#%?</cmp></riga>
+<riga><cmp>91</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?show_extra_cost_invo#%?=#%?txt#%?1#@?oper#%?413#%?part_tot_no_vat_invo#%?+#%?var#%?valore_costo_agg_senza_tasse#%?</cmp></riga>
+<riga><cmp>95</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?show_extra_cost_invo#%?=#%?txt#%?1#@?oper#%?414#%?part_tot_vat_invo#%?+#%?var#%?tasse_costo_agg#%?</cmp></riga>
+<riga><cmp>100</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?show_tax_cost_invo#%?=#%?txt#%?1#@?oper#%?425#%?tot_costs_tax_invo#%?+#%?var#%?valore_costo_agg#%?</cmp></riga>
+<riga><cmp>103</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?350#%?tot_no_vat_invo#%?+#%?txt#%?0#%?</cmp></riga>
+<riga><cmp>105</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?415#%?part_tot_no_vat_invo#%?+#%?txt#%?0#%?</cmp></riga>
+<riga><cmp>106</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?416#%?part_tot_vat_invo#%?+#%?txt#%?0#%?</cmp></riga>
+<riga><cmp>108</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?424#%?price_tot_invo#%?-#%?var#%?tot_no_vat_invo#%?</cmp></riga>
+<riga><cmp>110</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?424#%?vat_invo#%?-#%?var#%?tot_costs_tax_invo#%?</cmp></riga>
+<riga><cmp>111</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?349#%?vat_invo#%?+#%?txt#%?0#%?</cmp></riga>
+<riga><cmp>112</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?last_reserv_invo#%?=#%?var#%?numero_prenotazione#@?break#%?</cmp></riga>
+<riga><cmp>113</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?339#%?=#%?var#%?numero_prenotazione#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>114</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?show_rate_invo#%?=#%?txt#%?1#@?oper#%?343#%?tot_no_vat_invo#%?+#%?var#%?costo_tariffa_senza_tasse#%?</cmp></riga>
+<riga><cmp>115</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?show_rate_invo#%?=#%?txt#%?1#@?oper#%?413#%?part_tot_no_vat_invo#%?+#%?var#%?costo_tariffa_senza_tasse#%?</cmp></riga>
+<riga><cmp>116</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?show_rate_invo#%?=#%?txt#%?1#@?oper#%?414#%?part_tot_vat_invo#%?+#%?var#%?tasse_tariffa#%?</cmp></riga>
+<riga><cmp>117</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?show_discount_invo#%?=#%?txt#%?1#@?oper#%?343#%?tot_no_vat_invo#%?-#%?var#%?sconto_senza_tasse#%?</cmp></riga>
+<riga><cmp>118</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?show_discount_invo#%?=#%?txt#%?1#@?oper#%?413#%?part_tot_no_vat_invo#%?-#%?var#%?sconto_senza_tasse#%?</cmp></riga>
+<riga><cmp>119</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?show_discount_invo#%?=#%?txt#%?1#@?oper#%?414#%?part_tot_vat_invo#%?-#%?var#%?tasse_sconto#%?</cmp></riga>
+<riga><cmp>120</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?353#%?costo_tariffa_senza_tasse#%?+#%?txt#%?0#%?</cmp></riga>
+<riga><cmp>121</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?352#%?sconto_senza_tasse#%?*#%?txt#%?-1#%?</cmp></riga>
+<riga><cmp>122</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?350#%?tot_no_vat_invo#%?+#%?txt#%?0#%?</cmp></riga>
+<riga><cmp>123</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?415#%?part_tot_no_vat_invo#%?+#%?txt#%?0#%?</cmp></riga>
+<riga><cmp>124</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?416#%?part_tot_vat_invo#%?+#%?txt#%?0#%?</cmp></riga>
+<riga><cmp>125</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?424#%?price_tot_invo#%?-#%?var#%?tot_no_vat_invo#%?</cmp></riga>
+<riga><cmp>126</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?424#%?vat_invo#%?-#%?var#%?tot_costs_tax_invo#%?</cmp></riga>
+<riga><cmp>128</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?349#%?vat_invo#%?+#%?txt#%?0#%?</cmp></riga>
+<riga><cmp>129</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?merge_discount_with_rate#%?=#%?txt#%?YES#@?oper#%?353#%?costo_tariffa_senza_tasse#%?-#%?var#%?sconto_senza_tasse#%?</cmp></riga>
+<riga><cmp>130</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?merge_discount_with_rate#%?=#%?txt#%?YES#@?set#%?410#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>131</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?418#%?=#%?txt#%?#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>132</cmp><cmp>cond2</cmp><cmp>rpt#@?and#$?num_persone_tot#%?!=#%?txt#%?#$?num_persone_tot#%?!=#%?txt#%?0#@?set#%?418#%?=#%?txt#%? for x persons#%?txt#%?x#%?var#%?num_persone_tot</cmp></riga>
+<riga><cmp>133</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?repetition_num_invo#%?>#%?txt#%?1#@?break#%?</cmp></riga>
+<riga><cmp>134</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?347#%?price_tot_invo#%?+#%?var#%?costo_tot#%?</cmp></riga>
+<riga><cmp>135</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?348#%?price_tot_invo#%?+#%?txt#%?0#%?</cmp></riga>
+<riga><cmp>136</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?codice_fiscale_struttura#%?!=#%?txt#%?#@?set#%?330#%?=#%?txt#%?- Fiscal Code #%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>137</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?codice_fiscale_struttura#%?!=#%?txt#%?#@?set#%?330#%?.=#%?var#%?codice_fiscale_struttura#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>138</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?telefono_struttura#%?!=#%?txt#%?#@?set#%?333#%?=#%?txt#%?Tel. #%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>139</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?telefono_struttura#%?!=#%?txt#%?#@?set#%?333#%?.=#%?var#%?telefono_struttura#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>140</cmp><cmp>cond2</cmp><cmp>inr#@?#@?set#%?339#%?=#%?txt#%?#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>141</cmp><cmp>cond2</cmp><cmp>inr#@?#@?oper#%?412#%?repetition_num_invo#%?+#%?txt#%?1#%?</cmp></riga>
+<riga><cmp>142</cmp><cmp>cond2</cmp><cmp>ind#@?#@?set#%?419#%?=#%?txt#%?YES#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>143</cmp><cmp>cond2</cmp><cmp>ind#@?#@?set#%?422#%?=#%?txt#%?name of extra cost considered as tax#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>144</cmp><cmp>cond2</cmp><cmp>ind#@?#@?set#%?347#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>145</cmp><cmp>cond2</cmp><cmp>rpt#@?and#$?telefono_struttura#%?!=#%?txt#%?#$?sito_web_struttura#%?!=#%?txt#%?#@?set#%?333#%?.=#%?txt#%? - #%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>146</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?sito_web_struttura#%?!=#%?txt#%?#@?set#%?333#%?.=#%?var#%?sito_web_struttura#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>147</cmp><cmp>cond2</cmp><cmp>ind#@?#@?set#%?343#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>148</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?331#%?=#%?var#%?nome#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>149</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?332#%?=#%?var#%?cognome#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>150</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?numcivico#%?!=#%?txt#%?#@?set#%?355#%?=#%?txt#%?, #%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>151</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?numcivico#%?!=#%?txt#%?#@?set#%?355#%?.=#%?var#%?numcivico#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>152</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?citta#%?!=#%?txt#%?#@?set#%?325#%?.=#%?var#%?citta#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>153</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?regione#%?!=#%?txt#%?#@?set#%?325#%?.=#%?txt#%? (#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>154</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?regione#%?!=#%?txt#%?#@?set#%?325#%?.=#%?var#%?regione#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>155</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?regione#%?!=#%?txt#%?#@?set#%?325#%?.=#%?txt#%?)#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>156</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?cap#%?!=#%?txt#%?#@?set#%?326#%?.=#%?var#%?cap#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>157</cmp><cmp>cond2</cmp><cmp>rpt#@?and#$?cap#%?!=#%?txt#%?#$?nazione#%?!=#%?txt#%?#@?set#%?326#%?.=#%?txt#%? #%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>158</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?nazione#%?!=#%?txt#%?#@?set#%?326#%?.=#%?var#%?nazione#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>159</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?405#%?=#%?var#%?codice_fiscale#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>160</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?406#%?=#%?var#%?partita_iva#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>161</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?407#%?=#%?var#%?via#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>162</cmp><cmp>cond2</cmp><cmp>ind#@?#@?set#%?408#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>163</cmp><cmp>cond2</cmp><cmp>ind#@?#@?set#%?412#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>164</cmp><cmp>cond2</cmp><cmp>inr#@?#@?set#%?413#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>165</cmp><cmp>cond2</cmp><cmp>inr#@?#@?set#%?414#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>166</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?logo_struttura#%?!=#%?txt#%?#@?set#%?420#%?=#%?txt#%?<img src="#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>167</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?logo_struttura#%?!=#%?txt#%?#@?set#%?420#%?.=#%?var#%?logo_struttura#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>168</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?logo_struttura#%?!=#%?txt#%?#@?set#%?420#%?.=#%?txt#%?" alt="Logo" style="float: right;">#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>169</cmp><cmp>cond2</cmp><cmp>inr#@?#@?set#%?425#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
 <riga><cmp>1</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?=#%?txt#%?f#@?set#%?1#%?=#%?txt#%?s#%?txt#%?#%?txt#%?</cmp></riga>
 <riga><cmp>3</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?!=#%?txt#%?f#@?set#%?3#%?=#%?txt#%?il#%?txt#%?#%?txt#%?</cmp></riga>
 <riga><cmp>4</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?=#%?txt#%?f#@?set#%?3#%?=#%?txt#%?la#%?txt#%?#%?txt#%?</cmp></riga>
@@ -615,31 +648,8 @@ Invoice n. [document_progressive_number] released on [today]
 <riga><cmp>29</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?=#%?txt#%?f#@?set#%?16#%?=#%?txt#%?a#%?txt#%?#%?txt#%?</cmp></riga>
 <riga><cmp>30</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?!=#%?txt#%?f#@?set#%?17#%?=#%?txt#%?o#%?txt#%?#%?txt#%?</cmp></riga>
 <riga><cmp>31</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?=#%?txt#%?f#@?set#%?17#%?=#%?txt#%?a#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>32</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?=#%?txt#%?f#@?set#%?1#%?=#%?txt#%?s#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>34</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?!=#%?txt#%?f#@?set#%?3#%?=#%?txt#%?il#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>35</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?=#%?txt#%?f#@?set#%?3#%?=#%?txt#%?la#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>36</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?!=#%?txt#%?f#@?set#%?4#%?=#%?txt#%?Il#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>37</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?=#%?txt#%?f#@?set#%?4#%?=#%?txt#%?La#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>38</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?!=#%?txt#%?f#@?set#%?5#%?=#%?txt#%?al#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>39</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?=#%?txt#%?f#@?set#%?5#%?=#%?txt#%?alla#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>40</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?!=#%?txt#%?f#@?set#%?6#%?=#%?txt#%?e#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>41</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?=#%?txt#%?f#@?set#%?6#%?=#%?txt#%?a#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>42</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?!=#%?txt#%?f#@?set#%?7#%?=#%?txt#%?o#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>43</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?=#%?txt#%?f#@?set#%?7#%?=#%?txt#%?a#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>54</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?!=#%?txt#%?f#@?set#%?13#%?=#%?txt#%?el#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>55</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?=#%?txt#%?f#@?set#%?13#%?=#%?txt#%?la#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>56</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?!=#%?txt#%?f#@?set#%?14#%?=#%?txt#%?El#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>57</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?=#%?txt#%?f#@?set#%?14#%?=#%?txt#%?La#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>58</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?!=#%?txt#%?f#@?set#%?15#%?=#%?txt#%?al#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>59</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?=#%?txt#%?f#@?set#%?15#%?=#%?txt#%?a la#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>60</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?!=#%?txt#%?f#@?set#%?16#%?=#%?txt#%?#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>61</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?=#%?txt#%?f#@?set#%?16#%?=#%?txt#%?a#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>62</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?!=#%?txt#%?f#@?set#%?17#%?=#%?txt#%?o#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>63</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?=#%?txt#%?f#@?set#%?17#%?=#%?txt#%?a#%?txt#%?#%?txt#%?</cmp></riga>
 <riga><cmp>2</cmp><cmp>compress</cmp><cmp>gz</cmp></riga>
 <riga><cmp>3</cmp><cmp>compress</cmp><cmp>gz</cmp></riga>
-<riga><cmp>5</cmp><cmp>opzeml</cmp><cmp>;;</cmp></riga>
-<riga><cmp>6</cmp><cmp>opzeml</cmp><cmp>;SI;</cmp></riga>
 <riga><cmp>5</cmp><cmp>allegato</cmp><cmp>0</cmp></riga>
 <riga><cmp>6</cmp><cmp>allegato</cmp><cmp>0</cmp></riga>
 </righetabella>
