@@ -243,6 +243,11 @@ case "della tariffa fissa":  			$messaggio = "of fixed rate"; break;
 case "di una persona":  			$messaggio = "of one person"; break;
 case "non può essere moltiplicato per più di":	$messaggio = "can not be multiplied by more than"; break;
 case "Nuovo costo aggiuntivo":  		$messaggio = "New extra cost"; break;
+case "aggiungi promemoria per l'entrata":  	$messaggio = "add a reminder for checkin"; break;
+case "aggiungi promemoria per l'uscita":  	$messaggio = "add a reminder for checkout"; break;
+case "Verrà aggiunto un <b>promemoria</b> per l'<em>entrata</em>":	$messaggio = "A <b>reminder</b> for <em>checkin</em> will be added"; break;
+case "Verrà aggiunto un <b>promemoria</b> per l'<em>uscita</em>":	$messaggio = "A <b>reminder</b> for <em>checkout</em> will be added"; break;
+case "Promemoria":  				$messaggio = "Reminder"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
