@@ -21,7 +21,7 @@ case "porre":  					$messaggio = "put"; break;
 case "sostituendo":  				$messaggio = "replacing"; break;
 case "con":  					$messaggio = "with"; break;
 case "arrotondato a":  				$messaggio = "rounded to"; break;
-case "Utilizzare una variabile personalizzata che finisce con \"_p\" per aggiungervi i separatori delle migliaia dopo l'operazione":	$messaggio = "Use a custom variable that ends with \"_p\" to add the thousands separators after the operation"; break;
+case "Utilizzare una variabile personalizzata che finisce con \"_p\" per aggiungervi i separatori delle migliaia e 2 decimali dopo l'operazione":	$messaggio = "Use a custom variable that ends with \"_p\" to add the thousands separators and 2 decimals after the operation"; break;
 case "e":  					$messaggio = "and"; break;
 case "o":  					$messaggio = "or"; break;
 case "concatenato con":  				$messaggio = "concatenated with"; break;
@@ -98,6 +98,7 @@ case "giorni":  				$messaggio = "days"; break;
 case "mesi":  					$messaggio = "months"; break;
 case "anni":  					$messaggio = "years"; break;
 case "i valori dell'array":  			$messaggio = "the values from array"; break;
+case "elimina questo &quot;se&quot;":  		$messaggio = "delete this &quot;if&quot;"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
