@@ -159,8 +159,8 @@ case "Il mascheramento della provenienza delle email è stato cambiato":	$messag
 case "SI":  					$messaggio = "YES"; break;
 case "NO":  					$messaggio = "NO"; break;
 case "Cartelle in cui creare le pagine per il sito web":	$messaggio = "Directories where website pages are created"; break;
-case "percorso relativo":			$messaggio = "path relative"; break;
-case "alla cartella di HotelDruid":		$messaggio = "to the HotelDruid directory"; break;
+case "percorsi separati da virgole relativi":	$messaggio = "comma separated paths relative"; break;
+case "alla cartella di HotelDruid, se non iniziano con /":	$messaggio = "to the HotelDruid directory, if they don't begin with /"; break;
 case "Non ho i permessi di scrittura sulla cartella":	$messaggio = "I don't have write permissions on directory"; break;
 case "La cartella inserita <div style=\"display: inline; color: red;\">non esiste</div>":	$messaggio = "The inserted directory <div style=\"display: inline; color: red;\">does not exist</div>"; break;
 case "Le cartelle dove vengono create le pagine per il sito web sono state cambiate":	$messaggio = "The directories where website pages are created have been changed"; break;
@@ -201,7 +201,6 @@ case "Origini delle prenotazioni":  		$messaggio = "Reservations origins"; break
 case "Nuova origine delle prenotazioni aggiunta":	$messaggio = "New reservations origin added"; break;
 case "Origine delle prenotazioni eliminata":  	$messaggio = "Reservations origin deleted"; break;
 case "Nome combinazione":  			$messaggio = "Combination name"; break;
-case "separate da virgole":  			$messaggio = "comma separated"; break;
 case "prenotazioni correnti e future":  	$messaggio = "current and future reservations"; break;
 case "Personalizzazioni di <b>tutti gli utenti</b>":  	$messaggio = "Customizations of <b>all users</b>"; break;
 case "tutti gli utenti":  			$messaggio = "all users"; break;
@@ -268,7 +267,7 @@ case "CAP":  					$messaggio = "Postal code"; break;
 case "Telefono":  				$messaggio = "Telephone"; break;
 case "Fax":  					$messaggio = "Fax"; break;
 case "Codice fiscale":  			$messaggio = "Fiscal code"; break;
-case "Parita iva":  				$messaggio = "VAT number"; break;
+case "Partita iva":  				$messaggio = "VAT number"; break;
 case "Modifica i dati della struttura":  	$messaggio = "Modify property data"; break;
 case "Clicca su un documento per modificarlo":	$messaggio = "Click on a document to modify it"; break;
 case "Cambia l'ordine dei documenti":  		$messaggio = "Change documents order"; break;
@@ -330,6 +329,18 @@ case "f":  					$messaggio = "f"; break;
 case "Il nome delle unità da affittare è stato cambiato":	$messaggio = "The name of the rental unit has been changed"; break;
 case "Tabelle con le casse":  			$messaggio = "Cashboxes tables"; break;
 case "Il numero delle righe delle tabelle con le casse è stato cambiato":	$messaggio = "The number of rows of the tables with the cashboxes has been changed"; break;
+case "Elimina il documento":  			$messaggio = "Delete document"; break;
+case "Sei sicuro di voler eliminare il documento":	$messaggio = "Are you sure you want to delete document"; break;
+case "Il documento è stato eliminato":	$messaggio = "The document has been deleted"; break;
+case "Campi da considerare per la ricerca dei clienti":	$messaggio = "Fields to be considered when searching clients"; break;
+case "cognome":  				$messaggio = "surname"; break;
+case "email":  					$messaggio = "email"; break;
+case "nome":  					$messaggio = "name"; break;
+case "telefono":  				$messaggio = "telephone"; break;
+case "città":  					$messaggio = "city"; break;
+case "indirizzo":  				$messaggio = "address"; break;
+case "codice postale":  			$messaggio = "postal code"; break;
+case "I campi da considerare per la ricerca dei clienti sono stati cambiati":	$messaggio = "The fields to be considered when searching clients have been changed"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
