@@ -96,6 +96,9 @@ case "% del prezzo totale":  			$messaggio = "% of total price"; break;
 case "modificata":  				$messaggio = "modified"; break;
 case "Errore":  				$messaggio = "Error"; break;
 case "costo aggiuntivo":  			$messaggio = "extra cost"; break;
+case "per la prenotazione":  			$messaggio = "for reservation"; break;
+case "per l'entrata":  				$messaggio = "for checkin"; break;
+case "per l'uscita":  				$messaggio = "for checkout"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
