@@ -177,7 +177,7 @@ case "potrà modificare anche le <b>prenotazioni già iniziate</b> nel":	$messag
 case "non avrà <b>limite di tempo</b> per modificare le prenotazioni nel":	$messaggio = "will have no <b>time limit</b> to modify reservations"; break;
 case "non potrà più modificare le prenotazioni <b>dopo":	$messaggio = "will not be able to modify reservations anymore <b>after"; break;
 case "non potrà <b>cancellare</b> nessuna prenotazione nel":	$messaggio = "will not be able to <b>delete</b> any reservation in"; break;
-case "potrà <b>cancellare</b> solo le proprie prenotazioni nel":	$messaggio = "will be able to <b>delete</b> only his own reservations in"; break;
+case "potrà <b>cancellare</b> solo le prenotazioni non iniziate nel":	$messaggio = "will be able to <b>delete</b> only not begun reservations in"; break;
 case "potrà <b>cancellare</b> tutte le prenotazioni nel":	$messaggio = "will be able to <b>delete</b> all reservations in"; break;
 case "non avrà <b>limite di tempo</b> per cancellare le prenotazioni nel":	$messaggio = "will have no <b>time limit</b> to delete reservations"; break;
 case "ore</b> nel":  				$messaggio = "hours</b> in"; break;
@@ -322,6 +322,13 @@ case "potrà vedere <b>email, telefoni e fax</b> dei clienti":	$messaggio = "wil
 case "non potrà più vedere <b>email, telefoni e fax</b> dei clienti":	$messaggio = "will not be able to view <b>emails, telephones and faxes</b> of clients"; break;
 case "potrà vedere <b>l'indirizzo</b> dei clienti":	$messaggio = "will be able to view <b>the address</b> of clients"; break;
 case "non potrà più vedere <b>l'indirizzo</b> dei clienti":	$messaggio = "will not be able to view <b>the address</b> of clients"; break;
+case "Mostrare le prenotazioni non permesse come":	$messaggio = "Show not permitted reservations as"; break;
+case "oscurate":  				$messaggio = "obscured"; break;
+case "periodi vuoti":  				$messaggio = "empty periods"; break;
+case "solo correnti e future":  		$messaggio = "only current and future"; break;
+case "vedrà le prenotazioni non permesse come <em>oscurate</em>":	$messaggio = "will see not permitted reservations as <em>obscured</em>"; break;
+case "vedrà le prenotazioni non permesse come <em>periodi vuoti</em>":	$messaggio = "will see not permitted reservations as <em>empty periods</em>"; break;
+case "vedrà le prenotazioni non permesse come <em>periodi vuoti nel passato ed oscurate nel presente e nel futuro</em>":	$messaggio = "will see not permitted reservations as <em>empty periods in the past, obscured in the present and future</em>"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
