@@ -207,6 +207,7 @@ case "OK":  					$messaggio = "OK"; break;
 case "Annulla":  				$messaggio = "Cancel"; break;
 case "Si è sicuri di voler <div style=\"display: inline; color: red;\"><b>cancellare":	$messaggio = "Are you sure you want to <div style=\"display: inline; color: red;\"><b>delete"; break;
 case "clienti</b></div> che non sono associati a nessuna prenotazione e nessun pagamento":	$messaggio = "clients</b></div> that don't have any associated reservation or payment"; break;
+case "carte di credito</b></div> associate a clienti che non hanno nessuna prenotazione nel futuro":	$messaggio = "credit cards</b></div> from clients without reservations in the future"; break;
 case "Cancella i clienti senza prenotazioni":	$messaggio = "Delete clients without reservations"; break;
 case "Metodo pagamento":  			$messaggio = "Payment method"; break;
 case "Tariffe":  				$messaggio = "Rates"; break;
@@ -340,6 +341,14 @@ case "non più del numero di persone":  		$messaggio = "no more than the number
 case "non più del numero totale di persone":  	$messaggio = "no more than the total number of people"; break;
 case "meno":  					$messaggio = "minus"; break;
 case "aggiungendo":  				$messaggio = "adding"; break;
+case "più di":  				$messaggio = "more than"; break;
+case "prezzi importati":  			$messaggio = "prices imported"; break;
+case "dalla tariffa":  				$messaggio = "from rate"; break;
+case "Cancella le carte di credito di prenotazioni passate":	$messaggio = "Delete credit cards of past reservations"; break;
+case "password per le carte di credito":  	$messaggio = "password for credit cards"; break;
+case "Cancellate":  				$messaggio = "Deleted"; break;
+case "carte di credito":  			$messaggio = "credit cards"; break;
+case "password errata":  			$messaggio = "wrong password"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
