@@ -112,12 +112,12 @@ case "nazione":  				$messaggio = "nación"; break;
 case "rilasciato da":  				$messaggio = "emitido por"; break;
 case "nazione di rilascio":  			$messaggio = "nación emisora"; break;
 case "parentela":  				$messaggio = "emparentado"; break;
-case "Codice fiscale":  			$messaggio = "Código fiscal"; break;
+case "Codice fiscale":  			$messaggio = "N. Identificación Fiscal"; break;
 case "con i costi aggiuntivi selezionati":  	$messaggio = "con los costes añadidos seleccionados"; break;
 case "I beni richiesti dal costo":  		$messaggio = "Los bienes necesarios para el coste"; break;
 case "non sono disponibili nell'inventario":  	$messaggio = "no están disponibles en el inventario"; break;
 case "Si deve inserire il numero delle persone per questa tariffa":	$messaggio = "Hay que insertar el número de personas para esta tarifa"; break;
-case "Partita iva":  				$messaggio = "N. identificación fiscal"; break;
+case "Partita iva":  				$messaggio = "Cert. Identificación Fiscal"; break;
 case "lo sconto è sbagliato":  			$messaggio = "el descuento está equivocado"; break;
 case "la caparra è sbagliata":  		$messaggio = "la fianza está equivocada"; break;
 case "soprannome":  				$messaggio = "apodo"; break;
