@@ -196,7 +196,7 @@ case "SI":  					$messaggio = "SI"; break;
 case "Costo aggiuntivo già esistente":  	$messaggio = "Coste añadido ya existente"; break;
 case "Tariffe incompatibili con il costo":  	$messaggio = "Tarifas incompatibles con el coste"; break;
 case "Tariffe incompatibili":  			$messaggio = "Tarifas incompatibles"; break;
-case "Importa i prezzi della":  		$messaggio = "Importar los precios de la"; break;
+case "i prezzi della":  			$messaggio = "los precios de la"; break;
 case "dalla":  					$messaggio = "desde la"; break;
 case "aggiungendo":  				$messaggio = "añadiendo"; break;
 case "I prezzi della tariffa selezionata sono stati importati":	$messaggio = "Los precios de la tarifa seleccionada han sido importados"; break;
@@ -234,7 +234,7 @@ case "Commissioni":  				$messaggio = "Comisiones"; break;
 case "Le commissioni normali sulla":  		$messaggio = "Las comisiones normales sobre la"; break;
 case "sono":  					$messaggio = "son"; break;
 case "Tasse":  					$messaggio = "Tasas"; break;
-case "Tasse applicate sulla":  			$messaggio = "Tasas aplicadas sobre la"; break;
+case "Tasse applicate su":  			$messaggio = "Tasas aplicadas sobre"; break;
 case "della tariffa":  				$messaggio = "de la tarifa"; break;
 case "Inserisci o modifica le tasse":  		$messaggio = "Insertar o modificar las tasas"; break;
 case "Le commissioni sono state modificate":  	$messaggio = "Las comisiones han sido modificadas"; break;
@@ -292,6 +292,16 @@ case "Se la prenotazione ha una durata di":	$messaggio = "Si la reserva tiene un
 case "o più giorni":  				$messaggio = "o más días"; break;
 case "Se":  					$messaggio = "Si"; break;
 case "Se si inseriscono":  			$messaggio = "Si se insertan"; break;
+case "Importa ora":  				$messaggio = "Importar ahora"; break;
+case "Importa sempre":  			$messaggio = "Importar siempre"; break;
+case "cancella":  				$messaggio = "borrar"; break;
+case "L'importatazione dei prezzi è stata cancellata":	$messaggio = "La importación de los precios ha sido borrada"; break;
+case "al prezzo fisso":  			$messaggio = "al precio fijo"; break;
+case "al prezzo per persona":  			$messaggio = "al precio por persona"; break;
+case "ad entrambi i prezzi":  			$messaggio = "a ambos precios"; break;
+case "La tariffa":  				$messaggio = "La tarifa"; break;
+case "esporta i prezzi ad altre tariffe, non può importare i prezzi in modo permanente":	$messaggio = "exporta los precios a otras tarifas, no puede importar precios de manera permanente"; break;
+case "tutte le tariffe":  			$messaggio = "todas las tarifas"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
