@@ -210,7 +210,7 @@ case "nata":  					$messaggio = "nacida"; break;
 case "il":  					$messaggio = "el"; break;
 case " a":  					$messaggio = " en"; break;
 case "scade":  					$messaggio = "caduca"; break;
-case "Codice fiscale":  			$messaggio = "Código fiscal"; break;
+case "Codice fiscale":  			$messaggio = "N.I.F."; break;
 case "Origine":  				$messaggio = "Origen"; break;
 case "L'origine della prenotazione verrà cambiata a":	$messaggio = "El origen de la reserva será cambiado a"; break;
 case "Modifica o cancella le prenotazioni":  	$messaggio = "Modifica o borra las reservas"; break;
@@ -225,7 +225,7 @@ case "non sono disponibili nell'inventario":  	$messaggio = "no están disponibl
 case "<b><big>i</big></b>":  			$messaggio = "<b><big>i</big></b>"; break;
 case "pren.":  					$messaggio = "res."; break;
 case "Si deve inserire il <span class=\"colred\">numero delle persone</span> per la tariffa selezionata":	$messaggio = "Hay que insertar el <span class=\"colred\">número de personas</span> para la tarifa seleccionada"; break;
-case "Partita iva":  				$messaggio = "N. identificación fiscal"; break;
+case "Partita iva":  				$messaggio = "C.I.F."; break;
 case "i beni richiesti alla registrazione dell'entrata":	$messaggio = "los bienes necesarios para registrar la entrada"; break;
 case "Commissioni":  				$messaggio = "Comisiones"; break;
 case "Ricalcola le commissioni in base alla nuova tariffa":	$messaggio = "Vuelve a calcular las comisiones en base a la nueva tarifa"; break;
@@ -243,6 +243,11 @@ case "della tariffa fissa":  			$messaggio = "de la tarifa fija"; break;
 case "di una persona":  			$messaggio = "de una persona"; break;
 case "non può essere moltiplicato per più di":	$messaggio = "no puede ser multiplicado por más de"; break;
 case "Nuovo costo aggiuntivo":  		$messaggio = "Nuevo coste añadido"; break;
+case "aggiungi promemoria per l'entrata":  	$messaggio = "añadir un recordatorio para la entrada"; break;
+case "aggiungi promemoria per l'uscita":  	$messaggio = "añadir un recordatorio para la salida"; break;
+case "Verrà aggiunto un <b>promemoria</b> per l'<em>entrata</em>":	$messaggio = "Se añadirá un <b>recodatorio</b> para la <em>entrada</em>"; break;
+case "Verrà aggiunto un <b>promemoria</b> per l'<em>uscita</em>":	$messaggio = "Se añadirá un <b>recodatorio</b> para la <em>salida</em>"; break;
+case "Promemoria":  				$messaggio = "Recordatorio"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
