@@ -21,7 +21,7 @@ case "porre":  					$messaggio = "poner"; break;
 case "sostituendo":  				$messaggio = "substituyendo"; break;
 case "con":  					$messaggio = "con"; break;
 case "arrotondato a":  				$messaggio = "redondeado a"; break;
-case "Utilizzare una variabile personalizzata che finisce con \"_p\" per aggiungervi i separatori delle migliaia dopo l'operazione":	$messaggio = "Utilizar una variable personalizada que acaba con \"_p\" para añadir los separadores de los miles después de la operación"; break;
+case "Utilizzare una variabile personalizzata che finisce con \"_p\" per aggiungervi i separatori delle migliaia e 2 decimali dopo l'operazione":	$messaggio = "Utilizar una variable personalizada que acaba con \"_p\" para añadir los separadores de los miles y 2 decimales después de la operación"; break;
 case "e":  					$messaggio = "y"; break;
 case "o":  					$messaggio = "o"; break;
 case "concatenato con":  			$messaggio = "concatenado con"; break;
@@ -98,6 +98,7 @@ case "giorni":  				$messaggio = "días"; break;
 case "mesi":  					$messaggio = "meses"; break;
 case "anni":  					$messaggio = "años"; break;
 case "i valori dell'array":  			$messaggio = "los valores del array"; break;
+case "elimina questo &quot;se&quot;":  		$messaggio = "Eliminar este &quot;si&quot;"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
