@@ -153,14 +153,14 @@ case "variabili personalizzate":  		$messaggio = "variables personalizadas"; bre
 case "Cambia il numero dei documenti":  	$messaggio = "Cambiar el número de documentos"; break;
 case "Il numero di documenti è stato cambiato":	$messaggio = "El número de documentos ha sido cambiado"; break;
 case "Il numero di documenti è sbagliato":  	$messaggio = "El número de documentos está equivocado"; break;
-case "Indirizzo email":  			$messaggio = "Dirección de correo electronico"; break;
+case "Indirizzo email":  			$messaggio = "Dirección de correo electrónico"; break;
 case "Mascherare la provenienza delle email sull'envelope":	$messaggio = "Enmascarar la proveniencia de las email en el envelope"; break;
 case "Il mascheramento della provenienza delle email è stato cambiato":	$messaggio = "El enmascaramiento de la proveniencia de las email ha sido cambiado"; break;
 case "SI":  					$messaggio = "SI"; break;
 case "NO":  					$messaggio = "NO"; break;
 case "Cartelle in cui creare le pagine per il sito web":	$messaggio = "Carpetas en donde crear las páginas para el sitio web"; break;
-case "percorso relativo":			$messaggio = "recorrido relativo"; break;
-case "alla cartella di HotelDruid":		$messaggio = "a la carpeta de HotelDruid"; break;
+case "percorsi separati da virgole relativi":	$messaggio = "recorridos separados por comas relativos"; break;
+case "alla cartella di HotelDruid, se non iniziano con /":	$messaggio = "a la carpeta de HotelDruid, si no empiezan con /"; break;
 case "Non ho i permessi di scrittura sulla cartella":	$messaggio = "No tengo permisos para escribir en el directorio"; break;
 case "La cartella inserita <div style=\"display: inline; color: red;\">non esiste</div>":	$messaggio = "El directorio insertado <div style=\"display: inline; color: red;\">no existe</div>"; break;
 case "Le cartelle dove vengono create le pagine per il sito web sono state cambiate":	$messaggio = "Los directorios donde crear páginas para el sitio web han sido cambiados"; break;
@@ -201,7 +201,6 @@ case "Origini delle prenotazioni":  		$messaggio = "Origenes de las reservas"; b
 case "Nuova origine delle prenotazioni aggiunta":	$messaggio = "Nueva origen de las reservas añadida"; break;
 case "Origine delle prenotazioni eliminata":  	$messaggio = "Origen de las reservas eliminada"; break;
 case "Nome combinazione":  			$messaggio = "Nombre combinación"; break;
-case "separate da virgole":  			$messaggio = "separadas por comas"; break;
 case "prenotazioni correnti e future":  	$messaggio = "reservas corrientes y futuras"; break;
 case "Personalizzazioni di <b>tutti gli utenti</b>":  	$messaggio = "Personalizaciones de <b>todos los usuarios</b>"; break;
 case "tutti gli utenti":  			$messaggio = "todos los usuarios"; break;
@@ -267,8 +266,8 @@ case "Indirizzo":  				$messaggio = "Dirección"; break;
 case "CAP":  					$messaggio = "Código postal"; break;
 case "Telefono":  				$messaggio = "Teléfono"; break;
 case "Fax":  					$messaggio = "Fax"; break;
-case "Codice fiscale":  			$messaggio = "Código fiscal"; break;
-case "Parita iva":  				$messaggio = "Número identificación fiscal"; break;
+case "Codice fiscale":  			$messaggio = "Número Identificación Fiscal"; break;
+case "Parita iva":  				$messaggio = "Cert. Identificación Fiscal"; break;
 case "Modifica i dati della struttura":  	$messaggio = "Modificar los datos de la estructura"; break;
 case "Clicca su un documento per modificarlo":	$messaggio = "Hacer clic sobre un documento para modificarlo"; break;
 case "Cambia l'ordine dei documenti":  		$messaggio = "Cambiar el orden de los documentos"; break;
@@ -330,6 +329,18 @@ case "f":  					$messaggio = "f"; break;
 case "Il nome delle unità da affittare è stato cambiato":	$messaggio = "El nombre de las unidades a alquilar ha sido cambiado"; break;
 case "Tabelle con le casse":  			$messaggio = "Tablas con las cajas"; break;
 case "Il numero delle righe delle tabelle con le casse è stato cambiato":	$messaggio = "El número de líneas de las tablas con las cajas ha sido cambiado"; break;
+case "Elimina il documento":  			$messaggio = "Eliminar el documento"; break;
+case "Sei sicuro di voler eliminare il documento":	$messaggio = "Está seguro de querer eliminar el documento"; break;
+case "Il documento è stato eliminato":	$messaggio = "El documento ha sido eliminado"; break;
+case "Campi da considerare per la ricerca dei clienti":	$messaggio = "Campos a considerar para la búsqueda de los clientes"; break;
+case "cognome":  				$messaggio = "apellido"; break;
+case "email":  					$messaggio = "correo electrónico"; break;
+case "nome":  					$messaggio = "nombre"; break;
+case "telefono":  				$messaggio = "teléfono"; break;
+case "città":  					$messaggio = "ciudad"; break;
+case "indirizzo":  				$messaggio = "dirección"; break;
+case "codice postale":  			$messaggio = "código postal"; break;
+case "I campi da considerare per la ricerca dei clienti sono stati cambiati":	$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
