@@ -96,6 +96,9 @@ case "% del prezzo totale":  			$messaggio = "% del precio total"; break;
 case "modificata":  				$messaggio = "modificada"; break;
 case "Errore":  				$messaggio = "Error"; break;
 case "costo aggiuntivo":  			$messaggio = "coste añadido"; break;
+case "per la prenotazione":  			$messaggio = "para la reserva"; break;
+case "per l'entrata":  				$messaggio = "para la entrada"; break;
+case "per l'uscita":  				$messaggio = "para la salida"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
