@@ -177,7 +177,7 @@ case "potrà modificare anche le <b>prenotazioni già iniziate</b> nel":	$messag
 case "non avrà <b>limite di tempo</b> per modificare le prenotazioni nel":	$messaggio = "no tendrá <b>limite de tiempo</b> para modificar las reservas en el"; break;
 case "non potrà più modificare le prenotazioni <b>dopo":	$messaggio = "ya no podrá modificar las reservas <b>después de"; break;
 case "non potrà <b>cancellare</b> nessuna prenotazione nel":	$messaggio = "no podrá <b>borrar</b> ninguna reserva en el"; break;
-case "potrà <b>cancellare</b> solo le proprie prenotazioni nel":	$messaggio = "podrá <b>borrar</b> solo sus proprias reservas en el"; break;
+case "potrà <b>cancellare</b> solo le prenotazioni non iniziate nel":	$messaggio = "podrá <b>borrar</b> solo las reservas que no han empezado en el"; break;
 case "potrà <b>cancellare</b> tutte le prenotazioni nel":	$messaggio = "podrá <b>borrar</b> todas las reservas en el"; break;
 case "non avrà <b>limite di tempo</b> per cancellare le prenotazioni nel":	$messaggio = "no tendrá <b>limite de tiempo</b> para borrar las reservas en el"; break;
 case "ore</b> nel":  				$messaggio = "horas</b> en el"; break;
@@ -322,6 +322,13 @@ case "potrà vedere <b>email, telefoni e fax</b> dei clienti":	$messaggio = "pod
 case "non potrà più vedere <b>email, telefoni e fax</b> dei clienti":	$messaggio = "ya no podrà ver <b>emails, teléfonos y faxes</b> de los clientes"; break;
 case "potrà vedere <b>l'indirizzo</b> dei clienti":	$messaggio = "podrà ver <b>la dirección</b> de los clientes"; break;
 case "non potrà più vedere <b>l'indirizzo</b> dei clienti":	$messaggio = "ya no podrà ver <b>la dirección</b> de los clientes"; break;
+case "Mostrare le prenotazioni non permesse come":	$messaggio = "Mostrar las reservas no permitidas como"; break;
+case "oscurate":  				$messaggio = "oscurecidas"; break;
+case "periodi vuoti":  				$messaggio = "períodos vacios"; break;
+case "solo correnti e future":  		$messaggio = "solo corrientes y futuras"; break;
+case "vedrà le prenotazioni non permesse come <em>oscurate</em>":	$messaggio = "verá las reservas no permitidas como <em>oscurecidas</em>"; break;
+case "vedrà le prenotazioni non permesse come <em>periodi vuoti</em>":	$messaggio = "verá las reservas no permitidas como <em>períodos vacios</em>"; break;
+case "vedrà le prenotazioni non permesse come <em>periodi vuoti nel passato ed oscurate nel presente e nel futuro</em>":	$messaggio = "verá las reservas no permitidas como <em>períodos vacios en el pasado y oscurecidas en el presente y futuro</em>"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
