@@ -208,6 +208,7 @@ case "OK":  					$messaggio = "OK"; break;
 case "Annulla":  				$messaggio = "Cancelar"; break;
 case "Si è sicuri di voler <div style=\"display: inline; color: red;\"><b>cancellare":	$messaggio = "Estas seguro de querer <div style=\"display: inline; color: red;\"><b>borrar"; break;
 case "clienti</b></div> che non sono associati a nessuna prenotazione e nessun pagamento":	$messaggio = "clientes</b></div> que no estan asociados a ninguna reserva y ningun pago"; break;
+case "carte di credito</b></div> associate a clienti che non hanno nessuna prenotazione nel futuro":	$messaggio = "tarjetas de crédito</b></div> asociadas a clientes que no tienen reservas en el futuro"; break;
 case "Cancella i clienti senza prenotazioni":	$messaggio = "Borrar los clientes sin reservas"; break;
 case "Metodo pagamento":  			$messaggio = "Método pago"; break;
 case "Tariffe":  				$messaggio = "Tarifas"; break;
@@ -341,6 +342,14 @@ case "non più del numero di persone":  		$messaggio = "no más del número de p
 case "non più del numero totale di persone":  	$messaggio = "no más del número total de personas"; break;
 case "meno":  					$messaggio = "menos"; break;
 case "aggiungendo":  				$messaggio = "añadiendo"; break;
+case "più di":  				$messaggio = "más de"; break;
+case "prezzi importati":  			$messaggio = "precios importados"; break;
+case "dalla tariffa":  				$messaggio = "desde la tarifa"; break;
+case "Cancella le carte di credito di prenotazioni passate":	$messaggio = "Borrar las tarjetas de crédito de reservas pasadas"; break;
+case "password per le carte di credito":  	$messaggio = "contraseña para las tarjetas de crédito"; break;
+case "Cancellate":  				$messaggio = "Borradas"; break;
+case "carte di credito":  			$messaggio = "tarjetas de crédito"; break;
+case "password errata":  			$messaggio = "contraseña equivocada"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
