@@ -131,13 +131,15 @@ $lista_nazioni[43] = "Caroline";
 $cod_nazioni[43] = "100000741";
 $lista_nazioni[44] = "Cayman - isole";
 $cod_nazioni[44] = "100000742";
+$cod2_nazioni[44] = "KY";
 $lista_nazioni[45] = "Cecoslovacchia";
 $cod_nazioni[45] = "100000210";
 $lista_nazioni[46] = "Centrafrica";
 $cod_nazioni[46] = "100000414";
-$cod2_nazioni[46] = "AAF";
+$cod2_nazioni[46] = "CF";
 $lista_nazioni[47] = "Christmas";
 $cod_nazioni[47] = "100000743";
+$cod2_nazioni[47] = "CX";
 $lista_nazioni[48] = "Ciad";
 $cod_nazioni[48] = "100000415";
 $cod2_nazioni[48] = "TD";
@@ -160,6 +162,7 @@ $cod_nazioni[54] = "100000246";
 $cod2_nazioni[54] = "VA.";
 $lista_nazioni[55] = "Cocos";
 $cod_nazioni[55] = "100000746";
+$cod2_nazioni[55] = "CC";
 $lista_nazioni[56] = "Colombia";
 $cod_nazioni[56] = "100000608";
 $cod2_nazioni[56] = "CO.";
@@ -232,6 +235,7 @@ $cod_nazioni[81] = "100000420";
 $cod2_nazioni[81] = "ET";
 $lista_nazioni[82] = "Faer Oer";
 $cod_nazioni[82] = "100000755";
+$cod2_nazioni[82] = "FO";
 $lista_nazioni[83] = "Figi";
 $cod_nazioni[83] = "100000703";
 $cod2_nazioni[83] = "FJ";
@@ -240,7 +244,7 @@ $cod_nazioni[84] = "100000323";
 $cod2_nazioni[84] = "PH";
 $lista_nazioni[85] = "Finlandia";
 $cod_nazioni[85] = "100000214";
-$cod_nazioni[85] = "FI.";
+$cod2_nazioni[85] = "FI.";
 $lista_nazioni[86] = "Francia";
 $cod_nazioni[86] = "100000215";
 $cod2_nazioni[86] = "FR.";
@@ -334,8 +338,9 @@ $cod_nazioni[117] = "100000333";
 $cod2_nazioni[117] = "IQ";
 $lista_nazioni[118] = "Iraq - Etnia Curda";
 $cod_nazioni[118] = "110000007";
-$lista_nazioni[119] = "Irian Occidentale";
-$cod_nazioni[119] = "100000763";
+$lista_nazioni[119] = "Sudan Del Sud";
+$cod_nazioni[119] = "100000455";
+$cod2_nazioni[119] = "SS";
 $lista_nazioni[120] = "Irlanda";
 $cod_nazioni[120] = "100000221";
 $cod2_nazioni[120] = "IE";
@@ -344,6 +349,7 @@ $cod_nazioni[121] = "100000223";
 $cod2_nazioni[121] = "IS.";
 $lista_nazioni[122] = "Isole Vergini";
 $cod_nazioni[122] = "100000764";
+$cod2_nazioni[122] = "VI.";
 $lista_nazioni[123] = "Israele";
 $cod_nazioni[123] = "100000334";
 $cod2_nazioni[123] = "IL";
@@ -353,8 +359,9 @@ $cod2_nazioni[124] = "IT";
 $lista_nazioni[125] = "Jugoslavia - Serbia-Mont.";
 $cod_nazioni[125] = "100000224";
 $cod2_nazioni[125] = "YU";
-$lista_nazioni[126] = "Jugoslavia Et. Kossovara";
-$cod_nazioni[126] = "110000010";
+$lista_nazioni[126] = "Kosovo";
+$cod_nazioni[126] = "100001002";
+$cod2_nazioni[126] = "XK";
 $lista_nazioni[127] = "Kazakistan";
 $cod_nazioni[127] = "100000356";
 $cod2_nazioni[127] = "KZ";
@@ -392,7 +399,7 @@ $cod_nazioni[138] = "100000431";
 $cod2_nazioni[138] = "LY";
 $lista_nazioni[139] = "Liechtenstein";
 $cod_nazioni[139] = "100000225";
-$cod2_nazioni[139] = "Li.";
+$cod2_nazioni[139] = "LI.";
 $lista_nazioni[140] = "Lituania";
 $cod_nazioni[140] = "100000249";
 $cod2_nazioni[140] = "LT.";
@@ -413,8 +420,9 @@ $cod2_nazioni[145] = "MK";
 $lista_nazioni[146] = "Mali";
 $cod_nazioni[146] = "100000435";
 $cod2_nazioni[146] = "ML";
-$lista_nazioni[147] = "Malvine";
+$lista_nazioni[147] = "Malvine - Falkland";
 $cod_nazioni[147] = "100000768";
+$cod2_nazioni[147] = "FK";
 $lista_nazioni[148] = "Man";
 $cod_nazioni[148] = "100000769";
 $lista_nazioni[149] = "Malaysia";
@@ -430,11 +438,13 @@ $cod_nazioni[152] = "100000434";
 $cod2_nazioni[152] = "MW";
 $lista_nazioni[153] = "Marianne";
 $cod_nazioni[153] = "100000771";
+$cod2_nazioni[153] = "MP";
 $lista_nazioni[154] = "Marocco";
 $cod_nazioni[154] = "100000436";
 $cod2_nazioni[154] = "MA";
 $lista_nazioni[155] = "Marshall";
 $cod_nazioni[155] = "100000772";
+$cod2_nazioni[155] = "MH";
 $lista_nazioni[156] = "Malta";
 $cod_nazioni[156] = "100000227";
 $cod2_nazioni[156] = "MT.";
@@ -457,6 +467,7 @@ $cod_nazioni[162] = "100000527";
 $cod2_nazioni[162] = "MX";
 $lista_nazioni[163] = "Micronesia Stati Federali";
 $cod_nazioni[163] = "100000775";
+$cod2_nazioni[163] = "FM.";
 $lista_nazioni[164] = "Midway";
 $cod_nazioni[164] = "100000776";
 $lista_nazioni[165] = "Mongolia";
@@ -464,6 +475,7 @@ $cod_nazioni[165] = "100000341";
 $cod2_nazioni[165] = "MN.";
 $lista_nazioni[166] = "Monaco";
 $cod_nazioni[166] = "100000229";
+$cod2_nazioni[166] = "MC";
 $lista_nazioni[167] = "Moldavia";
 $cod_nazioni[167] = "100000254";
 $cod2_nazioni[167] = "MD";
@@ -514,12 +526,15 @@ $cod_nazioni[183] = "100000780";
 $cod2_nazioni[183] = "NC";
 $lista_nazioni[184] = "Norfolk";
 $cod_nazioni[184] = "100000778";
+$cod2_nazioni[184] = "NF";
 $lista_nazioni[185] = "Oman";
 $cod_nazioni[185] = "100000343";
 $cod2_nazioni[185] = "OM";
 $lista_nazioni[186] = "Nauru";
 $cod_nazioni[186] = "100000715";
+$cod2_nazioni[186] = "NR";
 $lista_nazioni[187] = "Nuova Guinea";
+$cod2_nazioni[187] = "PG.";
 $cod_nazioni[187] = "100000781";
 $lista_nazioni[188] = "Panama";
 $cod_nazioni[188] = "100000530";
@@ -540,8 +555,10 @@ $cod_nazioni[193] = "100000344";
 $cod2_nazioni[193] = "PK";
 $lista_nazioni[194] = "Palau Repubblica";
 $cod_nazioni[194] = "100000783";
+$cod2_nazioni[194] = "PW";
 $lista_nazioni[195] = "Pitcairn";
 $cod_nazioni[195] = "100000786";
+$cod2_nazioni[195] = "PN.";
 $lista_nazioni[196] = "Polonia";
 $cod_nazioni[196] = "100000233";
 $cod2_nazioni[196] = "PL";
@@ -549,6 +566,7 @@ $lista_nazioni[197] = "Pasqua";
 $cod_nazioni[197] = "100000785";
 $lista_nazioni[198] = "Polinesia";
 $cod_nazioni[198] = "100000787";
+$cod2_nazioni[198] = "PF";
 $lista_nazioni[199] = "Portogallo";
 $cod_nazioni[199] = "100000234";
 $cod2_nazioni[199] = "PT.";
@@ -576,6 +594,7 @@ $cod_nazioni[207] = "100000219";
 $cod2_nazioni[207] = "GB";
 $lista_nazioni[208] = "Salomone";
 $cod_nazioni[208] = "100000725";
+$cod2_nazioni[208] = "SB";
 $lista_nazioni[209] = "Ruanda";
 $cod_nazioni[209] = "100000446";
 $cod2_nazioni[209] = "RW";
@@ -589,12 +608,13 @@ $cod_nazioni[212] = "100000345";
 $cod2_nazioni[212] = "QA";
 $lista_nazioni[213] = "Ryukyu";
 $cod_nazioni[213] = "100000794";
-$lista_nazioni[214] = "S. Christopher E Nevis";
+$lista_nazioni[214] = "Saint Kitts E Nevis";
 $cod_nazioni[214] = "100000534";
+$cod2_nazioni[214] = "KN";
 $lista_nazioni[215] = "Saint Vincent E Grenadine";
 $cod_nazioni[215] = "100000797";
 $cod2_nazioni[215] = "VC.";
-$lista_nazioni[216] = "Repubblica Slovacca";
+$lista_nazioni[216] = "Slovacchia";
 $cod_nazioni[216] = "100000255";
 $cod2_nazioni[216] = "SK";
 $lista_nazioni[217] = "Romania";
@@ -614,7 +634,7 @@ $cod2_nazioni[221] = "SM";
 $lista_nazioni[222] = "Saint Pierre Et Miquelon";
 $cod_nazioni[222] = "100000796";
 $cod2_nazioni[222] = "PM";
-$lista_nazioni[223] = "Seicelle";
+$lista_nazioni[223] = "Seychelles";
 $cod_nazioni[223] = "100000449";
 $cod2_nazioni[223] = "SC";
 $lista_nazioni[224] = "Senegal";
@@ -654,14 +674,15 @@ $cod_nazioni[236] = "100000348";
 $cod2_nazioni[236] = "SY";
 $lista_nazioni[237] = "Siria - Etnia Curda";
 $cod_nazioni[237] = "110000008";
-$lista_nazioni[238] = "Somalia Francese";
-$cod_nazioni[238] = "100000802";
+$lista_nazioni[238] = "Montenegro";
+$cod_nazioni[238] = "100001001";
+$cod2_nazioni[238] = "ME";
 $lista_nazioni[239] = "Svezia";
 $cod_nazioni[239] = "100000240";
 $cod2_nazioni[239] = "SE";
 $lista_nazioni[240] = "Slovenia";
 $cod_nazioni[240] = "100000251";
-$cod2_nazioni[240] = "SO.";
+$cod2_nazioni[240] = "SI.";
 $lista_nazioni[241] = "Sri Lanka - Ceylon";
 $cod_nazioni[241] = "100000311";
 $cod2_nazioni[241] = "LK";
@@ -677,6 +698,7 @@ $cod_nazioni[245] = "100000351";
 $cod2_nazioni[245] = "TR.";
 $lista_nazioni[246] = "Turks";
 $cod_nazioni[246] = "100000810";
+$cod2_nazioni[246] = "TC";
 $lista_nazioni[247] = "Sudan";
 $cod_nazioni[247] = "100000455";
 $cod2_nazioni[247] = "SD";
@@ -721,7 +743,7 @@ $cod2_nazioni[260] = "TV.";
 $lista_nazioni[261] = "Stati Uniti D'America";
 $cod_nazioni[261] = "100000536";
 $cod2_nazioni[261] = "US";
-$lista_nazioni[262] = "Timor";
+$lista_nazioni[262] = "Timor Est";
 $cod_nazioni[262] = "100000805";
 $cod2_nazioni[262] = "TL";
 $lista_nazioni[263] = "Transkei";
@@ -752,33 +774,23 @@ $cod2_nazioni[271] = "ZM";
 $lista_nazioni[272] = "Ucraina";
 $cod_nazioni[272] = "100000243";
 $cod2_nazioni[272] = "UA";
-$lista_nazioni[273] = "Yemen Rep. Dem. Popolare";
-$cod_nazioni[273] = "100000816";
-$cod2_nazioni[273] = "YE";
-$lista_nazioni[274] = "Zimbabwe";
-$cod_nazioni[274] = "100000465";
-$cod2_nazioni[274] = "ZW";
-$lista_nazioni[275] = "Zaire";
-$cod_nazioni[275] = "100000463";
-$lista_nazioni[276] = "Vanuatu";
-$cod_nazioni[276] = "100000732";
-$cod2_nazioni[276] = "VU";
-$lista_nazioni[277] = "Venezuela";
-$cod_nazioni[277] = "100000619";
-$cod2_nazioni[277] = "VE.";
-$lista_nazioni[278] = "Vietnam Del Nord";
-$cod_nazioni[278] = "100000813";
-$cod2_nazioni[278] = "VN";
-$lista_nazioni[279] = "Vietnam Del Sud";
-$cod_nazioni[279] = "100000814";
-$cod2_nazioni[279] = "VN";
-$lista_nazioni[280] = "Wallis";
-$cod_nazioni[280] = "100000815";
-$cod2_nazioni[280] = "WF";
-$lista_nazioni[281] = "Yemen";
-$cod_nazioni[281] = "100000354";
-$cod2_nazioni[281] = "YE";
-$lista_nazioni[282] = "Zanzibar";
-$cod_nazioni[282] = "100000817";
+$lista_nazioni[273] = "Zimbabwe";
+$cod_nazioni[273] = "100000465";
+$cod2_nazioni[273] = "ZW";
+$lista_nazioni[274] = "Zaire";
+$cod_nazioni[274] = "100000463";
+$cod2_nazioni[274] = "CD";
+$lista_nazioni[275] = "Vanuatu";
+$cod_nazioni[275] = "100000732";
+$cod2_nazioni[275] = "VU";
+$lista_nazioni[276] = "Venezuela";
+$cod_nazioni[276] = "100000619";
+$cod2_nazioni[276] = "VE.";
+$lista_nazioni[277] = "Wallis";
+$cod_nazioni[277] = "100000815";
+$cod2_nazioni[277] = "WF";
+$lista_nazioni[278] = "Yemen";
+$cod_nazioni[278] = "100000354";
+$cod2_nazioni[278] = "YE";
 
 ?>
\ No newline at end of file
