@@ -125,6 +125,10 @@ else $url_server = "http://".$SERVER_NAME;
 if (substr($PHP_SELF,0,1) != "/") $PHP_SELF = "/".$PHP_SELF;
 $url_dir = $url_server.$PHP_SELF;
 if (substr($url_dir,(strlen($pag) * -1)) == $pag) $url_dir = substr($url_dir,0,(strlen($pag) * -1));
+if (substr($url_dir,-4) == ".php") {
+$url_vett1 = explode("/",$url_dir);
+$url_dir = substr($url_dir,0,(strlen($url_vett1[(count($url_vett1) - 1)]) * -1));
+} # fine if (substr($url_dir,-4) == ".php")
 } # fine if (@$PHP_SELF or @$_SERVER['PHP_SELF'])
 } # fine if (@$SERVER_NAME or @$_SERVER['SERVER_NAME'] or...
 if ($url_dir) {
