@@ -93,177 +93,198 @@ $var_predef[66] = "tasse_sconto";
 $var_predef[67] = "tasse_sconto_p";
 $var_predef[68] = "sconto_senza_tasse";
 $var_predef[69] = "sconto_senza_tasse_p";
-$var_predef[70] = "nome_costo_agg";
-$var_predef[71] = "valore_costo_agg";
-$var_predef[72] = "valore_costo_agg_p";
-$var_predef[73] = "percentuale_tasse_costo_agg";
-$var_predef[74] = "tasse_costo_agg";
-$var_predef[75] = "tasse_costo_agg_p";
-$var_predef[76] = "valore_costo_agg_senza_tasse";
-$var_predef[77] = "valore_costo_agg_senza_tasse_p";
-$var_predef[78] = "valore_tutti_costi_agg";
-$var_predef[79] = "valore_tutti_costi_agg_p";
-$var_predef[80] = "tutti_i_costi_agg";
-$var_predef[81] = "tutti_i_costi_agg_p";
-$var_predef[82] = "nome_costo_agg_sel";
-$var_predef[83] = "valore_costo_agg_sel";
-$var_predef[84] = "valore_costo_agg_sel_p";
-$var_predef[85] = "percentuale_tasse_costo_agg_sel";
-$var_predef[86] = "tasse_costo_agg_sel";
-$var_predef[87] = "tasse_costo_agg_sel_p";
-$var_predef[88] = "num_costi_aggiuntivi";
-$var_predef[89] = "tutti_i_pagamenti";
-$var_predef[90] = "tutti_i_pagamenti_p";
-$var_predef[91] = "valore_ultimo_pagamento";
-$var_predef[92] = "valore_ultimo_pagamento_p";
-$var_predef[93] = "data_ultimo_pagamento";
-$var_predef[94] = "metodo_ultimo_pagamento";
-$var_predef[95] = "num_pagamenti";
-$var_predef[96] = "numero_prenotazione";
-$var_predef[97] = "numero_ripetizione_prenotazioni";
-$var_predef[98] = "codice_prenotazione";
-$var_predef[99] = "data_inserimento_prenotazione";
-$var_predef[100] = "numero_progressivo_documento";
-$var_predef[101] = "num_ospiti_tot";
-$var_predef[102] = "numero_ospite";
-$var_predef[103] = "cognome_ospite";
-$var_predef[104] = "nome_ospite";
-$var_predef[105] = "soprannome_ospite";
-$var_predef[106] = "titolo_ospite";
-$var_predef[107] = "sesso_ospite";
-$var_predef[108] = "cittadinanza_ospite";
-$var_predef[109] = "parentela_ospite";
-$var_predef[110] = "data_nascita_ospite";
-$var_predef[111] = "citta_nascita_ospite";
-$var_predef[112] = "regione_nascita_ospite";
-$var_predef[113] = "nazione_nascita_ospite";
-$var_predef[114] = "citta_ospite";
-$var_predef[115] = "regione_ospite";
-$var_predef[116] = "nazione_ospite";
-$var_predef[117] = "via_ospite";
-$var_predef[118] = "via2_ospite";
-$var_predef[119] = "numcivico_ospite";
-$var_predef[120] = "documento_ospite";
-$var_predef[121] = "tipo_documento_ospite";
-$var_predef[122] = "citta_documento_ospite";
-$var_predef[123] = "regione_documento_ospite";
-$var_predef[124] = "nazione_documento_ospite";
-$var_predef[125] = "scadenza_documento_ospite";
-$var_predef[126] = "telefono_ospite";
-$var_predef[127] = "telefono2_ospite";
-$var_predef[128] = "telefono3_ospite";
-$var_predef[129] = "fax_ospite";
-$var_predef[130] = "email_ospite";
-$var_predef[131] = "cap_ospite";
-$var_predef[132] = "codice_fiscale_ospite";
-$var_predef[133] = "partita_iva_ospite";
-$var_predef[134] = "costo_tot_somma_ripetizioni";
-$var_predef[135] = "costo_tot_somma_ripetizioni_p";
-$var_predef[136] = "caparra_somma_ripetizioni";
-$var_predef[137] = "caparra_somma_ripetizioni_p";
-$var_predef[138] = "resto_caparra_somma_ripetizioni";
-$var_predef[139] = "resto_caparra_somma_ripetizioni_p";
-$var_predef[140] = "pagato_somma_ripetizioni";
-$var_predef[141] = "pagato_somma_ripetizioni_p";
-$var_predef[142] = "resto_da_pagare_somma_ripetizioni";
-$var_predef[143] = "resto_da_pagare_somma_ripetizioni_p";
-$var_predef[144] = "num_persone_tot_somma_ripetizioni";
-$var_predef[145] = "codice_cittadinanza";
-$var_predef[146] = "codice_nazione_nascita";
-$var_predef[147] = "codice_regione_nascita";
-$var_predef[148] = "codice_citta_nascita";
-$var_predef[149] = "codice_nazione";
-$var_predef[150] = "codice_regione";
-$var_predef[151] = "codice_citta";
-$var_predef[152] = "codice_tipo_documento";
-$var_predef[153] = "codice_citta_documento";
-$var_predef[154] = "codice_regione_documento";
-$var_predef[155] = "codice_nazione_documento";
-$var_predef[156] = "codice2_cittadinanza";
-$var_predef[157] = "codice2_nazione_nascita";
-$var_predef[158] = "codice2_regione_nascita";
-$var_predef[159] = "codice2_citta_nascita";
-$var_predef[160] = "codice2_nazione";
-$var_predef[161] = "codice2_regione";
-$var_predef[162] = "codice2_citta";
-$var_predef[163] = "codice2_tipo_documento";
-$var_predef[164] = "codice2_citta_documento";
-$var_predef[165] = "codice2_regione_documento";
-$var_predef[166] = "codice2_nazione_documento";
-$var_predef[167] = "codice3_cittadinanza";
-$var_predef[168] = "codice3_nazione_nascita";
-$var_predef[169] = "codice3_regione_nascita";
-$var_predef[170] = "codice3_citta_nascita";
-$var_predef[171] = "codice3_nazione";
-$var_predef[172] = "codice3_regione";
-$var_predef[173] = "codice3_citta";
-$var_predef[174] = "codice3_tipo_documento";
-$var_predef[175] = "codice3_citta_documento";
-$var_predef[176] = "codice3_regione_documento";
-$var_predef[177] = "codice3_nazione_documento";
-$var_predef[178] = "codice_cittadinanza_ospite";
-$var_predef[179] = "codice_parentela_ospite";
-$var_predef[180] = "codice_nazione_nascita_ospite";
-$var_predef[181] = "codice_regione_nascita_ospite";
-$var_predef[182] = "codice_citta_nascita_ospite";
-$var_predef[183] = "codice_nazione_ospite";
-$var_predef[184] = "codice_regione_ospite";
-$var_predef[185] = "codice_citta_ospite";
-$var_predef[186] = "codice_tipo_documento_ospite";
-$var_predef[187] = "codice_citta_documento_ospite";
-$var_predef[188] = "codice_regione_documento_ospite";
-$var_predef[189] = "codice_nazione_documento_ospite";
-$var_predef[190] = "codice2_cittadinanza_ospite";
-$var_predef[191] = "codice2_parentela_ospite";
-$var_predef[192] = "codice2_nazione_nascita_ospite";
-$var_predef[193] = "codice2_regione_nascita_ospite";
-$var_predef[194] = "codice2_citta_nascita_ospite";
-$var_predef[195] = "codice2_nazione_ospite";
-$var_predef[196] = "codice2_regione_ospite";
-$var_predef[197] = "codice2_citta_ospite";
-$var_predef[198] = "codice2_tipo_documento_ospite";
-$var_predef[199] = "codice2_citta_documento_ospite";
-$var_predef[200] = "codice2_regione_documento_ospite";
-$var_predef[201] = "codice2_nazione_documento_ospite";
-$var_predef[202] = "codice3_cittadinanza_ospite";
-$var_predef[203] = "codice3_parentela_ospite";
-$var_predef[204] = "codice3_nazione_nascita_ospite";
-$var_predef[205] = "codice3_regione_nascita_ospite";
-$var_predef[206] = "codice3_citta_nascita_ospite";
-$var_predef[207] = "codice3_nazione_ospite";
-$var_predef[208] = "codice3_regione_ospite";
-$var_predef[209] = "codice3_citta_ospite";
-$var_predef[210] = "codice3_tipo_documento_ospite";
-$var_predef[211] = "codice3_citta_documento_ospite";
-$var_predef[212] = "codice3_regione_documento_ospite";
-$var_predef[213] = "codice3_nazione_documento_ospite";
-$var_predef[214] = "data_inizio_selezione";
-$var_predef[215] = "data_fine_selezione";
-$var_predef[216] = "oggi";
-$var_predef[217] = "nome_struttura";
-$var_predef[218] = "tipo_struttura";
-$var_predef[219] = "email_struttura";
-$var_predef[220] = "ragione_sociale_struttura";
-$var_predef[221] = "sito_web_struttura";
-$var_predef[222] = "nome_contatto_struttura";
-$var_predef[223] = "nazione_struttura";
-$var_predef[224] = "comune_struttura";
-$var_predef[225] = "indirizzo_struttura";
-$var_predef[226] = "CAP_struttura";
-$var_predef[227] = "telefono_struttura";
-$var_predef[228] = "fax_struttura";
-$var_predef[229] = "codice_fiscale_struttura";
-$var_predef[230] = "partita_iva_struttura";
-$var_predef[231] = "numero_stelle_struttura";
-$var_predef[232] = "nome_valuta";
-$var_predef[233] = "ritorno_a_capo";
-$var_predef[234] = "avanzamento_riga";
-$var_predef[235] = "email_gia_inviata";
-$var_predef[236] = "errore_ripetizione";
-$var_predef[237] = "messaggio_di_errore";
+$var_predef[70] = "costo_tariffa_giorno_array";
+$var_predef[71] = "costo_tariffa_giorno_array_p";
+$var_predef[72] = "nome_costo_agg";
+$var_predef[73] = "valore_costo_agg";
+$var_predef[74] = "valore_costo_agg_p";
+$var_predef[75] = "percentuale_tasse_costo_agg";
+$var_predef[76] = "tasse_costo_agg";
+$var_predef[77] = "tasse_costo_agg_p";
+$var_predef[78] = "valore_costo_agg_senza_tasse";
+$var_predef[79] = "valore_costo_agg_senza_tasse_p";
+$var_predef[80] = "moltiplica_max_costo_agg";
+$var_predef[81] = "data_inserimento_costo_agg";
+$var_predef[82] = "utente_inserimento_costo_agg";
+$var_predef[83] = "valore_tutti_costi_agg";
+$var_predef[84] = "valore_tutti_costi_agg_p";
+$var_predef[85] = "tutti_i_costi_agg";
+$var_predef[86] = "tutti_i_costi_agg_p";
+$var_predef[87] = "nome_costo_agg_sel";
+$var_predef[88] = "valore_costo_agg_sel";
+$var_predef[89] = "valore_costo_agg_sel_p";
+$var_predef[90] = "percentuale_tasse_costo_agg_sel";
+$var_predef[91] = "tasse_costo_agg_sel";
+$var_predef[92] = "tasse_costo_agg_sel_p";
+$var_predef[93] = "moltiplica_max_costo_agg_sel";
+$var_predef[94] = "num_costi_aggiuntivi";
+$var_predef[95] = "valore_pagamento";
+$var_predef[96] = "valore_pagamento_p";
+$var_predef[97] = "metodo_pagamento";
+$var_predef[98] = "data_pagamento";
+$var_predef[99] = "utente_pagamento";
+$var_predef[100] = "tutti_i_pagamenti";
+$var_predef[101] = "tutti_i_pagamenti_p";
+$var_predef[102] = "valore_ultimo_pagamento";
+$var_predef[103] = "valore_ultimo_pagamento_p";
+$var_predef[104] = "metodo_ultimo_pagamento";
+$var_predef[105] = "data_ultimo_pagamento";
+$var_predef[106] = "utente_ultimo_pagamento";
+$var_predef[107] = "num_pagamenti";
+$var_predef[108] = "numero_prenotazione";
+$var_predef[109] = "numero_ripetizione_prenotazioni";
+$var_predef[110] = "codice_prenotazione";
+$var_predef[111] = "data_inserimento_prenotazione";
+$var_predef[112] = "utente_inserimento_prenotazione";
+$var_predef[113] = "num_ospiti_tot";
+$var_predef[114] = "numero_ospite";
+$var_predef[115] = "cognome_ospite";
+$var_predef[116] = "nome_ospite";
+$var_predef[117] = "soprannome_ospite";
+$var_predef[118] = "titolo_ospite";
+$var_predef[119] = "sesso_ospite";
+$var_predef[120] = "cittadinanza_ospite";
+$var_predef[121] = "parentela_ospite";
+$var_predef[122] = "data_nascita_ospite";
+$var_predef[123] = "citta_nascita_ospite";
+$var_predef[124] = "regione_nascita_ospite";
+$var_predef[125] = "nazione_nascita_ospite";
+$var_predef[126] = "citta_ospite";
+$var_predef[127] = "regione_ospite";
+$var_predef[128] = "nazione_ospite";
+$var_predef[129] = "via_ospite";
+$var_predef[130] = "via2_ospite";
+$var_predef[131] = "numcivico_ospite";
+$var_predef[132] = "documento_ospite";
+$var_predef[133] = "tipo_documento_ospite";
+$var_predef[134] = "citta_documento_ospite";
+$var_predef[135] = "regione_documento_ospite";
+$var_predef[136] = "nazione_documento_ospite";
+$var_predef[137] = "scadenza_documento_ospite";
+$var_predef[138] = "telefono_ospite";
+$var_predef[139] = "telefono2_ospite";
+$var_predef[140] = "telefono3_ospite";
+$var_predef[141] = "fax_ospite";
+$var_predef[142] = "email_ospite";
+$var_predef[143] = "cap_ospite";
+$var_predef[144] = "codice_fiscale_ospite";
+$var_predef[145] = "partita_iva_ospite";
+$var_predef[146] = "numero_progressivo_documento";
+$var_predef[147] = "nome_unita";
+$var_predef[148] = "casa_unita";
+$var_predef[149] = "piano_unita";
+$var_predef[150] = "capacita_unita";
+$var_predef[151] = "priorita_unita";
+$var_predef[152] = "num_unita";
+$var_predef[153] = "costo_tot_somma_ripetizioni";
+$var_predef[154] = "costo_tot_somma_ripetizioni_p";
+$var_predef[155] = "caparra_somma_ripetizioni";
+$var_predef[156] = "caparra_somma_ripetizioni_p";
+$var_predef[157] = "resto_caparra_somma_ripetizioni";
+$var_predef[158] = "resto_caparra_somma_ripetizioni_p";
+$var_predef[159] = "pagato_somma_ripetizioni";
+$var_predef[160] = "pagato_somma_ripetizioni_p";
+$var_predef[161] = "resto_da_pagare_somma_ripetizioni";
+$var_predef[162] = "resto_da_pagare_somma_ripetizioni_p";
+$var_predef[163] = "num_persone_tot_somma_ripetizioni";
+$var_predef[164] = "codice_cittadinanza";
+$var_predef[165] = "codice_nazione_nascita";
+$var_predef[166] = "codice_regione_nascita";
+$var_predef[167] = "codice_citta_nascita";
+$var_predef[168] = "codice_nazione";
+$var_predef[169] = "codice_regione";
+$var_predef[170] = "codice_citta";
+$var_predef[171] = "codice_tipo_documento";
+$var_predef[172] = "codice_citta_documento";
+$var_predef[173] = "codice_regione_documento";
+$var_predef[174] = "codice_nazione_documento";
+$var_predef[175] = "codice2_cittadinanza";
+$var_predef[176] = "codice2_nazione_nascita";
+$var_predef[177] = "codice2_regione_nascita";
+$var_predef[178] = "codice2_citta_nascita";
+$var_predef[179] = "codice2_nazione";
+$var_predef[180] = "codice2_regione";
+$var_predef[181] = "codice2_citta";
+$var_predef[182] = "codice2_tipo_documento";
+$var_predef[183] = "codice2_citta_documento";
+$var_predef[184] = "codice2_regione_documento";
+$var_predef[185] = "codice2_nazione_documento";
+$var_predef[186] = "codice3_cittadinanza";
+$var_predef[187] = "codice3_nazione_nascita";
+$var_predef[188] = "codice3_regione_nascita";
+$var_predef[189] = "codice3_citta_nascita";
+$var_predef[190] = "codice3_nazione";
+$var_predef[191] = "codice3_regione";
+$var_predef[192] = "codice3_citta";
+$var_predef[193] = "codice3_tipo_documento";
+$var_predef[194] = "codice3_citta_documento";
+$var_predef[195] = "codice3_regione_documento";
+$var_predef[196] = "codice3_nazione_documento";
+$var_predef[197] = "codice_cittadinanza_ospite";
+$var_predef[198] = "codice_parentela_ospite";
+$var_predef[199] = "codice_nazione_nascita_ospite";
+$var_predef[200] = "codice_regione_nascita_ospite";
+$var_predef[201] = "codice_citta_nascita_ospite";
+$var_predef[202] = "codice_nazione_ospite";
+$var_predef[203] = "codice_regione_ospite";
+$var_predef[204] = "codice_citta_ospite";
+$var_predef[205] = "codice_tipo_documento_ospite";
+$var_predef[206] = "codice_citta_documento_ospite";
+$var_predef[207] = "codice_regione_documento_ospite";
+$var_predef[208] = "codice_nazione_documento_ospite";
+$var_predef[209] = "codice2_cittadinanza_ospite";
+$var_predef[210] = "codice2_parentela_ospite";
+$var_predef[211] = "codice2_nazione_nascita_ospite";
+$var_predef[212] = "codice2_regione_nascita_ospite";
+$var_predef[213] = "codice2_citta_nascita_ospite";
+$var_predef[214] = "codice2_nazione_ospite";
+$var_predef[215] = "codice2_regione_ospite";
+$var_predef[216] = "codice2_citta_ospite";
+$var_predef[217] = "codice2_tipo_documento_ospite";
+$var_predef[218] = "codice2_citta_documento_ospite";
+$var_predef[219] = "codice2_regione_documento_ospite";
+$var_predef[220] = "codice2_nazione_documento_ospite";
+$var_predef[221] = "codice3_cittadinanza_ospite";
+$var_predef[222] = "codice3_parentela_ospite";
+$var_predef[223] = "codice3_nazione_nascita_ospite";
+$var_predef[224] = "codice3_regione_nascita_ospite";
+$var_predef[225] = "codice3_citta_nascita_ospite";
+$var_predef[226] = "codice3_nazione_ospite";
+$var_predef[227] = "codice3_regione_ospite";
+$var_predef[228] = "codice3_citta_ospite";
+$var_predef[229] = "codice3_tipo_documento_ospite";
+$var_predef[230] = "codice3_citta_documento_ospite";
+$var_predef[231] = "codice3_regione_documento_ospite";
+$var_predef[232] = "codice3_nazione_documento_ospite";
+$var_predef[233] = "data_inizio_selezione";
+$var_predef[234] = "data_fine_selezione";
+$var_predef[235] = "oggi";
+$var_predef[236] = "utente_attuale";
+$var_predef[237] = "nome_struttura";
+$var_predef[238] = "tipo_struttura";
+$var_predef[239] = "email_struttura";
+$var_predef[240] = "ragione_sociale_struttura";
+$var_predef[241] = "sito_web_struttura";
+$var_predef[242] = "nome_contatto_struttura";
+$var_predef[243] = "nazione_struttura";
+$var_predef[244] = "comune_struttura";
+$var_predef[245] = "indirizzo_struttura";
+$var_predef[246] = "CAP_struttura";
+$var_predef[247] = "telefono_struttura";
+$var_predef[248] = "fax_struttura";
+$var_predef[249] = "codice_fiscale_struttura";
+$var_predef[250] = "partita_iva_struttura";
+$var_predef[251] = "numero_stelle_struttura";
+$var_predef[252] = "logo_struttura";
+$var_predef[253] = "nome_valuta";
+$var_predef[254] = "ritorno_a_capo";
+$var_predef[255] = "avanzamento_riga";
+$var_predef[256] = "email_gia_inviata";
+$var_predef[257] = "errore_ripetizione";
+$var_predef[258] = "messaggio_di_errore";
 
 $num_var_predef = count($var_predef);
-$num_var_non_ripeti = 104;
+$num_var_non_ripeti = 113;
 $num_var_predef_ripeti = $num_var_predef - $num_var_non_ripeti;
 
 
@@ -274,7 +295,9 @@ $var_predef_data['data_nascita'] = 1;
 $var_predef_data['scadenza_documento'] = 1;
 $var_predef_data['data_inizio'] = 1;
 $var_predef_data['data_fine'] = 1;
+$var_predef_data['data_pagamento'] = 1;
 $var_predef_data['data_ultimo_pagamento'] = 1;
+$var_predef_data['data_inserimento_costo_agg'] = 1;
 $var_predef_data['data_inserimento_prenotazione'] = 1;
 $var_predef_data['data_nascita_ospite'] = 1;
 $var_predef_data['scadenza_documento_ospite'] = 1;
@@ -324,6 +347,7 @@ $var_riserv['stile_soldi'] = 1;
 $var_riserv['stile_data'] = 1;
 $var_riserv['id_utente'] = 1;
 $var_riserv['num_prog_contr'] = 1;
+$var_riserv['num_prog_contr_max'] = 1;
 $var_riserv['sovrascrivi'] = 1;
 $var_riserv['num_file_salva'] = 1;
 $var_riserv['lista_var_form'] = 1;
@@ -430,6 +454,11 @@ $var_riserv['apartment'] = 1;
 $var_riserv['apartment_list'] = 1;
 $var_riserv['apartamento'] = 1;
 $var_riserv['lista_apartamentos'] = 1;
+$var_riserv['n_utente_contr'] = 1;
+$var_riserv['dati_app_contr'] = 1;
+$var_riserv['tariffesettimanali'] = 1;
+$var_riserv['incr_np'] = 1;
+$var_riserv['filelock'] = 1;
 
 
 
