@@ -509,6 +509,7 @@ echo "<table class=\"t1\" style=\"background-color: $t1color; margin-left: auto;
 <td><small><small>".str_replace(" ","&nbsp;",mex("Da pagare",$pag))."</small></small></td>
 <td><small><small>$fr_Appartamento</small></small></td>
 <td><small><small>".mex("Pers",$pag).".</small></small></td>
+<td><small><small>".mex("Promemoria",$pag)."</small></small></td>
 <td colspan=2>".mex("Registra",$pag)."</td></tr>";
 
 for ($num1 = 0 ; $num1 < $num_prenotazioni ; $num1++) {
@@ -588,6 +589,13 @@ else $stima_checkin = " <small><small>($stima_checkin)</small></small>";
 $checkout = "";
 } # fine if ($checkout and !$checkin)
 else $stima_checkin = "";
+$promemoria = "&nbsp;";
+$commento = risul_query($prenotazioni,$num1,'commento');
+if (strstr($commento,">")) {
+$commento = explode(">",$commento);
+if (!$checkin and strcmp($commento[1],"")) $promemoria = "<small><small>".$commento[1]."</small></small>";
+if ($checkin and !$checkout and strcmp($commento[2],"")) $promemoria = "<small><small>".$commento[2]."</small></small>";
+} # fine if (strstr($commento,">"))
 $data_inserimento = risul_query($prenotazioni,$num1,'datainserimento');
 $host_inserimento = risul_query($prenotazioni,$num1,'hostinserimento');
 
@@ -601,11 +609,14 @@ echo "<td>$cognome</td>
 <td>$costo_tot_p</td>
 <td";
 if ($colore) echo " style=\"background-color: $colore;\"";
-echo ">$da_pagare_p</td>
-<td>$appartamento</td>
-<td>$num_persone";
+echo ">$da_pagare_p</td>";
+if (strlen($appartamento) > 6) echo "<td><small>$appartamento</small></td>";
+else echo "<td>$appartamento</td>";
+echo "<td>$num_persone";
 if ($n_letti_agg != 0) { echo "+$n_letti_agg"; }
-echo "</td>";
+echo "</td>
+<td>$promemoria</td>";
+
 if ($link_modifica == "SI" and $priv_mod_checkin == "s") {
 echo "<td valign=\"middle\"";
 if (!$colore or $priv_mod_pagato != "s") echo " colspan=2";
