@@ -48,7 +48,7 @@ else include("./includes/head.php");
 
 
 
-$idappartamenti = htmlspecialchars($idappartamenti);
+if (!$url_enc) $idappartamenti = htmlspecialchars($idappartamenti);
 $idappartamenti = aggslashdb($idappartamenti);
 
 if ($cancella_app) {
@@ -335,7 +335,7 @@ $n_maxoccupanti = ${"n_maxoccupanti".$num1};
 $n_priorita = ${"n_priorita".$num1};
 $n_app_vicini = ${"n_app_vicini".$num1};
 ${"d_app_vicini".$num1} = esegui_query("select app_vicini from $tableappartamenti where idappartamenti = '$idappartamenti' ");
-${"d_app_vicini".$num1} = risul_query(${"d_app_vicini".$num1},0,'app_vicini');
+if (numlin_query(${"d_app_vicini".$num1})) ${"d_app_vicini".$num1} = risul_query(${"d_app_vicini".$num1},0,'app_vicini');
 
 if ($cambia_nome_app and $modificaappartamento == "Continua") {
 $anni_esistenti2 = esegui_query("select * from $tableanni order by idanni");
@@ -630,7 +630,10 @@ echo "<input class=\"sbutton\" type=\"submit\" name=\"torna\" value=\"".mex("Tor
 if ($modificadescr) {
 $mostra_form_modifica = "NO";
 $tabelle_lock = array($tabledescrizioni);
-$tabelle_lock = lock_tabelle($tabelle_lock);
+$altre_tab_lock = array($tableappartamenti);
+$tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
+$app_esist = esegui_query("select idappartamenti from $tableappartamenti where idappartamenti = '$idappartamenti' ");
+if (numlin_query($app_esist)) {
 if (strcmp($n_descrizione_ita,"")) {
 if (get_magic_quotes_gpc()) $n_descrizione_ita = stripslashes($n_descrizione_ita);
 $n_descrizione_ita = aggslashdb(htmlspecialchars($n_descrizione_ita));
@@ -656,6 +659,7 @@ else esegui_query("delete from $tabledescrizioni where nome = '$idappartamenti'
 } # fine while ($file = readdir($lang_dig))
 closedir($lang_dir);
 echo "<br>".ucfirst(mex("descrizione dell'appartamento",'unit.php'))." $idappartamenti ".mex("aggiornata",$pag).".<br>";
+} # fine if (numlin_query($app_esist))
 unlock_tabelle($tabelle_lock);
 $mostra_torna_indietro = "SI";
 } # fine if ($modificadescr)
@@ -663,7 +667,8 @@ $mostra_torna_indietro = "SI";
 
 if ($commentofoto) {
 $mostra_form_modifica = "NO";
-if ($numfoto and controlla_num_pos($numfoto) == "SI") {
+$app_esist = esegui_query("select idappartamenti from $tableappartamenti where idappartamenti = '$idappartamenti' ");
+if ($numfoto and controlla_num_pos($numfoto) == "SI" and numlin_query($app_esist)) {
 $tabelle_lock = array($tabledescrizioni);
 $tabelle_lock = lock_tabelle($tabelle_lock);
 $foto_esistente = esegui_query("select testo from $tabledescrizioni where nome = '$idappartamenti' and tipo = 'appfoto' and numero = '$numfoto' ");
@@ -695,7 +700,7 @@ closedir($lang_dir);
 echo "<br>".ucfirst(mex("commento della foto",$pag))." $numfoto ".mex("aggiornato",$pag).".<br>";
 } # fine if (numlin_query($foto_esistente))
 unlock_tabelle($tabelle_lock);
-} # fine if ($numfoto and controlla_num_pos($numfoto) == "SI") 
+} # fine if ($numfoto and controlla_num_pos($numfoto) == "SI" and...
 $mostra_torna_indietro = "SI";
 } # fine if ($commentofoto)
 
@@ -716,6 +721,8 @@ if (get_magic_quotes_gpc()) $n_urlfoto = stripslashes($n_urlfoto);
 $lowurl = strtolower($n_urlfoto);
 if (substr($lowurl,-4) != ".jpg" and substr($lowurl,-5) != ".jpeg" and substr($lowurl,-4) != ".gif" and substr($lowurl,-4) != ".png") $errore = "SI";
 if (str_replace("<","",$n_urlfoto) != $n_urlfoto or str_replace(">","",$n_urlfoto) != $n_urlfoto or str_replace("\"","",$n_urlfoto) != $n_urlfoto) $errore = "SI";
+$app_esist = esegui_query("select idappartamenti from $tableappartamenti where idappartamenti = '$idappartamenti' ");
+if (!numlin_query($app_esist)) $errore = "SI";
 if ($errore != "SI") {
 $tabelle_lock = array($tabledescrizioni);
 $tabelle_lock = lock_tabelle($tabelle_lock);
@@ -752,12 +759,14 @@ if ($mostra_form_modifica != "NO") {
 echo "<h3>".mex("Modifica l'appartamento",'unit.php')." $idappartamenti.</h3>";
 
 $appartamento = esegui_query("select * from $tableappartamenti where idappartamenti = '$idappartamenti'");
+if (numlin_query($appartamento)) {
 $d_numcasa = risul_query($appartamento,0,'numcasa');
 $d_numpiano = risul_query($appartamento,0,'numpiano');
 $d_maxoccupanti = risul_query($appartamento,0,'maxoccupanti');
 $d_priorita = risul_query($appartamento,0,'priorita');
 $d_app_vicini = risul_query($appartamento,0,'app_vicini');
 $d_commento = risul_query($appartamento,0,'commento');
+} # fine if (numlin_query($appartamento))
 
 echo "<br>
 <form accept-charset=\"utf-8\" method=\"post\" action=\"modifica_app.php\"><div>
