@@ -734,7 +734,7 @@ $mostra_form_modifica_cliente = "NO";
 $tipo_transazione = "";
 if ($id_transazione) recupera_dati_transazione($id_transazione,$id_sessione,$anno,"SI",$tipo_transazione);
 if ($tipo_transazione == "mo_cc") {
-$tabelle_lock = array("$tablerelclienti");
+$tabelle_lock = array($tablerelclienti);
 $tabelle_lock = lock_tabelle($tabelle_lock);
 
 if ($cancella_cc) {
@@ -804,8 +804,8 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div>
 } # fine if (!$pass_cc)
 else {
 
-$tabelle_lock = array("$tableversioni","$tabletransazioni");
-$altre_tab_lock = array("$tablepersonalizza");
+$tabelle_lock = array($tableversioni,$tabletransazioni);
+$altre_tab_lock = array($tablepersonalizza);
 $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
 $adesso = date("YmdHis",(time() + (C_DIFF_ORE * 3600)));
 list($usec, $sec) = explode(' ', microtime());
