@@ -123,7 +123,7 @@ else $vecchio_multi_lingua = 0;
 $vecchio_formato = risul_query($vecchio_formato,0,'tipo');
 if ($vecchio_formato != $formato) {
 if ($vecchio_formato == "contreml") {
-esegui_query("delete from $tablecontratti where numero = '$num_contratto' and tipo = 'oggetto'");
+esegui_query("delete from $tablecontratti where numero = '$num_contratto' and tipo = 'oggetto' ");
 $num_all = esegui_query("select * from $tablecontratti where numero = '$num_contratto' and tipo = 'allegato'");
 $num_all = risul_query($num_all,0,'testo');
 esegui_query("delete from $tablecontratti where numero = '$num_contratto' and tipo = 'allegato'");
@@ -136,6 +136,7 @@ echo "".mex("Allegato eliminato",$pag).".<br>";
 } # fine if ($num_all)
 esegui_query("delete from $tablecontratti where numero = '$num_contratto' and tipo = 'opzeml'");
 } # fine if ($vecchio_formato == "contreml")
+if ($vecchio_formato == "contrhtm") esegui_query("delete from $tablecontratti where numero = '$num_contratto' and (tipo = 'headhtm' or tipo = 'foothtm') ");
 if ($formato == "contreml") {
 esegui_query("delete from $tablecontratti where numero = '$num_contratto' and tipo = 'dir'");
 esegui_query("insert into $tablecontratti (numero,tipo,testo) values ('$num_contratto','oggetto','') ");
@@ -205,7 +206,7 @@ esegui_query("insert into $tablecontratti (numero,tipo,testo) values ('$num_cont
 echo "".mex("I documenti verranno salvati nella cartella",$pag)." $dir_salva.<br>";
 } # fine if ($salva_contr == "SI")
 else {
-esegui_query("delete from $tablecontratti where numero = '$num_contratto' and (tipo = 'dir' or tipo = 'num_prog' or tipo = 'nomefile' or tipo = 'compress' or tipo = 'autosalv') ");
+esegui_query("delete from $tablecontratti where numero = '$num_contratto' and (tipo = 'dir' or tipo = 'num_prog' or tipo = 'nomefile' or tipo = 'compress' or tipo = 'autosalv' or tipo = 'incr_np') ");
 esegui_query("delete from $tablecontratti where testo = '$num_contratto_int' and tipo = 'num_prog' ");
 echo "".mex("I documenti non verranno salvati",$pag).".<br>";
 } # fine else if ($salva_contr == "SI")
@@ -263,6 +264,26 @@ echo ".<br>";
 unlock_tabelle($tabelle_lock);
 } # fine if ($cambia_autosalv)
 
+if ($cambia_incr_np) {
+$tabelle_lock = array($tablecontratti);
+$tabelle_lock = lock_tabelle($tabelle_lock);
+$dir_esistente = esegui_query("select * from $tablecontratti where numero = '$num_contratto' and tipo = 'dir'");
+if (numlin_query($dir_esistente)) {
+$mostra_form_iniziale = "NO";
+if (!$incr_np) {
+esegui_query("delete from $tablecontratti where numero = '$num_contratto' and tipo = 'incr_np' ");
+echo "".mex("Ogni documento avrà un unico numero progressivo",$pag).".<br>";
+} # fine if (!$incr_np)
+else {
+$incr_np_esistente = esegui_query("select testo from $tablecontratti where numero = '$num_contratto' and tipo = 'incr_np' ");
+if (numlin_query($incr_np_esistente)) esegui_query("update $tablecontratti set testo = '1' where numero = '$num_contratto' and tipo = 'incr_np' ");
+else esegui_query("insert into $tablecontratti (numero,tipo,testo) values ('$num_contratto','incr_np','1') ");
+echo "".mex("Il numero progressivo verrà incrementato ogni volta che compare nel documento",$pag).".<br>";
+} # fine else if (!$incr_np)
+} # fine if (numlin_query($dir_esistente))
+unlock_tabelle($tabelle_lock);
+} # fine if ($cambia_incr_np)
+
 if ($cambia_num_prog) {
 $tabelle_lock = array($tablecontratti);
 $tabelle_lock = lock_tabelle($tabelle_lock);
@@ -321,6 +342,25 @@ echo "".mex("I file verranno salvati con il nome",$pag)." \"$nome_file_salva\".<
 unlock_tabelle($tabelle_lock);
 } # fine if ($cambia_nome_file)
 
+if ($cambia_intestazione_pers) {
+$tipo_contratto = esegui_query("select tipo from $tablecontratti where numero = '$num_contratto' and tipo $LIKE 'contr%'");
+$tipo_contratto = risul_query($tipo_contratto,0,'tipo');
+if ($tipo_contratto == "contrhtm") {
+$intestazione_html = esegui_query("select * from $tablecontratti where numero = '$num_contratto' and tipo = 'headhtm'");
+if (numlin_query($intestazione_html) == 1) $intestazione_html = 1;
+else $intestazione_html = 0;
+if (($intestazione_html and !$intestazione_pers) or (!$intestazione_html and $intestazione_pers)) {
+$mostra_form_iniziale = "NO";
+if ($intestazione_html) esegui_query("delete from $tablecontratti where numero = '$num_contratto' and (tipo = 'headhtm' or tipo = 'foothtm') ");
+else {
+esegui_query("insert into $tablecontratti (numero,tipo,testo) values ('$num_contratto','headhtm','<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN\" \"http://www.w3.org/TR/html4/strict.dtd\">\n<html>\n<head>\n<meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\" >\n<title>".mex("documento",$pag)." $num_contratto</title>\n</head>\n<body style=\"background-color: #ffffff;\">\n') ");
+esegui_query("insert into $tablecontratti (numero,tipo,testo) values ('$num_contratto','foothtm','</body>\n</html>\n') ");
+} # fine else if ($intestazione_html)
+echo "".mex("Intestazione html cambiata",$pag).".<br>";
+} # fine if (($intestazione_html and !$intestazione_pers) or...
+} # fine if ($tipo_contratto == "contrhtm")
+} # fine if ($cambia_intestazione_pers)
+
 if ($cambia_oggetto) {
 if (@get_magic_quotes_gpc()) $nuovo_oggetto = stripslashes($nuovo_oggetto);
 if (strlen($nuovo_oggetto) > 120) $nuovo_oggetto = substr($nuovo_oggetto,0,120);
@@ -467,6 +507,20 @@ esegui_query("update $tablecontratti set testo = '#!mln!#$lingua_contr' where nu
 unlock_tabelle($tabelle_lock);
 } # fine if ($lingua_predef)
 
+if ($salva_head) {
+$tabelle_lock = array($tablecontratti);
+$tabelle_lock = lock_tabelle($tabelle_lock);
+$vecchio_head = esegui_query("select numero from $tablecontratti where numero = '$num_contratto' and tipo = 'headhtm' ");
+if (numlin_query($vecchio_head)) {
+$mostra_form_iniziale = "NO";
+if (@get_magic_quotes_gpc()) $n_head = stripslashes($n_head);
+$n_head = aggslashdb($n_head);
+esegui_query("update $tablecontratti set testo = '$n_head' where numero = '$num_contratto' and tipo = 'headhtm' ");
+echo "".mex("Intestazione html cambiata",$pag).".<br>";
+} # fine if (numlin_query($vecchio_head))
+unlock_tabelle($tabelle_lock);
+} # fine if ($salva_head)
+
 if ($salva_modifiche) {
 $mostra_form_iniziale = "NO";
 $errore = "NO";
@@ -500,14 +554,18 @@ if (substr($parte,0,2) == "r]") $apertura = "r";
 if (substr($parte,0,3) == "r2]") $apertura = "r2";
 if (substr($parte,0,3) == "r3]") $apertura = "r3";
 if (substr($parte,0,3) == "r4]") $apertura = "r4";
+if (substr($parte,0,3) == "r5]") $apertura = "r5";
+if (substr($parte,0,3) == "r6]") $apertura = "r6";
 if (substr($parte,0,3) == "/r]") $chiusura = "r";
 if (substr($parte,0,4) == "/r2]") $chiusura = "r2";
 if (substr($parte,0,4) == "/r3]") $chiusura = "r3";
 if (substr($parte,0,4) == "/r4]") $chiusura = "r4";
+if (substr($parte,0,4) == "/r5]") $chiusura = "r5";
+if (substr($parte,0,4) == "/r6]") $chiusura = "r6";
 if ($apertura) {
-if ($apertura == "r" and $livello != 0 and ($livello != 1 or $tipo_livello[1] != "r4" or $tipo_livello[0] == "r")) $errore = "SI";
-if (($apertura == "r2" or $apertura == "r3") and $tipo_livello[$livello] != "r") $errore = "SI";
-if ($apertura == "r4" and $tipo_livello[$livello] != "r" and $livello != 0 and ($livello != 1 or $tipo_livello[1] != "r4" or $tipo_livello[0] == "r")) $errore = "SI";
+if ($apertura == "r" and $livello != 0 and ($livello != 1 or ($tipo_livello[1] != "r4" and $tipo_livello[1] != "r6") or $tipo_livello[0] == "r")) $errore = "SI";
+if (($apertura == "r2" or $apertura == "r3" or $apertura == "r5") and $tipo_livello[$livello] != "r") $errore = "SI";
+if (($apertura == "r4" or $apertura == "r6") and $tipo_livello[$livello] != "r" and $livello != 0 and ($livello != 1 or ($tipo_livello[1] != "r4" and $tipo_livello[1] != "r6") or $tipo_livello[0] == "r")) $errore = "SI";
 $livello++;
 $tipo_livello[$livello] = $apertura;
 } # fine ($apertura)
@@ -585,11 +643,21 @@ $testo_agg1 = "[r4 array=\"".substr($tipo_rip,1)."\"]";
 $testo_agg2 = "\n".mex("SOSTITUISCI CON PARTE DA RIPETERE PER OGNI VALORE DELL'ARRAY",$pag)."\n";
 $testo_agg3 = "[/r4]";
 } # fine if (substr($tipo_rip,0,1) == "a")
-if ($tipo_rip == 4) {
+if ($tipo_rip == 5) {
+$testo_agg1 = "[r5]";
+$testo_agg2 = "\n".mex("SOSTITUISCI CON LISTA PAGAMENTI",$pag)."\n";
+$testo_agg3 = "[/r5]";
+} # fine if ($tipo_rip == 5)
+if ($tipo_rip == 6) {
+$testo_agg1 = "[r6]";
+$testo_agg2 = "\n".mex("SOSTITUISCI CON LISTA APPARTAMENTI",'unit.php')."\n";
+$testo_agg3 = "[/r6]";
+} # fine if ($tipo_rip == 6)
+if ($tipo_rip == 7) {
 $testo_agg1 = "[c ".mex("nome_variabile",$pag)."=\"".mex("valore",$pag)."\"]";
 $testo_agg2 = "\n".mex("SOSTITUISCI CON PARTE DA MOSTRARE SOLO SE E' SODDISFATTA LA CONDIZIONE PRECEDENTE",$pag)." (".mex("nome_variabile",$pag)." = ".mex("OPPURE",$pag)." != ".mex("valore",$pag).")\n";
 $testo_agg3 = "[/c]";
-} # fine if ($tipo_rip == 4)
+} # fine if ($tipo_rip == 7)
 if (!strcmp($pos_curs,"")) $testo_contratto_mod = $n_contratto.$testo_agg1.$testo_agg2.$testo_agg3;
 else {
 $pos_curs = strlen(utf8_encode(substr(utf8_decode($n_contratto),0,$pos_curs)));
@@ -601,6 +669,20 @@ $testo_contratto_mod = substr($n_contratto,0,$pos_curs).$testo_agg1.substr($n_co
 } # fine else if (!strcmp($pos_curs,""))
 } # fine if ($aggiungi_ripetizione or $aggiungi_ripetizione2)
 
+if ($salva_foot) {
+$tabelle_lock = array($tablecontratti);
+$tabelle_lock = lock_tabelle($tabelle_lock);
+$vecchio_foot = esegui_query("select numero from $tablecontratti where numero = '$num_contratto' and tipo = 'foothtm' ");
+if (numlin_query($vecchio_foot)) {
+$mostra_form_iniziale = "NO";
+if (@get_magic_quotes_gpc()) $n_foot = stripslashes($n_foot);
+$n_foot = aggslashdb($n_foot);
+esegui_query("update $tablecontratti set testo = '$n_foot' where numero = '$num_contratto' and tipo = 'foothtm' ");
+echo "".mex("Chiusura html cambiata",$pag).".<br>";
+} # fine if (numlin_query($vecchio_foot))
+unlock_tabelle($tabelle_lock);
+} # fine if ($salva_foot)
+
 
 if ($mostra_form_iniziale == "NO") {
 echo "<br><form accept-charset=\"utf-8\" method=\"post\" action=\"$pag$anchor\"><div>
@@ -638,13 +720,26 @@ echo "<h3>".ucfirst(mex("documento",$pag))." $num_contratto$nome_contratto</h3><
 $dati_contratto = esegui_query("select * from $tablecontratti where numero = '$num_contratto' and tipo $LIKE 'contr%'");
 if (numlin_query($dati_contratto) != 1) exit();
 
-echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"visualizza_contratto.php\"><div>
+echo "<table><tr><td><form accept-charset=\"utf-8\" method=\"post\" action=\"visualizza_contratto.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"numero_contratto\" value=\"$num_contratto\">
 <input type=\"hidden\" name=\"origine\" value=\"./$pag?num_contratto=$num_contratto\">
-<input class=\"sbutton\" type=\"submit\" name=\"torna\" value=\"".mex("Visualizza il documento",$pag)."\">
-</div></form><br>";
+<input class=\"sbutton\" type=\"submit\" name=\"torna\" value=\"".mex("Visualizza il documento",$pag)." $num_contratto_int\">
+</div></form></td><td style=\"width: 30px;\"></td>";
+if ($max_contr > 1) {
+echo "<td><form accept-charset=\"utf-8\" method=\"post\" action=\"./personalizza.php\"><div>
+<input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
+<input type=\"hidden\" name=\"id_utente_mod\" value=\"$id_utente_mod\">
+<input type=\"hidden\" name=\"aggiorna_qualcosa\" value=\"SI\">
+<input type=\"hidden\" name=\"elimina_contratto\" value=\"SI\">
+<input type=\"hidden\" name=\"num_contr_elimina\" value=\"$num_contratto_int\">
+<input type=\"hidden\" name=\"origine\" value=\"./$pag?num_contratto=$num_contratto\">
+<input class=\"sbutton\" type=\"submit\" value=\"".mex("Elimina il documento",'personalizza.php')." $num_contratto_int\">
+</div></form></td>";
+} # fine if ($max_contr > 1)
+echo "</tr></table><br>";
 
 $tipo_contratto = substr(risul_query($dati_contratto,0,'tipo'),5);
 $testo_contratto = risul_query($dati_contratto,0,'testo');
@@ -744,6 +839,22 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div>
 <input class=\"sbutton\" type=\"submit\" value=\"".mex("Cambia",$pag)."\">
 </div></form>";
 
+$incr_np = esegui_query("select * from $tablecontratti where numero = '$num_contratto' and tipo = 'incr_np' ");
+if (!numlin_query($incr_np)) $incr_np = "";
+else $incr_np = risul_query($incr_np,0,'testo');
+if ($incr_np) $checked = " checked";
+else $checked = "";
+echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div>
+<input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
+<input type=\"hidden\" name=\"num_contratto\" value=\"$num_contratto\">
+<input type=\"hidden\" name=\"cambia_qualcosa\" value=\"SI\">
+<input type=\"hidden\" name=\"cambia_incr_np\" value=\"SI\">
+<label><input type=\"checkbox\" name=\"incr_np\" value=\"SI\"$checked>
+".mex("Incrementa il numero progressivo ad ogni sua apparizione",$pag)."</label>
+<input class=\"sbutton\" type=\"submit\" value=\"".mex("Cambia",$pag)."\">
+</div></form>";
+
 $num_prog = esegui_query("select * from $tablecontratti where numero = '$num_contratto' and tipo = 'num_prog' ");
 if (!numlin_query($num_prog)) $num_prog = "";
 else $num_prog = risul_query($num_prog,0,'testo');
@@ -813,6 +924,29 @@ echo "<br>";
 } # fine if ($tipo_contratto == "rtf" or $tipo_contratto == "htm" or...
 
 
+$contr_head = "";
+$contr_foot = "";
+if ($tipo_contratto == "htm") {
+$intestazione_html = esegui_query("select * from $tablecontratti where numero = '$num_contratto' and tipo = 'headhtm'");
+if (numlin_query($intestazione_html) == 1) $checked = " checked";
+else $checked = "";
+echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div>
+<input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
+<input type=\"hidden\" name=\"num_contratto\" value=\"$num_contratto\">
+<input type=\"hidden\" name=\"cambia_qualcosa\" value=\"SI\">
+<label><input type=\"checkbox\" name=\"intestazione_pers\" value=\"SI\"$checked>
+".mex("Intestazione html personalizzata",$pag)."</label>
+<input class=\"sbutton\" type=\"submit\" name=\"cambia_intestazione_pers\" value=\"".mex("Cambia",$pag)."\">
+</div></form><br>";
+if ($checked) {
+$contr_head = risul_query($intestazione_html,0,'testo');
+$contr_foot = esegui_query("select * from $tablecontratti where numero = '$num_contratto' and tipo = 'foothtm'");
+$contr_foot = risul_query($contr_foot,0,'testo');
+} # fine if ($checked)
+} # fine if ($tipo_contratto == "htm")
+
+
 if ($tipo_contratto == "eml") {
 $oggetto = esegui_query("select * from $tablecontratti where numero = '$num_contratto' and tipo = 'oggetto'");
 $oggetto = risul_query($oggetto,0,'testo');
@@ -943,14 +1077,28 @@ $lingue['nome'][$num_lingue] = ucfirst(trim(implode("",file("./includes/lang/$in
 closedir($lang_dir);
 $num_lingue++;
 } # fine if ($multilingua)
-else $num_lingue = 1;
+else {
+$num_lingue = 1;
+echo mex("Modifica il documento",$pag).":<br>";
+} # fine else if ($multilingua) 
+
+
+if ($contr_head) {
+echo "<br><form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div style=\"text-align: center;\">
+<input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
+<input type=\"hidden\" name=\"num_contratto\" value=\"$num_contratto\">
+<input type=\"hidden\" name=\"cambia_qualcosa\" value=\"SI\">
+<input class=\"sbutton\" type=\"submit\" name=\"salva_head\" value=\"".mex("Modifica l'intestazione html",$pag)."\"><br>
+<textarea id=\"contr_head\" name=\"n_head\" rows=8 cols=135 style=\"white-space: pre; overflow: auto;\">".htmlspecialchars($contr_head)."</textarea>
+</div></form><br>";
+} # fine if ($contr_head)
+
 
 for ($num_lingua = 0 ; $num_lingua < $num_lingue ; $num_lingua++) {
 
-
 if ($num_lingua > 0) echo "<br><br>";
-if (!$multilingua) echo mex("Modifica il documento",$pag).":<br>";
-else {
+if ($multilingua) {
 $testo_contratto = esegui_query("select * from $tablecontratti where numero = '$num_contratto' and tipo = 'mln_".$lingue[$num_lingua]."'");
 if (numlin_query($testo_contratto)) $testo_contratto = risul_query($testo_contratto,0,'testo');
 else $testo_contratto = "";
@@ -965,7 +1113,7 @@ echo mex("Modifica il documento",$pag)."";
 echo " ".mex("in",$pag)." <b>".$lingue['nome'][$num_lingua]."</b> (";
 if (!$num_lingua) echo "".mex("predefinito",$pag)."):<br>";
 else echo "<input class=\"smallsbutton\" type=\"submit\" value=\"".mex("fai predefinito",$pag)."\">):</div></form>";
-} # fine else if (!$multilingua)
+} # fine if ($multilingua)
 
 echo "<table><tr><td style=\"height: 3px;\"></td></tr></table>";
 if ($testo_contratto_mod and (!$multilingua or $lingua_contr == $lingue[$num_lingua])) $testo_contratto = $testo_contratto_mod;
@@ -1019,7 +1167,9 @@ if (!$multilingua) $linea_mod .= "<option value=\"1\">".mex("ripetizione prenota
 $linea_mod .= "<option value=\"2\">".mex("ripetizione ospiti",$pag)."</option>
 <option value=\"3\">".mex("ripetizione costi aggiuntivi",$pag)."</option>
 $option_array
-<option value=\"4\">".mex("parte sotto condizione",$pag)."</option>
+<option value=\"5\">".mex("ripetizione pagamenti",$pag)."</option>
+<option value=\"6\">".mex("ripetizione unità",$pag)."</option>
+<option value=\"7\">".mex("parte sotto condizione",$pag)."</option>
 </select>
 <input class=\"sbutton\" type=\"submit\" name=\"aggiungi_ripetizione\" value=\"".mex("Aggiungi",$pag)."\">
 </td></tr>";
@@ -1038,6 +1188,17 @@ echo "$linea_mod</table>
 
 } # fine for $num_lingua
 
+if ($contr_foot) {
+echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div style=\"text-align: center;\">
+<input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
+<input type=\"hidden\" name=\"num_contratto\" value=\"$num_contratto\">
+<input type=\"hidden\" name=\"cambia_qualcosa\" value=\"SI\">
+<textarea id=\"contr_foot\" name=\"n_foot\" rows=4 cols=135 style=\"white-space: pre; overflow: auto;\">".htmlspecialchars($contr_foot)."</textarea>
+<input class=\"sbutton\" type=\"submit\" name=\"salva_foot\" value=\"".mex("Modifica la chiusura html",$pag)."\"><br>
+</div></form><br>";
+} # fine if ($contr_foot)
+
 echo "<script type=\"text/javascript\">
 <!--
 function resize_contr_txta(numlingue) {
@@ -1049,7 +1210,13 @@ for (n1 = 0 ; n1 < $num_lingua ; n1++) {
 document.getElementById('contr_txta'+n1).style.height = height + 'px';
 document.getElementById('contr_txta'+n1).style.width = width + 'px';
 }
-}
+";
+if ($contr_head) {
+echo "document.getElementById('contr_head').style.width = width + 'px';
+document.getElementById('contr_foot').style.width = width + 'px';
+";
+} # fine if ($contr_head)
+echo "}
 resize_contr_txta();
 window.onresize = new Function(\"resize_contr_txta()\");
 
