@@ -107,7 +107,7 @@ if ($agg_se) {
 $cambia_qualcosa = "";
 $num_se++;
 } # fine if ($agg_se)
-if ($num_se > 50) $num_se = 50;
+if ($num_se > 80) $num_se = 80;
 
 
 
@@ -414,7 +414,7 @@ $continua = "SI";
 if ($inizializza != "rpt" and $inizializza != "inr" and $inizializza != "ind") $continua = "NO";
 if (strcmp($cond_sempre,"") and $cond_sempre != "SI" and $cond_sempre != "NO") $continua = "NO";
 if ($azione != "set" and $azione != "trunc" and $azione != "oper" and $azione != "date" and $azione != "unset" and $azione != "array" and $azione != "break" and $azione != "cont") $continua = "NO";
-if ($num_se < 1 or $num_se > 50) $continua = "NO";
+if ($num_se < 1 or $num_se > 80) $continua = "NO";
 if ($num_se > 1 and $and_or != "and" and $and_or != "or") $continua = "NO";
 if ($continua == "SI") {
 
@@ -541,8 +541,8 @@ $var_non_predef = esegui_query("select numero from $tablecontratti where (tipo =
 if (!numlin_query($var_non_predef)) $continua = "NO";
 } # fine if (numlin_query($arr_esistente) != 1)
 if ($tipo_arr != "dat" and $tipo_arr != "val" and $tipo_arr != "cop") $continua = "NO";
-$lista_val = "";
 if ($tipo_arr == "val") $lista_val = controlla_testo_input($lista_val);
+else $lista_val = "";
 if ($tipo_arr == "cop") {
 $lista_val = $array2;
 if (substr($array2,0,1) != "a") $continua = "NO";
@@ -679,9 +679,11 @@ $num_var_predef++;
 $nome_var[$num_var_pers] = $var_pers;
 } # fine for $num1
 
-$contr_importa_vc = esegui_query("select testo from $tablecontratti where numero = '$contr_cond' and tipo = 'impor_vc' ");
-if (!numlin_query($contr_importa_vc)) $contr_importa_vc = "";
-else $contr_importa_vc = risul_query($contr_importa_vc,0,'testo');
+$contr_importa_vc = "";
+if ($contr_cond) {
+$c_imp_vc = esegui_query("select testo from $tablecontratti where numero = '$contr_cond' and tipo = 'impor_vc' ");
+if (numlin_query($c_imp_vc)) $contr_importa_vc = risul_query($c_imp_vc,0,'testo');
+} # fine if ($contr_cond)
 
 echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
@@ -1324,7 +1326,7 @@ echo "<table><tr onclick=\"document.getElementById('az_oper').checked='1'\"><td>
 </td><td>(".str_replace(" ","&nbsp;",mex("arrotondato a",$pag))."</td><td>
 <input type=\"text\" name=\"val_arrotond\" value=\"$val_arrotond\" size=\"15\" maxlength=\"50\"></td><td>)
 </td></tr><tr><td></td><td colspan=\"9\"><small>
-(".mex("Utilizzare una variabile personalizzata che finisce con \"_p\" per aggiungervi i separatori delle migliaia dopo l'operazione",$pag).")
+(".mex("Utilizzare una variabile personalizzata che finisce con \"_p\" per aggiungervi i separatori delle migliaia e 2 decimali dopo l'operazione",$pag).")
 </small></td></tr></table><br>";
 
 if ($azione == "date") $chk_az = " checked";
