@@ -254,6 +254,9 @@ if ($d_nome_tariffa == $tariffa or $d_nome_tariffa == $dati_tariffe[$tariffa]['n
 
 
 $azione = 0;
+$testo_azione = "";
+$mostra_contr = 0;
+
 if ($azzera) {
 $azione = 1;
 $id_costi = "";
@@ -680,7 +683,6 @@ if (!$cassa_trovata) $id_cassa_sel = "";
 } # fine if ($id_costi and !$errore_cassa)
 
 
-$testo_azione = "";
 if ($incassa and !$errore_cassa and $id_costi and $priv_ins_entrate == "s" and !$azione) {
 $azione = 1;
 
@@ -689,7 +691,8 @@ $metodi_pagamento = risul_query($metodi_pagamento,0,'valpersonalizza');
 if (($num_casse_attive > 1 or $metodi_pagamento) and !$id_cassa_sel) {
 $testo_azione = "<input type=\"hidden\" name=\"id_costi\" value=\"$id_costi\">
 <input type=\"hidden\" name=\"incassa\" value=\"1\">
-<input type=\"hidden\" name=\"categoria\" value=\"$categoria\">";
+<input type=\"hidden\" name=\"categoria\" value=\"$categoria\">
+<input type=\"hidden\" name=\"id_prenota\" value=\"$id_prenota\">";
 if ($metodi_pagamento) {
 $testo_azione .= "<br>".mex("Metodo pagamento",$pag).":<br><br>
 <select name=\"metodo_pagamento_sel\" style=\"font-size: xx-large;\">
@@ -731,9 +734,10 @@ if ($id_cassa == 1) $testo_azione .= mex("nella cassa principale",$pag);
 else $testo_azione .= mex("nella cassa",$pag)." \"$nome_cassa\"";
 $testo_azione .= "</b>.<br><br>
 <button class=\"pos\" type=\"submit\" style=\"height: 60px; width: 140px; margin: 2px;\"><b>".mex("OK",$pag)."</b></button>";
+$mostra_contr = 1;
+
 $costi = explode(",",$id_costi);
 $num_costi = count($costi);
-
 for ($num1 = 0 ; $num1 < $num_costi ; $num1++) {
 $id_costo = explode("x",$costi[$num1]);
 $molt_costo = $id_costo[1];
@@ -885,6 +889,7 @@ if ($dati_ca[$numca]['tasseperc']) esegui_query("update $tablecostiprenota set t
 
 $testo_azione = "<br>".mex("I costi sono stati inseriti sulla prenotazione dell'appartamento",'unit.php')." <b>$app_prenota</b>.<br><br>
 <button class=\"pos\" type=\"submit\" style=\"height: 60px; width: 140px; margin: 2px;\"><b>".mex("OK",$pag)."</b></button>";
+$mostra_contr = 1;
 } # fine elseif ($id_costi)
 } # fine if ($inprenota and !$errore_prenota and !$azione)
 
@@ -938,13 +943,16 @@ if ($molt_costo and $molt_costo != 1) $molt_costo = " <b>x$molt_costo</b>";
 else $molt_costo = "";
 if ($errori_costi[$num1]) $redclass = " class=\"colred\" title=\"".substr($errori_costi[$num1],2)."\"";
 else $redclass = "";
-if ($val_costo[$num1] != "?") $val_costo[$num1] = punti_in_num($val_costo[$num1],$stile_soldi,"2");
-else $tot_indef = 1;
+if ($val_costo[$num1] != "?") $val_costo_vedi = punti_in_num($val_costo[$num1],$stile_soldi,"2");
+else {
+$tot_indef = 1;
+$val_costo_vedi = "?";
+} # fine else if ($val_costo[$num1] != "?")
 $testo_costi .= "<tr style=\"background-color: ".rowbgcolor().";\"><td style=\"width: 34px; height: 34px;\">";
 if ($testo_azione) $testo_costi .= "&nbsp;";
 else $testo_costi .= "<button class=\"pos\" type=\"submit\" name=\"canc_costo\" value=\"$num1\"$onclick style=\"padding: 0;\"><img style=\"display: block; padding: 0; border: 0; margin: 0;\" src=\"./img/croce.gif\" alt=\"X\"></button>";
 $testo_costi .= "</td><td$redclass>".$dati_ca[$numca]['nome']."$molt_costo</td>
-<td style=\"width: 40px; text-align: right;\">".$val_costo[$num1]."</td></tr>";
+<td style=\"width: 40px; text-align: right;\">$val_costo_vedi</td></tr>";
 } # fine for $num1
 
 if (strcmp($n_categoria,"")) $categoria = $n_categoria;
@@ -993,6 +1001,59 @@ echo "</div></form>
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 $testo_azione
 </div></form>";
+
+if ($mostra_contr) {
+echo "<br><hr style=\"width: 350px; clear: right; margin: 4px auto 4px 0; text-align: left;\">
+<form accept-charset=\"utf-8\" method=\"post\" action=\"visualizza_contratto.php\"><div>
+<input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
+<input type=\"hidden\" name=\"origine\" value=\"punto_vendita.php\">";
+if ($incassa) {
+for ($num1 = 0 ; $num1 < $num_costi ; $num1++) {
+$numca = explode("x",$costi[$num1]);
+$molt_costo = $numca[1];
+if (!$molt_costo) $molt_costo = 1;
+$id_costo = $numca[0];
+$numca = $dati_ca['id'][$id_costo];
+echo "<input type=\"hidden\" name=\"nome_costo_agg$num1"."_1\" value=\"".$dati_ca[$numca]['nome']."\">
+<input type=\"hidden\" name=\"val_costo_agg$num1"."_1\" value=\"".$val_costo[$num1]."\">
+<input type=\"hidden\" name=\"percentuale_tasse_costo_agg$num1"."_1\" value=\"".$dati_ca[$numca]['tasseperc']."\">
+<input type=\"hidden\" name=\"moltiplica_max_costo_agg$num1"."_1\" value=\"$molt_costo\">
+<input type=\"hidden\" name=\"data_inserimento_costo_agg$num1"."_1\" value=\"".substr($datainserimento,0,10)."\">
+<input type=\"hidden\" name=\"utente_inserimento_costo_agg$num1"."_1\" value=\"$id_utente\">";
+} # fine for $num1
+echo "<input type=\"hidden\" name=\"num_costi_aggiuntivi_1\" value=\"$num_costi\">
+<input type=\"hidden\" name=\"data_paga0_1\" value=\"".substr($datainserimento,0,10)."\">
+<input type=\"hidden\" name=\"utente_paga0_1\" value=\"$id_utente\">
+<input type=\"hidden\" name=\"metodo_paga0_1\" value=\"$metodo_pagamento_sel\">
+<input type=\"hidden\" name=\"saldo_paga0_1\" value=\"$val_tot\">
+<input type=\"hidden\" name=\"num_pagamenti_1\" value=\"1\">
+<input type=\"hidden\" name=\"num_ripeti\" value=\"1\">";
+} # fine if ($incassa)
+if ($inprenota) echo "<input type=\"hidden\" name=\"lista_prenota\" value=\",$id_prenota,\">";
+unset($nome_contratto);
+$nomi_contratti = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'nomi_contratti' and idutente = '$id_utente'");
+$nomi_contratti = risul_query($nomi_contratti,0,'valpersonalizza');
+$nomi_contratti = explode("#@&",$nomi_contratti);
+$num_nomi_contratti = count($nomi_contratti);
+for ($num1 = 0 ; $num1 < $num_nomi_contratti ; $num1++) {
+$dati_nome_contratto = explode("#?&",$nomi_contratti[$num1]);
+$nome_contratto[$dati_nome_contratto[0]] = $dati_nome_contratto[1];
+} # fine for $num1
+$max_contr = esegui_query("select max(numero) from $tablecontratti where tipo $LIKE 'contr%'");
+$max_contr = risul_query($max_contr,0,0);
+for ($num_contratto = 1 ; $num_contratto <= $max_contr ; $num_contratto++) {
+if ($attiva_contratti_consentiti == "n" or $contratti_consentiti_vett[$num_contratto] == "SI") {
+if ($nome_contratto[$num_contratto]) $num_contratto_vedi = $nome_contratto[$num_contratto];
+else $num_contratto_vedi = mex("documento",$pag)." ".$num_contratto;
+echo "<div style=\"float: left; padding: 2px;\">
+<button class=\"pos\" type=\"submit\" name=\"numero_contratto\" value=\"$num_contratto\" style=\"min-height: 60px; min-width: 70px; max-width: 110px;\">$num_contratto_vedi</button>
+</div>";
+} # fine if ($attiva_contratti_consentiti == "n" or...
+} # fine for $num_contratto
+echo "</div></form>";
+} # fine if ($mostra_contr)
+
 } # fine if ($testo_azione)
 
 else {
