@@ -59,7 +59,13 @@ $vedi_clienti = "NO";
 if (substr($priv_ins_clienti,2,1) == "s") $vedi_clienti = "SI";
 if (substr($priv_ins_clienti,2,1) == "p") $vedi_clienti = "PROPRI";
 if (substr($priv_ins_clienti,2,1) == "g") { $vedi_clienti = "GRUPPI"; $prendi_gruppi = "SI"; }
+$priv_mod_prenota = risul_query($privilegi_annuali_utente,0,'priv_mod_prenota');
+$priv_mod_prenotazioni = substr($priv_mod_prenota,0,1);
+if ($priv_mod_prenotazioni == "g") $prendi_gruppi = "SI";
+$priv_mod_prenota_iniziate = substr($priv_mod_prenota,11,1);
+$priv_mod_prenota_ore = substr($priv_mod_prenota,12,3);
 } # fine else if (numlin_query($privilegi_annuali_utente) == 0)
+
 unset($utenti_gruppi);
 $utenti_gruppi[$id_utente] = 1;
 if ($prendi_gruppi == "SI") {
@@ -72,11 +78,15 @@ $num_utenti_gruppo = numlin_query($utenti_gruppo);
 for ($num2 = 0 ; $num2 < $num_utenti_gruppo ; $num2++) $utenti_gruppi[risul_query($utenti_gruppo,$num2,'idutente')] = 1;
 } # fine for $num1
 } # fine if ($prendi_gruppi == "SI")
+
 } # fine if ($id_utente != 1)
 else {
 $anno_utente_attivato = "SI";
 $priv_vedi_tab_costi = "s";
 $vedi_clienti = "SI";
+$priv_mod_prenotazioni = "s";
+$priv_mod_prenota_iniziate = "s";
+$priv_mod_prenota_ore = "000";
 } # fine if ($id_utente != 1)
 if ($anno_utente_attivato == "SI" and $priv_vedi_tab_costi != "n") {
 
@@ -156,6 +166,7 @@ if ($mostra_tabella != "NO") {
 
 unset($periodo_query);
 unset($cond_metodo);
+if ($priv_mod_prenota_iniziate != "s") $id_periodo_corrente = calcola_id_periodo_corrente($anno);
 
 if (!$cerca_prenota) {
 echo "<table class=\"buttonbar\"><tr><td align=\"left\">
@@ -312,7 +323,7 @@ else $pagina_prenota = 1;
 } # fine if (!$cerca_prenota)
 
 echo "<table class=\"t1\" style=\"background-color: $colore; margin-left: auto; margin-right: auto;\" width=200 border=\"$t1border\" cellspacing=\"$t1cellspacing\" cellpadding=\"$t1cellpadding\">
-<tr><td colspan=3>".mex("Dati della prenotazione",$pag)."</td>
+<tr><td colspan=4>".mex("Dati della prenotazione",$pag)."</td>
 <td rowspan=2>".mex("Pagato prima",$pag)."</td>
 <td rowspan=2>".mex("Pagato dopo",$pag)."</td>
 <td rowspan=2>".mex("Saldo",$pag)."</td>
@@ -320,7 +331,10 @@ echo "<table class=\"t1\" style=\"background-color: $colore; margin-left: auto;
 <td rowspan=2>".mex("Metodo",$pag)."</td>";
 if ($num_tutti_utenti > 1) echo "<td rowspan=2>".mex("Utente",$pag)."</td>";
 echo "<td rowspan=2>".mex("Data_della modifica",$pag)."</td></tr>
-<tr><td>".mex("Cognome_cliente",$pag)."</td><td>".mex("Data_iniziale",$pag)."</td><td>".mex("Data_finale",$pag)."</td></tr>";
+<tr><td>".mex("N°",$pag)."</td>
+<td>".str_replace("_","&nbsp;",mex("Cognome_cliente",$pag))."</td>
+<td>".str_replace("_","&nbsp;",mex("Data_iniziale",$pag))."</td>
+<td>".str_replace("_","&nbsp;",mex("Data_finale",$pag))."</td></tr>";
 
 if (!$cerca_prenota and $num_storia_soldi_prenota > $num_vedi_in_tab and $pagina_prenota != 1) echo $stringa_puntini_tab;
 
@@ -354,6 +368,30 @@ $data_fine = risul_query($data_fine,0,'datafine');
 $data_fine_f = formatta_data($data_fine,$stile_data);
 } # fine if ($motivazione[2])
 else $data_fine_f = "&nbsp;";
+
+if ($motivazione[3]) {
+$num_prenota = $motivazione[3];
+if ($priv_mod_prenotazioni != "n") {
+$prenota_esist = esegui_query("select iddatainizio,datainserimento,utente_inserimento from $tableprenota where idprenota = '$num_prenota' ");
+if (numlin_query($prenota_esist)) {
+$link_modifica = 1;
+$utente_ins_pren = risul_query($prenota_esist,0,'utente_inserimento');
+$iddatainizio = risul_query($prenota_esist,0,'iddatainizio');
+if ($priv_mod_prenotazioni == "p" and $utente_ins_pren != $id_utente) $link_modifica = 0;
+if ($priv_mod_prenotazioni == "g" and !$utenti_gruppi[$utente_ins_pren]) $link_modifica = 0;
+if ($priv_mod_prenota_iniziate != "s" and $id_periodo_corrente >= $iddatainizio) $link_modifica = 0;
+if ($priv_mod_prenota_ore != "000") {
+$adesso = date("YmdHis",(time() + (C_DIFF_ORE * 3600)));
+$data_ins = risul_query($prenota_esist,0,'datainserimento');
+$limite = date("YmdHis",mktime((substr($data_ins,11,2) + $priv_mod_prenota_ore),substr($data_ins,14,2),substr($data_ins,17,2),substr($data_ins,5,2),substr($data_ins,8,2),substr($data_ins,0,4)));
+if ($adesso > $limite) $link_modifica = 0;
+} # fine if ($priv_mod_prenota_ore != "000")
+if ($link_modifica) $num_prenota = "<a href=\"modifica_prenota.php?id_prenota=$num_prenota&amp;anno=$anno&amp;id_sessione=$id_sessione&amp;origine=storia_soldi.php\">$num_prenota</a>";
+} # fine if (numlin_query($prenota_esist))
+} # fine if ($priv_mod_prenotazioni != "n")
+} # fine if ($motivazione[3])
+else $num_prenota = "&nbsp;";
+
 $soldi_prima = risul_query($storia_soldi_prenota,$num1,'soldi_prima');
 $saldo_prenota = risul_query($storia_soldi_prenota,$num1,'saldo_prenota');
 $soldi_dopo = $soldi_prima + $saldo_prenota;
@@ -371,7 +409,8 @@ $saldo_prenota_p = punti_in_num($saldo_prenota,$stile_soldi);
 
 if ($cerca_prenota or (($num1+1) > (($pagina_prenota - 1)*$num_vedi_in_tab) and ($num1+1) <= (($pagina_prenota)*$num_vedi_in_tab)) ) {
 
-echo "<tr><td>$cognome</td>
+echo "<tr><td>$num_prenota</td>
+<td>$cognome</td>
 <td>$data_inizio_f</td>
 <td>$data_fine_f</td>
 <td>$soldi_prima_p</td>
@@ -389,7 +428,7 @@ echo "<td><small>$data_inserimento_f</small></td></tr>";
 if (!$cerca_prenota and $num_storia_soldi_prenota > $num_vedi_in_tab and $pagina_prenota != $num_pagine_prenota) echo $stringa_puntini_tab;
 
 $saldo_prenota_TOT_p = punti_in_num($saldo_prenota_TOT,$stile_soldi);
-echo "<tr><td colspan=5><b>".mex("TOTALE",$pag)."</b></td>
+echo "<tr><td colspan=6><b>".mex("TOTALE",$pag)."</b></td>
 <td>$saldo_prenota_TOT_p</td>";
 if ($num_tutti_utenti > 1) echo "<td>&nbsp;</td>";
 echo "<td>&nbsp;</td>
@@ -402,13 +441,13 @@ if ($costo_cassa and !$cerca_prenota) {
 $resto_tot = $saldo_prenota_TOT - $costo_cassa;
 $costo_cassa_p = punti_in_num($costo_cassa,$stile_soldi);
 $resto_tot_p = punti_in_num($resto_tot,$stile_soldi);
-echo "<tr><td colspan=\"5\"><b><i>".mex("Trasferito in cassa",$pag).":</i></b></td>
+echo "<tr><td colspan=\"6\"><b><i>".mex("Trasferito in cassa",$pag).":</i></b></td>
 <td>$costo_cassa_p</td>";
 if ($num_tutti_utenti > 1) echo "<td>&nbsp;</td>";
 echo "<td>&nbsp;</td>
 <td>&nbsp;</td>
 <td>&nbsp;</td></tr>
-<tr><td colspan=\"5\"><b><i>".mex("RESTO",$pag)."</i></b></td>
+<tr><td colspan=\"6\"><b><i>".mex("RESTO",$pag)."</i></b></td>
 <td>$resto_tot_p</td>";
 if ($num_tutti_utenti > 1) echo "<td>&nbsp;</td>";
 echo "<td>&nbsp;</td>
