@@ -40,6 +40,7 @@ $tableanni = $PHPR_TAB_PRE."anni";
 $tablepersonalizza = $PHPR_TAB_PRE."personalizza";
 $tableregole = $PHPR_TAB_PRE."regole".$anno;
 $tablecontratti = $PHPR_TAB_PRE."contratti";
+$tablecostiprenota = $PHPR_TAB_PRE."costiprenota".$anno;
 
 $id_utente = controlla_login($numconnessione,$PHPR_TAB_PRE,$id_sessione,$nome_utente_phpr,$password_phpr,$anno);
 if ($id_utente) {
@@ -294,7 +295,11 @@ return $colore;
 
 
 
+$manda_xml = 0;
+$dati_xml = "";
+
 if ($idg_agg and controlla_num_pos(substr($idg_agg,2)) == "SI") {
+$manda_xml = 1;
 $tabelle_lock = "";
 if ($priv_vedi_tab_mesi != "p") $altre_tab_lock = array($tableprenota,$tableperiodi,$tableclienti,$tablepersonalizza);
 else $altre_tab_lock = array($tableprenota,$tablenometariffe,$tableperiodi,$tableappartamenti,$tableclienti,$tableregole,$tablepersonalizza);
@@ -308,7 +313,6 @@ if ($priv_app_gruppi != "SI") $appartamenti_consentiti = trova_app_consentiti($a
 else $appartamenti_consentiti = trova_app_consentiti($appartamenti,$num_appartamenti,$attiva_regole1_consentite_gr,$regole1_consentite_gr,$priv_mod_assegnazione_app_gr,$priv_mod_prenotazioni_gr,$priv_ins_assegnazione_app_gr,$priv_ins_nuove_prenota_gr,$attiva_tariffe_consentite_gr,$tariffe_consentite_vett_gr,$id_utente,$tableregole,$tablenometariffe);
 } # fine if ($priv_vedi_tab_mesi == "p")
 
-$dati_xml = "";
 $ncol = 0;
 if (substr($idg_agg,0,1) == "7") $loop = 7;
 else $loop = 1;
@@ -394,7 +398,6 @@ if ($priv_mod_prenotazioni == "g" and !$utenti_gruppi[$utente_inserimento]) $lin
 if ($priv_mod_prenota_iniziate != "s" and $id_periodo_corrente >= $iddatainizio) $link_modifica = 0;
 if ($priv_mod_prenota_ore != "000") {
 $adesso = date("YmdHis",(time() + (C_DIFF_ORE * 3600)));
-$data_ins = risul_query($prenota_ini_fine,$num1,'datainserimento',$tableprenota);
 $limite = date("YmdHis",mktime((substr($data_ins_js,11,2) + $priv_mod_prenota_ore),substr($data_ins_js,14,2),substr($data_ins_js,17,2),substr($data_ins_js,5,2),substr($data_ins_js,8,2),substr($data_ins_js,0,4)));
 if ($adesso > $limite) $link_modifica = 0;
 } # fine if ($priv_mod_prenota_ore != "000")
@@ -449,14 +452,93 @@ $dati_prenota
 
 } # fine if ($d_inizio_settimana)
 } # fine for $ncol
+unlock_tabelle($tabelle_lock);
+} # fine if ($idg_agg and controlla_num_pos(substr($idg_agg,2)) == "SI")
+
+if ($dati_prn and substr($dati_prn,0,3) == "prn" and controlla_num_pos(substr($dati_prn,3)) == "SI" and !$manda_xml) {
+$manda_xml = 1;
+$id_prn = substr($dati_prn,3);
+$tabelle_lock = array();
+$altre_tab_lock = array($tableprenota,$tablecostiprenota,$tableperiodi,$tableclienti,$tablepersonalizza);
+$tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
+$dati_prn = esegui_query("select * from $tableprenota where idprenota = '$id_prn' ");
+if (numlin_query($dati_prn)) {
+$utente_inserimento = risul_query($dati_prn,0,'utente_inserimento');
+$iddatainizio = risul_query($dati_prn,0,'iddatainizio');
+$link_modifica = 1;
+if ($priv_mod_prenotazioni == "n") $link_modifica = 0;
+if ($priv_mod_prenotazioni == "p" and $utente_inserimento != $id_utente) $link_modifica = 0;
+if ($priv_mod_prenotazioni == "g" and !$utenti_gruppi[$utente_inserimento]) $link_modifica = 0;
+if ($priv_mod_prenota_iniziate != "s") {
+$id_periodo_corrente = calcola_id_periodo_corrente($anno);
+if ($id_periodo_corrente >= $iddatainizio) $link_modifica = 0;
+} # fine if ($priv_mod_prenota_iniziate != "s")
+if ($priv_mod_prenota_ore != "000") {
+$adesso = date("YmdHis",(time() + (C_DIFF_ORE * 3600)));
+$data_ins = risul_query($dati_prn,0,'datainserimento');
+$limite = date("YmdHis",mktime((substr($data_ins_js,11,2) + $priv_mod_prenota_ore),substr($data_ins_js,14,2),substr($data_ins_js,17,2),substr($data_ins_js,5,2),substr($data_ins_js,8,2),substr($data_ins_js,0,4)));
+if ($adesso > $limite) $link_modifica = 0;
+} # fine if ($priv_mod_prenota_ore != "000")
+if ($link_modifica) {
+$iddatafine = risul_query($dati_prn,0,'iddatafine');
+$dati_xml = "<txt>";
+$id_cli = risul_query($dati_prn,0,'idclienti');
+$dati_cliente = esegui_query("select * from $tableclienti where idclienti = '$id_cli' ");
+$utente_inserimento = risul_query($dati_cliente,0,'utente_inserimento');
+$pag_orig = $pag;
+$pag = "modifica_prenota.php";
+if (($vedi_clienti == "PROPRI" and $utente_inserimento != $id_utente) or ($vedi_clienti == "GRUPPI" and !$utenti_gruppi[$utente_inserimento])) $dati_xml .= mex("Cliente",$pag)." $id_cli ";
+else {
+include_once("./includes/funzioni_clienti.php");
+$txt_cli = mostra_dati_cliente($dati_cliente,$dcognome,$dnome,$dsoprannome,$dtitolo_cli,$dsesso,$ddatanascita,$ddatanascita_f,$dnazionenascita,$dcittanascita,$dregionenascita,$ddocumento,$dscadenzadoc,$dscadenzadoc_f,$dtipodoc,$dnazionedoc,$dregionedoc,$dcittadoc,$dnazionalita,$dlingua_cli,$dnazione,$dregione,$dcitta,$dvia,$dnumcivico,$dtelefono,$dtelefono2,$dtelefono3,$dfax,$dcap,$demail,$dcod_fiscale,$dpartita_iva,"",$priv_ins_clienti,"1");
+$txt_cli = str_replace("<br>"," \n",$txt_cli);
+$txt_cli = preg_replace("/<[^<]*>/","",$txt_cli);
+$dati_xml .= $txt_cli." ";
+} # fine else if (($vedi_clienti == "PROPRI" and $utente_inserimento != $id_utente) or...
+$num_persone = risul_query($dati_prn,0,'num_persone');
+include_once("./includes/funzioni_costi_agg.php");
+$dati_cap = dati_costi_agg_prenota($tablecostiprenota,$id_prn);
+unset($num_letti_agg);
+for ($numca = 0 ; $numca < $dati_cap['num'] ; $numca++) aggiorna_letti_agg_in_periodi($dati_cap,$numca,$num_letti_agg,$iddatainizio,$iddatafine,$dati_cap[$numca]['settimane'],$dati_cap[$numca]['moltiplica_costo'],"","");
+if ($num_persone or $num_letti_agg['max']) {
+$dati_xml .= "\n-".mex("Nº di persone",$pag).": $num_persone ";
+if ($num_letti_agg['max']) $dati_xml .= "+ ".$num_letti_agg['max']." ";
+} # fine if ($num_persone or $num_letti_agg['max'])
+$tariffa = risul_query($dati_prn,0,'tariffa');
+if ($tariffa) {
+$tariffa = explode("#@&",$tariffa);
+$tariffa = $tariffa[0];
+$dati_xml .= "\n-".mex("Tipo di tariffa",$pag).": ".str_replace("\"","&quot;",str_replace(">","&gt;",str_replace("<","&lt;",str_replace("&","&amp;",$tariffa))))." ";
+} # fine if ($tariffa)
+$commento = risul_query($dati_prn,0,'commento');
+if (strstr($commento,">")) {
+$commento = explode(">",$commento);
+$commento = $commento[0];
+} # fine if (strstr($commento,">"))
+if ($commento) $dati_xml .= "\n-".mex("Commento",$pag).": ".str_replace("\"","&quot;",str_replace(">","&gt;",str_replace("<","&lt;",str_replace("&","&amp;",$commento))))." ";
+$Euro = nome_valuta();
+$stile_soldi = stile_soldi();
+$tariffa_tot = risul_query($dati_prn,0,'tariffa_tot');
+$dati_xml .= "\n-".mex("Totale da pagare",$pag).": ".punti_in_num($tariffa_tot,$stile_soldi)." $Euro ";
+$pagato = risul_query($dati_prn,0,'pagato');
+$dati_xml .= "\n-".mex("Pagato",$pag).": ".punti_in_num($pagato,$stile_soldi)." $Euro ";
+$da_pagare = $tariffa_tot - $pagato;
+if ($da_pagare and $da_pagare != $tariffa_tot) $dati_xml .= "\n-".mex("Ancora da pagare",$pag).": ".punti_in_num($da_pagare,$stile_soldi)." $Euro ";
+$dati_xml .= "</txt>";
+$pag = $pag_orig;
+} # fine if ($link_modifica)
+} # fine if (numlin_query($dati_prn))
+unlock_tabelle($tabelle_lock);
+} # fine if ($dati_prn and substr($dati_prn,0,3) == "prn" and controlla_num_pos(substr($dati_prn,3)) == "SI" and...
+
+if ($manda_xml) {
 header('Content-type: text/xml');
 echo "<?xml version=\"1.0\" encoding=\"UTF-8\" ?>
 <data>
 $dati_xml
 </data>
 ";
-unlock_tabelle($tabelle_lock);
-} # fine if ($idg_agg and controlla_num_pos(substr($idg_agg)) == "SI")
+} # fine if ($manda_xml)
 
 
 else {
@@ -476,7 +558,7 @@ if ($priv_mod_prenotazioni != "n") {
 $inserire = "SI";
 $cancellata = "NO";
 prepara_modifiche_prenotazione($id_prenota_idpr,$num_id_prenota,$prenota_in_anno_succ,$dati_da_anno_prec,$tra_anni,$anno,$PHPR_TAB_PRE);
-esegui_modifiche_prenotazione($inserire,$cancellata,$id_prenota_int,$id_prenota_idpr,$num_id_prenota,$id_transazione,$id_sessione,$anno,$id_nuovo_utente_inserimento,$n_stima_checkin,$n_met_paga_caparra,$n_origine_prenota,$n_pagato,$n_confermato,$n_commento,$n_cancella_commento,$tableprenota_da_aggiornare,$tipo_sposta,$dati_da_anno_prec,$prenota_in_anno_succ,$tra_anni,$PHPR_TAB_PRE);
+esegui_modifiche_prenotazione($inserire,$cancellata,$id_prenota_int,$id_prenota_idpr,$num_id_prenota,$id_transazione,$id_sessione,$anno,$id_nuovo_utente_inserimento,$n_stima_checkin,$n_met_paga_caparra,$n_origine_prenota,$n_pagato,$n_confermato,$tipo_commento,$n_commento,$n_cancella_commento,$tableprenota_da_aggiornare,$tipo_sposta,$dati_da_anno_prec,$prenota_in_anno_succ,$tra_anni,$PHPR_TAB_PRE);
 } # fine if ($priv_mod_prenotazioni != "n")
 } # fine if ($modificaprenotazione == "Continua")
 
@@ -712,6 +794,10 @@ var id_sessione = '$id_sessione';
 var anno = $anno;
 var allinea_tab_mesi = '$allinea_tab_mesi';
 var tab_spostata = 0;
+var sel_start_date = 0;
+var sel_start_col = 0;
+var sel_stop_date = 0;
+var curr_sel_row = 0;
 
 
 -->
@@ -1038,11 +1124,22 @@ var DaIn = new Array();
 $array_data_ins_js
 var ArDaCo = new Array();
 $array_date_col_js
+var ArTiOr = new Array();
+var ArTiPr = new Array();
 
 attiva_drag_drop();
 attiva_colora_date(allinea_tab_mesi);
 -->
 </script>
+<form id=\"ins_pren\" accept-charset=\"utf-8\" method=\"post\" action=\"prenota.php\"><div>
+<input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
+<input type=\"hidden\" name=\"num_tipologie\" value=\"1\">
+<input type=\"hidden\" name=\"mos_tut_dat\" value=\"SI\">
+<input type=\"hidden\" id=\"ins_ini_per\" name=\"inizioperiodo1\" value=\"\">
+<input type=\"hidden\" id=\"ins_fin_per\" name=\"fineperiodo1\" value=\"\">
+<input type=\"hidden\" id=\"ins_app\" name=\"appartamento1\" value=\"\">
+</div></form>
 <table><tr><td style=\"height: 2px;\"></td></tr></table>
 <table style=\"margin-left: auto; margin-right: auto;\"><tr><td style=\"width: 100px;\" align=\"right\">";
 if ($mese != 1) {
@@ -1162,7 +1259,7 @@ if ($tema[$id_utente] and $tema[$id_utente] != "base" and @is_dir("./themes/".$t
 else include("./includes/foot.php");
 
 
-} # fine else if ($idg_agg and controlla_num_pos(substr($idg_agg)) == "SI")
+} # fine else if ($manda_xml)
 
 } # fine if ($anno_utente_attivato == "SI" and $priv_vedi_tab_mesi != "n")
 } # fine if ($id_utente)
