@@ -49,17 +49,17 @@ if (numlin_query($privilegi_annuali_utente) == 0) $anno_utente_attivato = "NO";
 else {
 $anno_utente_attivato = "SI";
 $privilegi_globali_utente = esegui_query("select * from $tableprivilegi where idutente = '$id_utente' and anno = '1'");
-$priv_ins_clienti = risul_query($privilegi_globali_utente,0,priv_ins_clienti);
+$priv_ins_clienti = risul_query($privilegi_globali_utente,0,'priv_ins_clienti');
 $vedi_clienti = "NO";
 if (substr($priv_ins_clienti,2,1) == "s") $vedi_clienti = "SI";
 if (substr($priv_ins_clienti,2,1) == "p") $vedi_clienti = "PROPRI";
 if (substr($priv_ins_clienti,2,1) == "g") { $vedi_clienti = "GRUPPI"; $prendi_gruppi = "SI"; }
-$priv_mod_prenota = risul_query($privilegi_annuali_utente,0,priv_mod_prenota);
+$priv_mod_prenota = risul_query($privilegi_annuali_utente,0,'priv_mod_prenota');
 $priv_mod_prenotazioni = substr($priv_mod_prenota,0,1);
 if ($priv_mod_prenotazioni == "g") $prendi_gruppi = "SI";
 $priv_mod_prenota_iniziate = substr($priv_mod_prenota,11,1);
 $priv_mod_prenota_ore = substr($priv_mod_prenota,12,3);
-$priv_vedi_tab = risul_query($privilegi_annuali_utente,0,priv_vedi_tab);
+$priv_vedi_tab = risul_query($privilegi_annuali_utente,0,'priv_vedi_tab');
 $priv_vedi_tab_mesi = substr($priv_vedi_tab,0,1);
 $priv_prenota_gruppi = "NO";
 $priv_app_gruppi = "NO";
@@ -68,22 +68,23 @@ if ($priv_vedi_tab_mesi == "r" or $priv_vedi_tab_mesi == "g") $priv_app_gruppi =
 if ($priv_vedi_tab_mesi == "q" or $priv_vedi_tab_mesi == "r" or $priv_vedi_tab_mesi == "g") { $priv_vedi_tab_mesi = "p"; $prendi_gruppi = "SI"; }
 
 if ($priv_vedi_tab_mesi == "p") {
-$regole1_consentite = risul_query($privilegi_annuali_utente,0,regole1_consentite);
+$regole1_consentite = risul_query($privilegi_annuali_utente,0,'regole1_consentite');
 $attiva_regole1_consentite = substr($regole1_consentite,0,1);
 if ($attiva_regole1_consentite != "n") $regole1_consentite = explode("#@^",substr($regole1_consentite,3));
-$tariffe_consentite = risul_query($privilegi_annuali_utente,0,tariffe_consentite);
+$tariffe_consentite = risul_query($privilegi_annuali_utente,0,'tariffe_consentite');
 $attiva_tariffe_consentite = substr($tariffe_consentite,0,1);
 if ($attiva_tariffe_consentite == "s") {
 $tariffe_consentite = explode(",",substr($tariffe_consentite,2));
 unset($tariffe_consentite_vett);
 for ($num1 = 0 ; $num1 < count($tariffe_consentite) ; $num1++) if ($tariffe_consentite[$num1]) $tariffe_consentite_vett[$tariffe_consentite[$num1]] = "SI";
 } # fine if ($attiva_tariffe_consentite == "s")
-$priv_ins_prenota = risul_query($privilegi_annuali_utente,0,priv_ins_prenota);
+$priv_ins_prenota = risul_query($privilegi_annuali_utente,0,'priv_ins_prenota');
 $priv_ins_nuove_prenota_v = substr($priv_ins_prenota,0,1);
 $priv_ins_assegnazione_app_v = substr($priv_ins_prenota,1,1);
 $priv_mod_assegnazione_app_v = substr($priv_mod_prenota,2,1);
 $priv_mod_prenotazioni_v = $priv_mod_prenotazioni;
 } # fine if ($priv_vedi_tab_mesi == "p")
+$priv_oscura_tab_mesi = substr($priv_vedi_tab,8,1);
 } # fine else if (numlin_query($privilegi_annuali_utente) == 0)
 
 if ($priv_app_gruppi == "SI") {
@@ -121,7 +122,7 @@ $attiva_tariffe_consentite_gr[$idutente_gruppo] = substr($tariffe_consentite_tmp
 if ($attiva_tariffe_consentite_gr[$idutente_gruppo] == "s") {
 $tariffe_consentite_tmp = explode(",",substr($tariffe_consentite_tmp,2));
 $tariffe_consentite_vett_gr[$idutente_gruppo] = "";
-for ($num1 = 0 ; $num1 < count($tariffe_consentite_tmp) ; $num1++) if ($tariffe_consentite_tmp[$num1]) $tariffe_consentite_vett_gr[$idutente_gruppo][$tariffe_consentite_tmp[$num1]] = "SI";
+for ($num3 = 0 ; $num3 < count($tariffe_consentite_tmp) ; $num3++) if ($tariffe_consentite_tmp[$num3]) $tariffe_consentite_vett_gr[$idutente_gruppo][$tariffe_consentite_tmp[$num3]] = "SI";
 } # fine if ($attiva_tariffe_consentite_gr[$idutente_gruppo] == "s")
 $costi_agg_consentiti_tmp = risul_query($priv_anno_ut_gr,0,"costi_agg_consentiti");
 $attiva_costi_agg_consentiti_tmp = substr($costi_agg_consentiti_tmp,0,1);
@@ -177,7 +178,7 @@ else include("./includes/head.php");
 $altre_tab_lock = array($tableprenota,$tablenometariffe,$tableperiodi,$tableappartamenti,$tableclienti,$tableregole,$tablepersonalizza);
 $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
 
-if ($priv_mod_prenota_iniziate != "s") $id_periodo_corrente = calcola_id_periodo_corrente ($anno);
+if ($priv_mod_prenota_iniziate != "s" or $priv_oscura_tab_mesi == "f") $id_periodo_corrente = calcola_id_periodo_corrente($anno);
 
 $oggi = date("j/n/Y",(time() + (C_DIFF_ORE * 3600)));
 $ora = date("H:i",(time() + (C_DIFF_ORE * 3600)));
@@ -186,14 +187,14 @@ echo "<small><small>".mex("situazione alle",$pag)." $ora ".mex("del",$pag)." $og
 if ($anno_succ == "SI") { $mese = $mese + 12; }
 
 $data_inizio_periodi = esegui_query("select * from $tableperiodi where idperiodi = 1");
-$data_inizio_periodi = risul_query($data_inizio_periodi,0,datainizio);
+$data_inizio_periodi = risul_query($data_inizio_periodi,0,'datainizio');
 $data_inizio_periodi = explode("-",$data_inizio_periodi);
 $mese_inizio_periodi = $data_inizio_periodi[1];
 if ($mese < $mese_inizio_periodi) { $mese = $mese_inizio_periodi; }
 $data_fine_periodi = esegui_query("select max(idperiodi) from $tableperiodi");
 $id_data_fine_periodi = risul_query($data_fine_periodi,0,0);
 $data_fine_periodi = esegui_query("select * from $tableperiodi where idperiodi = '$id_data_fine_periodi'");
-$data_fine_periodi = risul_query($data_fine_periodi,0,datainizio);
+$data_fine_periodi = risul_query($data_fine_periodi,0,'datainizio');
 $data_fine_periodi = explode("-",$data_fine_periodi);
 $mese_fine_periodi = $data_fine_periodi[1] + (($data_fine_periodi[0] - $anno) * 12);
 if ($mese > $mese_fine_periodi) { $mese = $mese_fine_periodi; }
@@ -202,7 +203,7 @@ $appartamenti = esegui_query("select * from $tableappartamenti order by idappart
 $num_appartamenti = numlin_query($appartamenti);
 
 $aggiunta_tronca = esegui_query("select valpersonalizza_num from $tablepersonalizza where idpersonalizza = 'aggiunta_tronca_nomi_tab1' and idutente = '$id_utente'");
-$aggiunta_tronca = risul_query($aggiunta_tronca,0,valpersonalizza_num);
+$aggiunta_tronca = risul_query($aggiunta_tronca,0,'valpersonalizza_num');
 if ($aggiunta_tronca < -4) $aggiunta_tronca = -4;
 
 if ($priv_vedi_tab_mesi == "p") {
@@ -212,9 +213,9 @@ else $appartamenti_consentiti = trova_app_consentiti($appartamenti,$num_appartam
 } # fine if ($priv_vedi_tab_mesi == "p")
 
 $linee_ripeti_date_tab_mesi = esegui_query("select valpersonalizza_num from $tablepersonalizza where idpersonalizza = 'linee_ripeti_date_tab_mesi' and idutente = '$id_utente'");
-$linee_ripeti_date_tab_mesi = risul_query($linee_ripeti_date_tab_mesi,0,valpersonalizza_num);
+$linee_ripeti_date_tab_mesi = risul_query($linee_ripeti_date_tab_mesi,0,'valpersonalizza_num');
 $mostra_giorni_tab_mesi = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'mostra_giorni_tab_mesi' and idutente = '$id_utente'");
-$mostra_giorni_tab_mesi = risul_query($mostra_giorni_tab_mesi,0,valpersonalizza);
+$mostra_giorni_tab_mesi = risul_query($mostra_giorni_tab_mesi,0,'valpersonalizza');
 
 function ins_nome_giorno (&$var,$g_corr) {
 $var .= "<small>";
@@ -230,7 +231,7 @@ $var .= "</small>";
 } # fine function ins_nome_giorno
 
 $num_righe_app_max = esegui_query("select valpersonalizza_num from $tablepersonalizza where idpersonalizza = 'num_linee_tab2_prenota' and idutente = '$id_utente'");
-$num_righe_app_max = risul_query($num_righe_app_max,0,valpersonalizza_num);
+$num_righe_app_max = risul_query($num_righe_app_max,0,'valpersonalizza_num');
 $num_tabelle = floor($num_righe_app_max/$num_appartamenti);
 $mese_ini_for = $mese;
 $mese_fine_for = $mese;
@@ -299,9 +300,9 @@ echo "</td></tr></table>
 $mese_inizio_tab = $mese2;
 $data_inizio_tab = date("Y-m-d" , mktime(0,0,0,$mese_inizio_tab,1,$anno));
 $data_inizio_tab = esegui_query("select * from $tableperiodi where datainizio >= '$data_inizio_tab' order by idperiodi");
-$id_data_inizio_tab = risul_query($data_inizio_tab,0,idperiodi);
+$id_data_inizio_tab = risul_query($data_inizio_tab,0,'idperiodi');
 if ($mese2 != $mese_inizio_periodi) {
-$g_inizio_tab = risul_query($data_inizio_tab,0,datainizio);
+$g_inizio_tab = risul_query($data_inizio_tab,0,'datainizio');
 $g_inizio_tab = explode("-",$g_inizio_tab);
 $g_inizio_tab = $g_inizio_tab[2];
 if ($g_inizio_tab == 7 or $g_inizio_tab == 6) { $id_data_inizio_tab = $id_data_inizio_tab - 1; }
@@ -311,8 +312,8 @@ $data_fine_tab = date("Y-m-d" , mktime(0,0,0,$mese_fine_tab,31,$anno));
 $data_fine_tab = esegui_query("select * from $tableperiodi where datainizio <= '$data_fine_tab' order by idperiodi");
 $num_date = numlin_query($data_fine_tab);
 $num_date = $num_date - 1;
-$id_data_fine_tab = risul_query($data_fine_tab,$num_date,idperiodi);
-$g_fine_tab = risul_query($data_fine_tab,$num_date,datafine);
+$id_data_fine_tab = risul_query($data_fine_tab,$num_date,'idperiodi');
+$g_fine_tab = risul_query($data_fine_tab,$num_date,'datafine');
 $g_fine_tab = explode("-",$g_fine_tab);
 $g_fine_tab = $g_fine_tab[2];
 if ($g_fine_tab == 8 or $g_fine_tab == 9 or $g_fine_tab == 10) { $id_data_fine_tab = $id_data_fine_tab - 1; }
@@ -325,7 +326,7 @@ $num_colonne = $id_data_fine_tab - $id_data_inizio_tab + 1;
 $num_appartamenti_cancellati = 0;
 $query_prenota_app_canc = "select * from $tableprenota where iddatainizio <= '$id_data_fine_tab' and iddatafine >= '$id_data_inizio_tab'";
 for ($num1 = 0 ; $num1 < $num_appartamenti ; $num1 = $num1 + 1) {
-$id_appartamento = risul_query($appartamenti,$num1,idappartamenti);
+$id_appartamento = risul_query($appartamenti,$num1,'idappartamenti');
 if ($priv_vedi_tab_mesi != "p" or $appartamenti_consentiti[$id_appartamento] != "NO") $query_prenota_app_canc .= " and idappartamenti != '$id_appartamento'";
 } # fine for $num1
 if ($priv_vedi_tab_mesi == "p") {
@@ -341,7 +342,7 @@ $num_prenota_app_canc = numlin_query($prenota_app_canc);
 $num_app_canc = 0;
 unset($app_canc_trovato);
 for ($num1 = 0 ; $num1 < $num_prenota_app_canc; $num1 = $num1 + 1) {
-$idapp_prenota_app_canc = risul_query($prenota_app_canc,$num1,idappartamenti);
+$idapp_prenota_app_canc = risul_query($prenota_app_canc,$num1,'idappartamenti');
 if ($app_canc_trovato[$idapp_prenota_app_canc] != "SI") {
 $app_canc_trovato[$idapp_prenota_app_canc] = "SI";
 $app_canc[$num_app_canc] = $idapp_prenota_app_canc;
@@ -354,11 +355,11 @@ $linea_date = "<tr><td>&nbsp;</td>
 for ($num1 = 0 ; $num1 < $num_colonne ; $num1 = $num1 + 1) {
 $id_settimana = $id_data_inizio_tab + $num1;
 $riga_setimana = esegui_query("select * from $tableperiodi where idperiodi = '$id_settimana'");
-$inizio_settimana = risul_query($riga_setimana,0,datainizio);
+$inizio_settimana = risul_query($riga_setimana,0,'datainizio');
 $inizio_settimana = explode("-",$inizio_settimana);
 $g_inizio_settimana = $inizio_settimana[2];
 $m_inizio_settimana = $inizio_settimana[1];
-$fine_settimana = risul_query($riga_setimana,0,datafine);
+$fine_settimana = risul_query($riga_setimana,0,'datafine');
 $fine_settimana = explode("-",$fine_settimana);
 $g_fine_settimana = $fine_settimana[2];
 $m_fine_settimana = $fine_settimana[1];
@@ -390,7 +391,7 @@ $num_ripeti = 1;
 
 for ($num1 = 0 ; $num1 < ($num_appartamenti + $num_app_canc) ; $num1 = $num1 + 1) {
 if ($num1 < $num_appartamenti) {
-$id_appartamento = risul_query($appartamenti,$num1,idappartamenti);
+$id_appartamento = risul_query($appartamenti,$num1,'idappartamenti');
 $condizione_prenota_propria = "";
 } # fine if ($num1 < $num_appartamenti)
 else {
@@ -417,7 +418,7 @@ else echo "</small></td>";
 $prenotazione_presente = esegui_query("select * from $tableprenota where idappartamenti = '$id_appartamento' and iddatainizio <= '".($id_data_inizio_tab + $num_colonne - 1)."' and iddatafine >= '$id_data_inizio_tab'$condizione_prenota_propria order by iddatainizio");
 $num_prenotazione_presente = numlin_query($prenotazione_presente);
 $prenota_succ = 0;
-if ($num_prenotazione_presente > 0) $ini_prenota_succ = risul_query($prenotazione_presente,0,iddatainizio);
+if ($num_prenotazione_presente > 0) $ini_prenota_succ = risul_query($prenotazione_presente,0,'iddatainizio');
 else $ini_prenota_succ = $id_data_inizio_tab + $num_colonne + 1;
 
 for ($num2 = 0 ; $num2 < $num_colonne ; $num2 = $num2 + 1) {
@@ -428,18 +429,19 @@ $prenota_corr = $prenota_succ;
 $prenota_succ++;
 if ($num_prenotazione_presente > $prenota_succ) $ini_prenota_succ = risul_query($prenotazione_presente,$prenota_succ,iddatainizio);
 else {
-$ini_prenota_succ = (risul_query($prenotazione_presente,$prenota_corr,iddatafine) + 1);
+$ini_prenota_succ = (risul_query($prenotazione_presente,$prenota_corr,'iddatafine') + 1);
 if (($id_data_inizio_tab + $num_colonne + 1) > $ini_prenota_succ) $ini_prenota_succ = $id_data_inizio_tab + $num_colonne + 1;
 } # fine else if ($num_prenotazione_presente > $prenota_succ)
 } # fine if ($id_settimana >= $ini_prenota_succ)
 else $esiste = 0;
 
-if ($esiste == 1) $utente_inserimento = risul_query($prenotazione_presente,$prenota_corr,utente_inserimento);
+if ($esiste == 1) $utente_inserimento = risul_query($prenotazione_presente,$prenota_corr,'utente_inserimento');
 else $utente_inserimento = $id_utente;
+
 if ($priv_vedi_tab_mesi == "p" and (($utente_inserimento != $id_utente and ($priv_prenota_gruppi != "SI" or !$utenti_gruppi[$utente_inserimento])) or ($periodo_consentito_app[$id_appartamento][$id_settimana] == "NO" and $esiste != 1))) {
 if ($utente_inserimento != $id_utente and ($priv_prenota_gruppi != "SI" or !$utenti_gruppi[$utente_inserimento])) {
-$id_inizio_prenota = risul_query($prenotazione_presente,$prenota_corr,iddatainizio);
-$id_fine_prenota = risul_query($prenotazione_presente,$prenota_corr,iddatafine);
+$id_inizio_prenota = risul_query($prenotazione_presente,$prenota_corr,'iddatainizio');
+$id_fine_prenota = risul_query($prenotazione_presente,$prenota_corr,'iddatafine');
 if ($id_inizio_prenota > $id_data_inizio_tab) $id_inizio = $id_inizio_prenota;
 else $id_inizio = $id_data_inizio_tab;
 if ($id_fine_prenota < $id_data_fine_tab) $id_fine = $id_fine_prenota;
@@ -456,9 +458,9 @@ if ($id_fine == $id_data_fine_tab) $fatto = "SI";
 while ($fatto == "NO") {
 $id_inizio2 = $id_fine + 1;
 if ($id_inizio2 >= $ini_prenota_succ) {
-$utente_inserimento2 = risul_query($prenotazione_presente,$prenota_succ,utente_inserimento);
-if ($utente_inserimento2 != $id_utente) {
-$id_fine_prenota = risul_query($prenotazione_presente,$prenota_succ,iddatafine);
+$utente_inserimento2 = risul_query($prenotazione_presente,$prenota_succ,'utente_inserimento');
+if ($utente_inserimento2 != $id_utente and ($priv_prenota_gruppi != "SI" or !$utenti_gruppi[$utente_inserimento2])) {
+$id_fine_prenota = risul_query($prenotazione_presente,$prenota_succ,'iddatafine');
 if ($id_fine_prenota < $id_data_fine_tab) $id_fine = $id_fine_prenota;
 else {
 $id_fine = $id_data_fine_tab;
@@ -470,7 +472,7 @@ $prenota_corr = $prenota_succ;
 $prenota_succ++;
 if ($num_prenotazione_presente > $prenota_succ) $ini_prenota_succ = risul_query($prenotazione_presente,$prenota_succ,iddatainizio);
 else {
-$ini_prenota_succ = (risul_query($prenotazione_presente,$prenota_corr,iddatafine) + 1);
+$ini_prenota_succ = (risul_query($prenotazione_presente,$prenota_corr,'iddatafine') + 1);
 if (($id_data_inizio_tab + $num_colonne + 1) > $ini_prenota_succ) $ini_prenota_succ = $id_data_inizio_tab + $num_colonne + 1;
 } # fine else if ($num_prenotazione_presente > $prenota_succ)
 } # fine if ($utente_inserimento2 != $id_utente)
@@ -485,40 +487,55 @@ $colonne++;
 else $fatto = "SI";
 } # fine else if (numlin_query($prenotazione_successiva) == 1)
 } # fine while ($fatto == "NO")
-$colonne_span = $colonne * 8;
-echo "<td align=\"center\" colspan=\"$colonne_span\"><b>-</b></td>";
+if ($priv_oscura_tab_mesi != "v" and $priv_oscura_tab_mesi != "f") {
+$colonne_s = $colonne * 8;
+echo "<td align=\"center\" colspan=\"$colonne_s\"><b>-</b></td>";
+} # fine if ($priv_oscura_tab_mesi != "v" and $priv_oscura_tab_mesi != "f")
+if ($priv_oscura_tab_mesi == "v") {
+for ($num3 = 0 ; $num3 < $colonne ; $num3++) echo "<td colspan=\"8\">&nbsp;</td>";
+} # fine if ($priv_oscura_tab_mesi == "v")
+if ($priv_oscura_tab_mesi == "f") {
+for ($num3 = 0 ; $num3 < $colonne ; $num3++) {
+if ($id_periodo_corrente > ($id_settimana + $num3)) echo "<td colspan=\"8\">&nbsp;</td>";
+else {
+$colonne_s = ($colonne - $num3) * 8;
+echo "<td align=\"center\" colspan=\"$colonne_s\"><b>-</b></td>";
+break;
+} # fine else if ($id_periodo_corrente > ($id_settimana + $num3))
+} # fine for $num3
+} # fine if ($priv_oscura_tab_mesi == "f")
 $num2 = $num2 + $colonne - 1;
 } # fine if ($priv_vedi_tab_mesi == "p" and ($utente_inserimento != $id_utente or...
 else {
 
 if ($esiste == 1) {
-$id_prenota = risul_query($prenotazione_presente,$prenota_corr,idprenota);
-$id_clienti = risul_query($prenotazione_presente,$prenota_corr,idclienti);
+$id_prenota = risul_query($prenotazione_presente,$prenota_corr,'idprenota');
+$id_clienti = risul_query($prenotazione_presente,$prenota_corr,'idclienti');
 if ($id_clienti) {
 $cognome = esegui_query("select cognome,utente_inserimento from $tableclienti where idclienti = '$id_clienti'");
 $mostra_cliente = "SI";
 if ($vedi_clienti == "NO") $mostra_cliente = "NO";
 if ($vedi_clienti == "PROPRI" or $vedi_clienti == "GRUPPI") {
-$utente_inserimento_cli = risul_query($cognome,0,utente_inserimento);
+$utente_inserimento_cli = risul_query($cognome,0,'utente_inserimento');
 if ($vedi_clienti == "PROPRI" and $utente_inserimento_cli != $id_utente) $mostra_cliente = "NO";
 if ($vedi_clienti == "GRUPPI" and !$utenti_gruppi[$utente_inserimento_cli]) $mostra_cliente = "NO";
 } # fine if ($vedi_clienti == "PROPRI" or $vedi_clienti == "GRUPPI")
 if ($mostra_cliente == "NO") $cognome = $id_prenota;
-else $cognome = risul_query($cognome,0,cognome);
+else $cognome = risul_query($cognome,0,'cognome');
 } # fine if ($id_clienti)
 else $cognome = "?";
 
 $colore = "";
-$pagato = risul_query($prenotazione_presente,$prenota_corr,pagato);
+$pagato = risul_query($prenotazione_presente,$prenota_corr,'pagato');
 if (!$pagato) { $pagato = 0; }
-$caparra = risul_query($prenotazione_presente,$prenota_corr,caparra);
+$caparra = risul_query($prenotazione_presente,$prenota_corr,'caparra');
 if (!$caparra) { $caparra = 0; }
-$costo_tot = risul_query($prenotazione_presente,$prenota_corr,tariffa_tot);
+$costo_tot = risul_query($prenotazione_presente,$prenota_corr,'tariffa_tot');
 if ($pagato < $caparra) { $colore = "#CC0000"; }
 else { if ($pagato < $costo_tot) { $colore = "#FFCC00"; } }
 
-$id_inizio_prenota = risul_query($prenotazione_presente,$prenota_corr,iddatainizio);
-$id_fine_prenota = risul_query($prenotazione_presente,$prenota_corr,iddatafine);
+$id_inizio_prenota = risul_query($prenotazione_presente,$prenota_corr,'iddatainizio');
+$id_fine_prenota = risul_query($prenotazione_presente,$prenota_corr,'iddatafine');
 if ($id_inizio_prenota > $id_data_inizio_tab) { $id_inizio = $id_inizio_prenota; }
 else { $id_inizio = $id_data_inizio_tab; }
 if ($id_fine_prenota < $id_data_fine_tab) { $id_fine = $id_fine_prenota; }
@@ -528,14 +545,14 @@ $colonne = $id_fine - $id_inizio + 1;
 $link_modifica = "SI";
 if ($priv_mod_prenotazioni == "n") $link_modifica = "NO";
 if ($priv_mod_prenotazioni == "p" or $priv_mod_prenotazioni == "g") {
-$utente_inserimento = risul_query($prenotazione_presente,$prenota_corr,utente_inserimento);
+$utente_inserimento = risul_query($prenotazione_presente,$prenota_corr,'utente_inserimento');
 if ($priv_mod_prenotazioni == "p" and $utente_inserimento != $id_utente) $link_modifica = "NO";
 if ($priv_mod_prenotazioni == "g" and !$utenti_gruppi[$utente_inserimento]) $link_modifica = "NO";
 } # fine if ($priv_mod_prenotazioni == "p" or $priv_mod_prenotazioni == "g")
 if ($priv_mod_prenota_iniziate != "s" and $id_periodo_corrente >= $id_inizio_prenota) $link_modifica = "NO";
 if ($priv_mod_prenota_ore != "000") {
 $adesso = date("YmdHis",(time() + (C_DIFF_ORE * 3600)));
-$data_ins = risul_query($prenotazione_presente,$prenota_corr,datainserimento);
+$data_ins = risul_query($prenotazione_presente,$prenota_corr,'datainserimento');
 $limite = date("YmdHis",mktime((substr($data_ins,11,2) + $priv_mod_prenota_ore),substr($data_ins,14,2),substr($data_ins,17,2),substr($data_ins,5,2),substr($data_ins,8,2),substr($data_ins,0,4)));
 if ($adesso > $limite) $link_modifica = "NO";
 } # fine if ($priv_mod_prenota_ore != "000")
