@@ -47,6 +47,8 @@ $tablecitta = $PHPR_TAB_PRE."citta";
 $tabledocumentiid = $PHPR_TAB_PRE."documentiid";
 $tableparentele = $PHPR_TAB_PRE."parentele";
 $tableanni = $PHPR_TAB_PRE."anni";
+$tableutenti = $PHPR_TAB_PRE."utenti";
+$tableappartamenti = $PHPR_TAB_PRE."appartamenti";
 
 
 $id_utente = controlla_login($numconnessione,$PHPR_TAB_PRE,$id_sessione,$nome_utente_phpr,$password_phpr,$anno);
@@ -150,7 +152,7 @@ $dir_salvato = esegui_query("select * from $tablecontratti where numero = '$nume
 if (numlin_query($dir_salvato)) $dir_salvato = formatta_dir_salva_doc(risul_query($dir_salvato,0,'testo'));
 else $dir_salvato = "";
 if (!$dir_salvato) $mostra_contratto = "NO";
-if (preg_replace("/$nome_contratto"."_[0-9]{4,4}_[0-9]{5,5}(_[0-9]+(-[0-9]+)?)*\.$suff_file/","",$contr_corr) != "") $mostra_contratto = "NO";
+if (preg_replace("/$nome_contratto"."_[0-9]{4,4}_[0-9]{5,8}(-[0-9]{5,8})?(_[0-9]+(-[0-9]+)?)*\.$suff_file/","",$contr_corr) != "") $mostra_contratto = "NO";
 $n_file = 1;
 $nome_file_contr[$n_file] = $contr_corr_orig;
 if ($mostra_contratto == "NO") {
@@ -343,6 +345,9 @@ for ($num1 = 0 ; $num1 < $num_var_predef_ripeti ; $num1++) ${$var_predef[$num1].
 if ($lista_prenota) {
 $lista_clienti = "";
 if ($priv_vedi_tab_prenotazioni != "n" or ($priv_vedi_tab_mesi != "n" and $priv_mod_prenotazioni != "n")) {
+$tabelle_lock = "";
+$altre_tab_lock = array($tableanni,$tableprenota,$tablecostiprenota,$tableperiodi,$tableclienti,$tablesoldi,$tableutenti);
+$tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
 include("./includes/funzioni_costi_agg.php");
 $lista_prenota = explode(",",$lista_prenota);
 $num_ripeti = count($lista_prenota) - 2;
@@ -351,14 +356,16 @@ $id_prenota = aggslashdb($lista_prenota[$num1]);
 $dati_prenota = esegui_query("select * from $tableprenota where idprenota = '$id_prenota'");
 if (numlin_query($dati_prenota) == 1) {
 $cont = "SI";
-if ($priv_vedi_tab_prenotazioni != "s" and ($priv_vedi_tab_mesi != "s" or $priv_mod_prenotazioni != "s")) {
 $utente_inserimento = risul_query($dati_prenota,0,'utente_inserimento');
+if ($priv_vedi_tab_prenotazioni != "s" and ($priv_vedi_tab_mesi != "s" or $priv_mod_prenotazioni != "s")) {
 if ($priv_vedi_tab_prenotazioni == "g" or (($priv_vedi_tab_mesi == "g" or $priv_vedi_tab_mesi == "q") and $priv_mod_prenotazioni == "g")) {
 if (!$utenti_gruppi[$utente_inserimento]) $cont = "NO";
 } # fine if ($priv_vedi_tab_prenotazioni == "g" or...
 elseif ($utente_inserimento != $id_utente) $cont = "NO";
 } # fine if ($priv_vedi_tab_prenotazioni != "s" and ($priv_vedi_tab_mesi != "s" or $priv_mod_prenotazioni != "s"))
 if ($cont == "SI") {
+${"utente_inserimento_prenotazione_".$num1} = $utente_inserimento;
+${"data_inserimento_prenotazione_".$num1} = substr(risul_query($dati_prenota,0,'datainserimento'),0,16);
 if ($vedi_clienti != "NO") {
 $id_clienti = risul_query($dati_prenota,0,'idclienti');
 $dati_cliente = esegui_query("select * from $tableclienti where idclienti = $id_clienti ");
@@ -427,6 +434,10 @@ $sconto = (double) risul_query($dati_prenota,0,'sconto');
 ${"sconto_".$num1} = $sconto;
 ${"percentuale_tasse_tariffa_".$num1} = risul_query($dati_prenota,0,'tasseperc');
 ${"commento_".$num1} = risul_query($dati_prenota,0,'commento');
+if (strstr(${"commento_".$num1},">")) {
+${"commento_".$num1} = explode(">",${"commento_".$num1});
+${"commento_".$num1} = ${"commento_".$num1}[0];
+} # fine if (strstr(${"commento_".$num1},">"))
 ${"origine_prenotazione_".$num1} = risul_query($dati_prenota,0,'origine');
 $caparra = risul_query($dati_prenota,0,'caparra');
 ${"caparra_".$num1} = $caparra;
@@ -437,6 +448,7 @@ ${"unita_occupata_".$num1} = risul_query($dati_prenota,0,'idappartamenti');
 ${"unita_assegnabili_".$num1} = risul_query($dati_prenota,0,'app_assegnabili');
 ${"pagato_".$num1} = risul_query($dati_prenota,0,'pagato');
 $tariffesettimanali = risul_query($dati_prenota,0,'tariffesettimanali');
+${"tariffesettimanali_".$num1} = $tariffesettimanali;
 $dati_cap = dati_costi_agg_prenota($tablecostiprenota,$id_prenota);
 unset($num_letti_agg);
 $costo_agg_tot = (double) 0;
@@ -447,6 +459,9 @@ $costo_agg_tot = (double) $costo_agg_tot + $costo_agg_parziale;
 ${"nome_costo_agg".$numca."_".$num1} = $dati_cap[$numca]['nome'];
 ${"val_costo_agg".$numca."_".$num1} = $costo_agg_parziale;
 ${"percentuale_tasse_costo_agg".$numca."_".$num1} = $dati_cap[$numca]['tasseperc'];
+${"moltiplica_max_costo_agg".$numca."_".$num1} = $dati_cap[$numca]['moltiplica_costo'];
+${"data_inserimento_costo_agg".$numca."_".$num1} = substr($dati_cap[$numca]['datainserimento'],0,10);
+${"utente_inserimento_costo_agg".$numca."_".$num1} = $dati_cap[$numca]['utente_inserimento'];
 } # fine for $numca
 ${"num_costi_aggiuntivi_".$num1} = $dati_cap['num'];
 ${"n_letti_agg_".$num1} = $num_letti_agg['max'];
@@ -458,15 +473,20 @@ ${"id_anni_prec_".$num1} = risul_query($dati_prenota,0,'id_anni_prec');
 if ($priv_vedi_tab_costi != "n") {
 $num_pagamenti = 0;
 if (${"id_anni_prec_".$num1}) {
+if ($tabelle_lock) {
+unlock_tabelle($tabelle_lock);
+$tabelle_lock = "";
+} # fine if ($tabelle_lock)
 $id_anni_prec_vett = explode(";",${"id_anni_prec_".$num1});
 for ($num2 = 1 ; $num2 < (count($id_anni_prec_vett) - 1) ; $num2++) {
 $id_anno_prec = explode(",",$id_anni_prec_vett[$num2]);
 $anno_prec_esistente = esegui_query("select idanni from $tableanni where idanni = '".aggslashdb($id_anno_prec[0])."'");
 if (numlin_query($anno_prec_esistente)) {
-$pagamenti = esegui_query("select metodo_pagamento,saldo_prenota,data_inserimento from $PHPR_TAB_PRE"."soldi".$id_anno_prec[0]." where saldo_prenota is not NULL and motivazione $LIKE '%;".$id_anno_prec[1]."' order by data_inserimento");
+$pagamenti = esegui_query("select metodo_pagamento,saldo_prenota,data_inserimento,utente_inserimento from $PHPR_TAB_PRE"."soldi".$id_anno_prec[0]." where saldo_prenota is not NULL and motivazione $LIKE '%;".$id_anno_prec[1]."' order by data_inserimento");
 $num_pagamenti2 = numlin_query($pagamenti);
 for ($num3 = 0 ; $num3 < $num_pagamenti2 ; $num3++) {
 ${"data_paga".$num_pagamenti."_".$num1} = substr(risul_query($pagamenti,$num3,'data_inserimento'),0,10);
+${"utente_paga".$num_pagamenti."_".$num1} = risul_query($pagamenti,$num3,'utente_inserimento');
 ${"metodo_paga".$num_pagamenti."_".$num1} = risul_query($pagamenti,$num3,'metodo_pagamento');
 ${"saldo_paga".$num_pagamenti."_".$num1} = risul_query($pagamenti,$num3,'saldo_prenota');
 $num_pagamenti++;
@@ -474,21 +494,22 @@ $num_pagamenti++;
 } # fine (numlin_query($anno_prec_esistente))
 } # fine for $num2
 } # fine if (${"id_anni_prec_".$num1})
-$pagamenti = esegui_query("select metodo_pagamento,saldo_prenota,data_inserimento from $tablesoldi where saldo_prenota is not NULL and motivazione $LIKE '%;$id_prenota' order by data_inserimento");
+$pagamenti = esegui_query("select metodo_pagamento,saldo_prenota,data_inserimento,utente_inserimento from $tablesoldi where saldo_prenota is not NULL and motivazione $LIKE '%;$id_prenota' order by data_inserimento");
 $num_pagamenti2 = numlin_query($pagamenti);
 for ($num2 = 0 ; $num2 < $num_pagamenti2 ; $num2++) {
 ${"data_paga".$num_pagamenti."_".$num1} = substr(risul_query($pagamenti,$num2,'data_inserimento'),0,10);
+${"utente_paga".$num_pagamenti."_".$num1} = risul_query($pagamenti,$num2,'utente_inserimento');
 ${"metodo_paga".$num_pagamenti."_".$num1} = risul_query($pagamenti,$num2,'metodo_pagamento');
 ${"saldo_paga".$num_pagamenti."_".$num1} = risul_query($pagamenti,$num2,'saldo_prenota');
 $num_pagamenti++;
 } # fine for $num2
 ${"num_pagamenti_".$num1} = $num_pagamenti;
 } # fine if ($priv_vedi_tab_costi != "n")
-${"data_inserimento_prenotazione_".$num1} = substr(risul_query($dati_prenota,0,'datainserimento'),0,16);
 } # fine if ($id_data_inizio)
 } # fine if ($cont == "SI")
 } # fine if (numlin_query($dati_prenota) == 1)
 } # fine for $num1
+if ($tabelle_lock) unlock_tabelle($tabelle_lock);
 } # fine if ($priv_vedi_tab_mesi == "s" or ($priv_vedi_tab_mesi == "s" and $priv_mod_prenotazioni != "n"))
 } # fine if ($lista_prenota)
 
@@ -565,8 +586,18 @@ $mostra_torna_indietro = "SI";
 
 
 if ($dir_salva and !$num_contr_esist) $mostra_headers = "NO";
+$foothtm = "";
 
-if ($tipo_contratto == "contrhtm" and !$dir_salva) $show_bar = "NO";
+if ($tipo_contratto == "contrhtm" and !$dir_salva) {
+$show_bar = "NO";
+$headhtm = esegui_query("select testo from $tablecontratti where numero = '$numero_contratto' and tipo = 'headhtm'");
+if (numlin_query($headhtm) == 1) {
+$mostra_headers = "NO";
+echo risul_query($headhtm,0,'testo');
+$foothtm = esegui_query("select testo from $tablecontratti where numero = '$numero_contratto' and tipo = 'foothtm'");
+if (numlin_query($foothtm)) $foothtm = risul_query($foothtm,0,'testo');
+} # fine if (numlin_query($headhtm) == 1)
+} # fine if ($tipo_contratto == "contrhtm" and !$dir_salva)
 if ($tipo_contratto == "contreml") $mostra_torna_indietro = "SI";
 if ($tipo_contratto == "contrrtf" and !$dir_salva) {
 $mostra_headers = "NO";
@@ -627,7 +658,7 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"".htmlspecialchars
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"torna_indietro\" value=\"1\">
-&nbsp;&nbsp;<input class=\"sbutton\" id=\"indi\" type=\"submit\" name=\"indietro\" value=\"".mex("Torna indietro",$pag)."\">
+&nbsp;&nbsp;".bottone_submit_contr(mex("Torna indietro",$pag),"indi","indietro")."
 </div></form><br>";
 } # fine if ($mostra_torna_indietro == "SI")
 
@@ -636,6 +667,7 @@ if (($mostra_contratto == "SI" and $mostra_headers == "SI") or $manda_mail == "S
 if ($tema[$id_utente] and $tema[$id_utente] != "base" and @is_dir("./themes/".$tema[$id_utente]."/php")) include("./themes/".$tema[$id_utente]."/php/foot.php");
 else include("./includes/foot.php");
 } # fine if (($mostra_contratto == "SI" and $mostra_headers == "SI") or...
+if ($foothtm) echo $foothtm;
 
 
 
